@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 5 2004
     copyright            : (C) 2004 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -38,6 +38,7 @@ protected:
 private:
 /// needed if file to be loaded is remote
 	QString tmpfile;
+	bool _merge;
 };
 
 #endif
