@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Jan 18 2007
     copyright            : (C) 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,14 +40,14 @@ RKQuitAgent::RKQuitAgent (QObject *parent) : QObject (parent) {
 	RKWardMainWindow::getMain ()->hide ();
 	cancel_dialog = new RKProgressControl (this, i18n ("Waiting for remaining R commands to finish. To quit immediately, press Cancel (WARNING: This may result in loss of data)"), i18n ("Waiting for R to finish"), RKProgressControl::AllowCancel | RKProgressControl::ShowAtOnce);
 	cancel_dialog->addRCommand (command, true);
-	connect (cancel_dialog, SIGNAL (cancelled ()), this, SLOT (doQuitNow ()));
+	connect (cancel_dialog, SIGNAL (cancelled()), this, SLOT (doQuitNow()));
 
 	if (RKGlobals::rInterface ()->backendIsDead ()) {	// nothing to loose
-		QTimer::singleShot (0, this, SLOT (doQuitNow ()));
+		QTimer::singleShot (0, this, SLOT (doQuitNow()));
 		return;
 	} else if (RKGlobals::rInterface ()->backendIsIdle ()) {
 		// there should be no problem while quitting. If there is, show the dialog after 300 msec
-		QTimer::singleShot (300, this, SLOT (showWaitDialog ()));
+		QTimer::singleShot (300, this, SLOT (showWaitDialog()));
 	} else {
 		showWaitDialog ();
 	}
@@ -74,7 +74,7 @@ void RKQuitAgent::doQuitNow () {
 void RKQuitAgent::rCommandDone (RCommand *) {
 	RK_TRACE (APP);
 
-	QTimer::singleShot (0, this, SLOT (doQuitNow ()));
+	QTimer::singleShot (0, this, SLOT (doQuitNow()));
 }
 
 
