@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Aug 29 2004
     copyright            : (C) 2004, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -50,7 +50,7 @@ RKSaveAgent::RKSaveAgent (KUrl url, bool save_file_as, DoneAction when_done, KUr
 	
 	RKWorkplace::mainWorkplace ()->setWorkspaceURL (save_url, true);
 	RKWorkplace::mainWorkplace ()->saveWorkplace (save_chain);
-	RKGlobals::rInterface ()->issueCommand (new RCommand ("save.image (\"" + save_url.toLocalFile () + "\")", RCommand::App, QString::null, this), save_chain);
+	RKGlobals::rInterface ()->issueCommand (new RCommand ("save.image (\"" + save_url.toLocalFile () + "\")", RCommand::App, QString (), this), save_chain);
 }
 
 RKSaveAgent::~RKSaveAgent () {
@@ -83,7 +83,7 @@ void RKSaveAgent::rCommandDone (RCommand *command) {
 
 		if (res == KMessageBox::Yes) {
 			if (askURL ()) {
-				RKGlobals::rInterface ()->issueCommand (new RCommand ("save.image (\"" + save_url.toLocalFile () + "\")", RCommand::App, QString::null, this), save_chain);
+				RKGlobals::rInterface ()->issueCommand (new RCommand ("save.image (\"" + save_url.toLocalFile () + "\")", RCommand::App, QString (), this), save_chain);
 				return;
 			}
 		} else if (res == KMessageBox::No) {
@@ -99,11 +99,12 @@ void RKSaveAgent::rCommandDone (RCommand *command) {
 
 void RKSaveAgent::done () {
 	RK_TRACE (APP);
+	RKWardMainWindow::getMain ()->setWorkspaceMightBeModified (false);
 	if (save_chain) {
 		RKGlobals::rInterface ()->closeChain (save_chain);
 	}
 	if (when_done == Load) {
-		RKWardMainWindow::getMain ()->fileOpenNoSave (load_url);
+		RKWardMainWindow::getMain ()->askOpenWorkspace (load_url);
 	}
 	deleteLater ();
 }
