@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Mar 11 2011
     copyright            : (C) 2011-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,7 +32,7 @@ This class represents a "pseudo" list of the S4 slots of the corresponding paren
 */
 class RSlotsPseudoObject : public RContainerObject {
 public:
-	RSlotsPseudoObject (RObject *parent);
+	explicit RSlotsPseudoObject (RObject *parent);
 	~RSlotsPseudoObject ();
 
 	QString getFullName () const;
@@ -48,7 +48,7 @@ rather call it a "special" object, instead).
 */
 class RKNamespaceObject : public REnvironmentObject {
 public:
-	RKNamespaceObject (REnvironmentObject* package, const QString name = QString ());
+	explicit RKNamespaceObject (REnvironmentObject* package, const QString name = QString ());
 	~RKNamespaceObject ();
 
 	QString getFullName () const;
@@ -64,7 +64,7 @@ class RObjectList;
 This class represents the list of namespace environments which are loaded, but do not belong to a package on the search path.
 
 (TODO: Actually, we should relax the assumption that objects can only be at one place in the hierarchy, and turn this into a list of
-all namespace environemnts!)
+all namespace environments!)
 
 It exists only once, as a direct child of the RObjectList.
 
@@ -72,7 +72,7 @@ It exists only once, as a direct child of the RObjectList.
 */
 class RKOrphanNamespacesObject : public REnvironmentObject {
 public:
-	RKOrphanNamespacesObject (RObjectList *parent);
+	explicit RKOrphanNamespacesObject (RObjectList *parent);
 	~RKOrphanNamespacesObject ();
 
 	QString getFullName () const;
