@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Aug 20 2004
     copyright            : (C) 2004 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -27,11 +27,4 @@ RKEditor::~RKEditor () {
 //	getObject ()->setObjectOpened (this, false);
 }
 
-QString RKEditor::getDescription () {
-	RK_TRACE (EDITOR);
-	RK_ASSERT (getObject ());
-
-	return ("data:" + getObject ()->getFullName ());
-}
-
 #include "rkeditor.moc"
