@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Aug 20 2004
     copyright            : (C) 2004, 2006, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -125,7 +125,9 @@ void RKEditorDataFrame::rCommandDone (RCommand *command) {
 void RKEditorDataFrame::restoreObject (RObject *object) {
 	RK_TRACE (EDITOR);
 
-#warning TODO: this interface should be moved to the model for good.
+#ifdef __GNUC__
+#	warning TODO: this interface should be moved to the model for good.
+#endif
 	datamodel->restoreObject (object, 0);
 }
 
