@@ -2,8 +2,8 @@
                           twintable.h  -  description
                              -------------------
     begin                : Tue Oct 29 2002
-    copyright            : (C) 2002, 2006, 2007, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002, 2006, 2007, 2010, 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -39,7 +39,7 @@ class KAction;
 class TwinTable : public RKEditor, public RObjectListener, public KXMLGUIClient {
 	Q_OBJECT
 public: 
-	TwinTable (QWidget *parent=0);
+	explicit TwinTable (QWidget *parent=0);
 	~TwinTable ();
 /** Pastes clipboard content to the current table */
 	void paste (RKEditor::PasteMode paste_mode);
@@ -98,6 +98,8 @@ protected:
 	KAction* action_delete_row;
 	KAction* action_delete_rows;
 	KAction* action_enable_editing;
+	KAction* action_tb_lock_editing;
+	KAction* action_tb_unlock_editing;
 	KAction* action_show_rownames;
 	KAction* editCut;
 	KAction* editCopy;
