@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Oct 29 2002
     copyright            : (C) 2002, 2006, 2007, 2010, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -35,7 +35,7 @@ class RKVarEditModelBase;
 class TwinTableMember : public RKTableView {
 	Q_OBJECT
 public: 
-	TwinTableMember (QWidget *parent);
+	explicit TwinTableMember (QWidget *parent);
 	~TwinTableMember ();
 	TwinTableMember *getTwin () { return twin; };
 /** ends editing. Actually it's just a simple wrapper around QTable::endEdit () */
