@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Jan 30 2007
     copyright            : (C) 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -32,7 +32,7 @@
 RKImportDialogFormatSelector::RKImportDialogFormatSelector () : KHBox () {
 	RK_TRACE (DIALOGS);
 
-	new QLabel (i18n ("File format: "), this);
+	new QLabel (i18n ("File format:"), this);
 	combo = new QComboBox (this);
 }
 
@@ -77,7 +77,7 @@ RKImportDialog::RKImportDialog (const QString &context_id, QWidget *parent) : KF
 	// initialize
 	setMode (KFile::File | KFile::ExistingOnly | KFile::LocalOnly);
 	setFilter (formats);
-	connect (this, SIGNAL (filterChanged (const QString&)), this, SLOT (filterWasChanged (const QString&)));
+	connect (this, SIGNAL (filterChanged(QString)), this, SLOT (filterWasChanged(QString)));
 	filterWasChanged (QString ());
 	show ();
 }
