@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Jan 30 2007
     copyright            : (C) 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,10 +21,11 @@
 #include <kfiledialog.h>
 
 #include <qstringlist.h>
-#include <qhbox.h>
+
+#include <khbox.h>
 
 class QComboBox;
-class RKContextMap;
+class RKComponentGUIXML;
 class RKImportDialogFormatSelector;
 
 /** This dialog is designed to allow the user to select a file, and file format. After that a suitable plugin
@@ -40,7 +41,7 @@ public:
 	~RKImportDialog ();
 public slots:
 /** The currently selected file extension filter was changed. Update the file format selection box accordingly. */
-	void filterChanged ();
+	void filterWasChanged (const QString &);
 protected:
 /** reimplemented to a) invoke the relevant plugin, b) trigger self-destruction of the dialog */
 	void accept ();
@@ -52,11 +53,11 @@ private:
 	QStringList format_labels;
 	QStringList filters;
 	QStringList component_ids;
-	RKContextMap *context;
+	RKComponentGUIXML *context;
 };
 
 /** Internal helper class to RKImportDialog. Needed solely to work around a design flaw in the KFileDialog API */
-class RKImportDialogFormatSelector : public QHBox {
+class RKImportDialogFormatSelector : public KHBox {
 friend class RKImportDialog;
 private:
 	RKImportDialogFormatSelector ();
