@@ -2,8 +2,8 @@
                           rkloadlibsdialog  -  description
                              -------------------
     begin                : Mon Sep 6 2004
-    copyright            : (C) 2004, 2006, 2007, 2008, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004 - 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -45,6 +45,7 @@
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkdynamicsearchline.h"
 
 #include "../debug.h"
 
@@ -61,20 +62,20 @@ RKLoadLibsDialog::RKLoadLibsDialog (QWidget *parent, RCommandChain *chain, bool
 	setFaceType (KPageDialog::Tabbed);
 	setModal (modal);
 	setCaption (i18n ("Configure Packages"));
-	setButtons (KDialog::Ok | KDialog::Apply | KDialog::Cancel | KDialog::User1);
+	setButtons (KDialog::Ok | KDialog::Apply | KDialog::Cancel);
 
 	LoadUnloadWidget *luwidget = new LoadUnloadWidget (this);
-	addPage (luwidget, i18n ("Local packages"));
-	connect (this, SIGNAL (installedPackagesChanged ()), luwidget, SLOT (updateInstalledPackages ()));
+	addChild (luwidget, i18n ("Load / Unload R packages"));
+	connect (this, SIGNAL (installedPackagesChanged()), luwidget, SLOT (updateInstalledPackages()));
 
 	install_packages_widget = new InstallPackagesWidget (this);
-	install_packages_pageitem = addPage (install_packages_widget, i18n ("Install / Update / Remove"));
+	install_packages_pageitem = addChild (install_packages_widget, i18n ("Install / Update / Remove R packages"));
 
-	setButtonText (KDialog::User1, i18n ("Configure Repositories"));
+	configure_pluginmaps_pageitem = addChild (new RKPluginMapSelectionWidget (this), i18n ("Manage RKWard Plugins"));
 
 	connect (this, SIGNAL (currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), this, SLOT (slotPageChanged()));
 	QTimer::singleShot (0, this, SLOT (slotPageChanged()));
-	num_child_widgets = 3;
+	num_child_widgets = 4;
 	accepted = false;
 
 	RKGlobals::rInterface ()->issueCommand (".libPaths ()", RCommand::App | RCommand::GetStringVector, QString (), this, GET_CURRENT_LIBLOCS_COMMAND, chain);
@@ -87,6 +88,16 @@ RKLoadLibsDialog::~RKLoadLibsDialog () {
 	else KPageDialog::reject ();
 }
 
+KPageWidgetItem* RKLoadLibsDialog::addChild (QWidget *child_page, const QString &caption) {
+	RK_TRACE (DIALOGS);
+
+	connect (this, SIGNAL (okClicked()), child_page, SLOT (ok()));
+	connect (this, SIGNAL (applyClicked()), child_page, SLOT (apply()));
+	connect (this, SIGNAL (cancelClicked()), child_page, SLOT (cancel()));
+	connect (child_page, SIGNAL (destroyed()), this, SLOT (childDeleted()));
+	return addPage (child_page, caption);
+}
+
 void RKLoadLibsDialog::slotPageChanged () {
 	RK_TRACE (DIALOGS);
 
@@ -100,12 +111,21 @@ void RKLoadLibsDialog::showInstallPackagesModal (QWidget *parent, RCommandChain
 
 	RKLoadLibsDialog *dialog = new RKLoadLibsDialog (parent, chain, true);
 	dialog->auto_install_package = package_name;
-	QTimer::singleShot (0, dialog, SLOT (automatedInstall ()));		// to get past the dialog->exec, below
+	QTimer::singleShot (0, dialog, SLOT (automatedInstall()));		// to get past the dialog->exec, below
 	dialog->setCurrentPage (dialog->install_packages_pageitem);
 	dialog->exec ();
 	RK_TRACE (DIALOGS);
 }
 
+// static
+void RKLoadLibsDialog::showPluginmapConfig (QWidget* parent, RCommandChain* chain) {
+	RK_TRACE (DIALOGS);
+
+	RKLoadLibsDialog *dialog = new RKLoadLibsDialog (parent, chain, false);
+	dialog->setCurrentPage (dialog->configure_pluginmaps_pageitem);
+	dialog->show ();
+}
+
 void RKLoadLibsDialog::automatedInstall () {
 	RK_TRACE (DIALOGS);
 
@@ -144,9 +164,6 @@ void RKLoadLibsDialog::slotButtonClicked (int button) {
 	case KDialog::Apply:
 		emit (applyClicked ());
 		break;
-	case KDialog::User1:
-		RKSettings::configureSettings (RKSettings::PageRPackages, this, chain);
-		break;
 	}
 }
 
@@ -269,13 +286,13 @@ bool RKLoadLibsDialog::installPackages (const QStringList &packages, QString to_
 
 	addLibraryLocation (to_libloc);
 
-	QString command_string = "install.packages (pkgs=c (\"" + packages.join ("\", \"") + "\")" + ", lib=\"" + to_libloc + "\"";
+	QString command_string = "install.packages (c (\"" + packages.join ("\", \"") + "\")" + ", lib=\"" + to_libloc + "\"";
 	QString downloaddir = QDir (RKSettingsModuleGeneral::filesPath ()).filePath ("package_archive");
 	if (RKSettingsModuleRPackages::archivePackages ()) {
 		QDir (RKSettingsModuleGeneral::filesPath ()).mkdir ("package_archive");
 		command_string += ", destdir=\"" + downloaddir + "\"";
 	}
-	if (install_suggested_packages) command_string += ", suggested_packages=TRUE";
+	if (install_suggested_packages) command_string += ", dependencies=TRUE";
 	command_string += ")\n";
 
 	QString repos_string = "options (repos= c(";
@@ -315,7 +332,7 @@ void RKLoadLibsDialog::runInstallationCommand (const QString& command, bool as_r
 		RK_ASSERT (false);
 	}
 
-	QString R_binary (getenv ("R_binary"));
+	QString R_binary (getenv ("R_BINARY"));
 	QString call;
 	QStringList params;
 #ifdef Q_WS_WIN
@@ -340,8 +357,8 @@ void RKLoadLibsDialog::runInstallationCommand (const QString& command, bool as_r
 
 	RKProgressControl *installation_progress = new RKProgressControl (this, message, title, RKProgressControl::CancellableProgress);
 	connect (this, SIGNAL (installationComplete()), installation_progress, SLOT (done()));
-	connect (this, SIGNAL (installationOutput(const QString&)), installation_progress, SLOT (newOutput(const QString&)));
-	connect (this, SIGNAL (installationError(const QString&)), installation_progress, SLOT (newError(const QString&)));
+	connect (this, SIGNAL (installationOutput(QString)), installation_progress, SLOT (newOutput(QString)));
+	connect (this, SIGNAL (installationError(QString)), installation_progress, SLOT (newError(QString)));
 
 	installation_process->start (call, params, QIODevice::ReadWrite | QIODevice::Unbuffered);
 
@@ -374,7 +391,7 @@ void RKLoadLibsDialog::processExited (int exitCode, QProcess::ExitStatus exitSta
 	RK_TRACE (DIALOGS);
 
 	if (exitCode || (exitStatus != QProcess::NormalExit)) {
-		installationError ("\n" + i18n ("Installation process died with exit code %1", exitCode));
+		installationError ('\n' + i18n ("Installation process died with exit code %1", exitCode));
 	}
 
 	emit (installationComplete ());
@@ -414,9 +431,9 @@ LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog) : QWidget (0) {
 	instvbox->addWidget (installed_view);
 
 	load_button = new QPushButton (RKStandardIcons::getIcon (RKStandardIcons::ActionAddRight), i18n ("Load"), this);
-	connect (load_button, SIGNAL (clicked ()), this, SLOT (loadButtonClicked ()));
+	connect (load_button, SIGNAL (clicked()), this, SLOT (loadButtonClicked()));
 	detach_button = new QPushButton (RKStandardIcons::getIcon (RKStandardIcons::ActionRemoveLeft), i18n ("Unload"), this);
-	connect (detach_button, SIGNAL (clicked ()), this, SLOT (detachButtonClicked ()));
+	connect (detach_button, SIGNAL (clicked()), this, SLOT (detachButtonClicked()));
 	buttonvbox->addStretch (1);
 	buttonvbox->addWidget (load_button);
 	buttonvbox->addWidget (detach_button);
@@ -432,11 +449,6 @@ LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog) : QWidget (0) {
 	connect (loaded_view, SIGNAL (itemSelectionChanged()), this, SLOT (updateButtons()));
 	connect (installed_view, SIGNAL (itemSelectionChanged()), this, SLOT (updateButtons()));
 
-	connect (dialog, SIGNAL (okClicked ()), this, SLOT (ok ()));
-	connect (dialog, SIGNAL (applyClicked ()), this, SLOT (apply ()));
-	connect (dialog, SIGNAL (cancelClicked ()), this, SLOT (cancel ()));
-	connect (this, SIGNAL (destroyed ()), dialog, SLOT (childDeleted ()));
-
 	updateInstalledPackages ();
 	updateButtons ();
 }
@@ -508,8 +520,8 @@ void LoadUnloadWidget::updateInstalledPackages () {
 	installed_view->clear ();
 	loaded_view->clear ();
 
-	RKGlobals::rInterface ()->issueCommand (".rk.get.installed.packages ()", RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString::null, this, GET_INSTALLED_PACKAGES, parent->chain);
-	RKGlobals::rInterface ()->issueCommand (".packages ()", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString::null, this, GET_LOADED_PACKAGES, parent->chain);
+	RKGlobals::rInterface ()->issueCommand (".rk.get.installed.packages ()", RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString (), this, GET_INSTALLED_PACKAGES, parent->chain);
+	RKGlobals::rInterface ()->issueCommand (".packages ()", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString (), this, GET_LOADED_PACKAGES, parent->chain);
 }
 
 void LoadUnloadWidget::loadButtonClicked () {
@@ -575,7 +587,7 @@ void LoadUnloadWidget::doLoadUnload () {
 	RK_TRACE (DIALOGS);
 
 	RKProgressControl *control = new RKProgressControl (this, i18n ("There has been an error while trying to load / unload packages. See transcript below for details"), i18n ("Error while handling packages"), RKProgressControl::DetailedError);
-	connect (this, SIGNAL (loadUnloadDone ()), control, SLOT (done ()));
+	connect (this, SIGNAL (loadUnloadDone()), control, SLOT (done()));
 
 	// load packages previously not loaded
 	for (int i = 0; i < loaded_view->topLevelItemCount (); ++i) {
@@ -619,61 +631,99 @@ void LoadUnloadWidget::cancel () {
 	deleteLater ();
 }
 
-
 /////////////////////// InstallPackagesWidget //////////////////////////
+#include <QHeaderView>
+#include <QStyledItemDelegate>
+
+/** Responsible for drawing the "category" items */
+class InstallPackagesDelegate : public QStyledItemDelegate {
+public:
+	InstallPackagesDelegate (QTreeView* parent) : QStyledItemDelegate (parent) {
+		table = parent;
+		expanded = RKStandardIcons::getIcon (RKStandardIcons::ActionCollapseUp);
+		collapsed = RKStandardIcons::getIcon (RKStandardIcons::ActionExpandDown);
+	}
+	void initStyleOption (QStyleOptionViewItem* option, const QModelIndex& index) const {
+		QStyledItemDelegate::initStyleOption (option, index);
+		if (!index.parent ().isValid ()) {
+			QStyleOptionViewItemV4 *v4 = qstyleoption_cast<QStyleOptionViewItemV4 *> (option);
+			if (!v4) {
+				RK_ASSERT (false);
+				return;
+			}
+			v4->icon = table->isExpanded (index) ? expanded : collapsed;
+			v4->features |= QStyleOptionViewItemV2::HasDecoration;
+			v4->font.setBold (true);
+			v4->backgroundBrush = table->palette ().mid ();
+		}
+	}
+	QTreeView* table;
+	QIcon expanded;
+	QIcon collapsed;
+};
 
 InstallPackagesWidget::InstallPackagesWidget (RKLoadLibsDialog *dialog) : QWidget (0) {
 	RK_TRACE (DIALOGS);
 	InstallPackagesWidget::parent = dialog;
 	
-	QVBoxLayout *mvbox = new QVBoxLayout (this);
-	mvbox->setContentsMargins (0, 0, 0, 0);
-	QLabel *label = new QLabel (i18n ("Many packages are available on CRAN (Comprehensive R Archive Network), and other repositories<br>(click \"Configure Repositories\" to add more sources)."), this);
-	mvbox->addWidget (label);
-	QHBoxLayout *hbox = new QHBoxLayout ();
-	mvbox->addLayout (hbox);
+	QHBoxLayout *hbox = new QHBoxLayout (this);
 	hbox->setContentsMargins (0, 0, 0, 0);
 
+	QVBoxLayout *vbox = new QVBoxLayout ();
+	vbox->setContentsMargins (0, 0, 0, 0);
+	hbox->addLayout (vbox);
+	hbox->setStretchFactor (vbox, 2);
+
 	packages_status = new RKRPackageInstallationStatus (this);
 	packages_view = new QTreeView (this);
 	packages_view->setSortingEnabled (true);
 	model = new RKRPackageInstallationStatusSortFilterModel (this);
 	model->setSourceModel (packages_status);
-	model->setFilterCaseSensitivity (Qt::CaseInsensitive);
 	model->setSortCaseSensitivity (Qt::CaseInsensitive);
 	packages_view->setModel (model);
+	packages_view->setItemDelegateForColumn (0, new InstallPackagesDelegate (packages_view));
+	for (int i = 0; i < model->rowCount (); ++i) {  // the root level captions
+		packages_view->setFirstColumnSpanned (i, QModelIndex (), true);
+	}
+	connect (packages_view, SIGNAL(clicked(QModelIndex)), this, SLOT(rowClicked(QModelIndex)));
+	packages_view->setRootIsDecorated (false);
+	packages_view->setIndentation (0);
 	packages_view->setEnabled (false);
 	packages_view->setMinimumHeight (packages_view->sizeHintForRow (0) * 15);	// force a decent height
-	hbox->addWidget (packages_view);
-	hbox->setStretchFactor (packages_view, 2);
+	packages_view->setMinimumWidth (packages_view->fontMetrics ().width ("This is to force a sensible min width for the packages view (empty on construction)"));
+	vbox->addWidget (packages_view);
+
+	QPushButton *configure_repos_button = new QPushButton (i18n ("Configure Repositories"), this);
+	RKCommonFunctions::setTips (i18n ("Many packages are available on CRAN (Comprehensive R Archive Network), and other repositories.<br>Click this to add more sources."), configure_repos_button);
+	connect (configure_repos_button, SIGNAL (clicked()), this, SLOT(configureRepositories()));
+	vbox->addWidget (configure_repos_button);
 
 	QVBoxLayout *buttonvbox = new QVBoxLayout ();
 	hbox->addLayout (buttonvbox);
 	buttonvbox->setContentsMargins (0, 0, 0, 0);
-	label = new QLabel (i18n ("Show only packages matching:"), this);
-	filter_edit = new QLineEdit ("*", this);
-	RKCommonFunctions::setTips (i18n ("<p>You can limit the packages displayed in the list to with names or titles matching a filter string.</p><p><b>Note:</b> To search for partial strings, add '*' to the start and / or end of the filter, e.g. '*stat*'.</p>"), label, filter_edit);
-	connect (filter_edit, SIGNAL (textChanged(const QString&)), this, SLOT (filterStringChanged(const QString&)));
-	filterStringChanged (filter_edit->text ());
+	QLabel *label = new QLabel (i18n ("Show only packages matching:"), this);
+	filter_edit = new RKDynamicSearchLine (this);
+	RKCommonFunctions::setTips (i18n ("<p>You can limit the packages displayed in the list to with names or titles matching a filter string.</p>") + filter_edit->regexpTip (), label, filter_edit);
+	filter_edit->setModelToFilter (model);
+	rkward_packages_only = new QCheckBox (i18n ("Show only packages providing RKWard dialogs"), this);
+	RKCommonFunctions::setTips (i18n ("<p>Some but not all R packages come with plugins for RKWard. That means they provide a graphical user-interface in addition to R functions. Check this box to show only such packages.</p><p></p>"), rkward_packages_only);
+	connect (rkward_packages_only, SIGNAL(stateChanged(int)), this, SLOT (filterChanged()));
+	filterChanged ();
 
 	mark_all_updates_button = new QPushButton (i18n ("Select all updates"), this);
 	connect (mark_all_updates_button, SIGNAL (clicked()), this, SLOT (markAllUpdates()));
 
 	install_params = new PackageInstallParamsWidget (this);
-	connect (parent, SIGNAL (libraryLocationsChanged (const QStringList &)), install_params, SLOT (liblocsChanged (const QStringList &)));
+	connect (parent, SIGNAL (libraryLocationsChanged(QStringList)), install_params, SLOT (liblocsChanged(QStringList)));
 
 	buttonvbox->addWidget (label);
 	buttonvbox->addWidget (filter_edit);
+	buttonvbox->addWidget (rkward_packages_only);
 	buttonvbox->addStretch (1);
 	buttonvbox->addWidget (mark_all_updates_button);
 	buttonvbox->addStretch (1);
 	buttonvbox->addWidget (install_params);
 	buttonvbox->addStretch (1);
-
-	connect (dialog, SIGNAL (okClicked ()), this, SLOT (ok ()));
-	connect (dialog, SIGNAL (applyClicked ()), this, SLOT (apply ()));
-	connect (dialog, SIGNAL (cancelClicked ()), this, SLOT (cancel ()));
-	connect (this, SIGNAL (destroyed ()), dialog, SLOT (childDeleted ()));
 }
 
 InstallPackagesWidget::~InstallPackagesWidget () {
@@ -695,21 +745,31 @@ void InstallPackagesWidget::initialize () {
 
 	packages_status->initialize (parent->chain);
 	packages_view->setEnabled (true);
-	for (int i = 0; i <= RKRPackageInstallationStatus::PackageName; ++i) {
+	// Force a good width for the icon column, particularly for MacOS X.
+	packages_view->header ()->resizeSection (0, packages_view->sizeHintForIndex (model->index (0, 0, model->index (RKRPackageInstallationStatus::NewPackages, 0, QModelIndex ()))).width () + packages_view->indentation ());
+	for (int i = 1; i <= RKRPackageInstallationStatus::PackageName; ++i) {
 		packages_view->resizeColumnToContents (i);
-#ifdef Q_WS_MAC
-		// HACK: Without this, the column is just too narrow on MacOS X, and the icon is hidden
-		if (i == RKRPackageInstallationStatus::EnhancesRKWard) packages_view->setColumnWidth (i, packages_view->columnWidth (i) + 16);
-#endif
+	}
+	// For whatever reason, we have to re-set these, here.
+	for (int i = 0; i < model->rowCount (); ++i) {
+		packages_view->setFirstColumnSpanned (i, QModelIndex (), true);
 	}
 }
 
-void InstallPackagesWidget::filterStringChanged (const QString& new_filter) {
+void InstallPackagesWidget::rowClicked (const QModelIndex& row) {
 	RK_TRACE (DIALOGS);
 
-	QString f = new_filter;
-	if (f.isEmpty ()) f = "*";
-	model->setFilterWildcard (f);
+	if (!row.parent ().isValid ()) {
+		QModelIndex fixed_row = model->index (row.row (), 0, row.parent ());
+		packages_view->setExpanded (fixed_row, !packages_view->isExpanded (fixed_row));
+	}
+}
+
+void InstallPackagesWidget::filterChanged () {
+	RK_TRACE (DIALOGS);
+
+	model->setRKWardOnly (rkward_packages_only->isChecked ());
+	// NOTE: filter string already set by RKDynamicSearchLine
 }
 
 void InstallPackagesWidget::trySelectPackage (const QString &package_name) {
@@ -717,7 +777,7 @@ void InstallPackagesWidget::trySelectPackage (const QString &package_name) {
 
 	QModelIndex index = packages_status->markPackageForInstallation (package_name);
 	if (!index.isValid ()) {
-		KMessageBox::sorry (0, i18n ("The package requested by the backend (\"%1\") was not found in the package repositories. Maybe the package name was mis-spelled. Or maybe you need to add additional repositories via the \"Configure Repositories\"-button.", package_name), i18n ("Package not available"));
+		KMessageBox::sorry (0, i18n ("The package requested by the backend (\"%1\") was not found in the package repositories. Maybe the package name was mis-spelled. Or maybe you need to add additional repositories via the \"Configure Repositories\" button.", package_name), i18n ("Package not available"));
 	} else {
 		packages_view->scrollTo (model->mapFromSource (index));
 	}
@@ -775,6 +835,11 @@ void InstallPackagesWidget::cancel () {
 	deleteLater ();
 }
 
+void InstallPackagesWidget::configureRepositories () {
+	RK_TRACE (DIALOGS);
+	RKSettings::configureSettings (RKSettings::PageRPackages, this, parent->chain);
+}
+
 /////////////////////// PackageInstallParamsWidget //////////////////////////
 
 #include <qcombobox.h>
@@ -972,25 +1037,29 @@ QVariant RKRPackageInstallationStatus::data (const QModelIndex &index, int role)
 	if (!index.parent ().isValid ()) {	// top level item
 		int row = index.row ();
 		if (row == UpdateablePackages) {
-			if ((role == Qt::DisplayRole) && (index.column () == PackageName)) return QVariant (i18n ("Updateable Packages"));
+			if (role == Qt::DisplayRole) return QVariant (i18n ("Updateable Packages"));
 			if (role == Qt::ToolTipRole) return QVariant (i18n ("Packages for which an update is available. This may include packages which were merely built against a newer version of R."));
 		} else if (row == NewPackages) {
-			if ((role == Qt::DisplayRole) && (index.column () == PackageName)) return QVariant (i18n ("New Packages"));
+			if (role == Qt::DisplayRole) return QVariant (i18n ("New Packages"));
 			if (role == Qt::ToolTipRole) return QVariant (i18n ("Packages which are available for installation, but which are not currently installed."));
 		} else if (row == InstalledPackages) {
-			if ((role == Qt::DisplayRole) && (index.column () == PackageName)) return QVariant (i18n ("Installed Packages"));
+			if (role == Qt::DisplayRole) return QVariant (i18n ("Installed Packages"));
 			if (role == Qt::ToolTipRole) return QVariant (i18n ("Packages which are installed locally. Note that updates may be available for these packages."));
 		}
-		if (role == Qt::BackgroundColorRole) return QVariant (QColor (200, 200, 200));
 	} else if (!index.parent ().parent ().isValid ()) {		// model has exactly two levels
-		int col = index.column ();
-		int prow = index.parent ().row ();
+		const int col = index.column ();
+		const int prow = index.parent ().row ();
 		int arow, irow;		// row numbers in the lists of available_packages / installed_packages
+		arow = irow = 0;	// Suppress bogus GCC warning (doesn't seem to understand that irow is not needed for NewPackages, and arow is not needed for InstalledPackages)
 		if (prow == UpdateablePackages) {
 			arow = updateable_packages_in_available.value (index.row ());
 			irow = updateable_packages_in_installed.value (index.row ());
-		} else if (prow == NewPackages) arow = new_packages_in_available.value (index.row ());
-		else irow = index.row ();
+		} else if (prow == NewPackages) {
+			arow = new_packages_in_available.value (index.row ());
+		} else {
+			RK_ASSERT (prow == InstalledPackages);
+			irow = index.row ();
+		}
 
 		if (col == InstallationStatus) {
 			PackageStatusChange stat;
@@ -1037,7 +1106,10 @@ QVariant RKRPackageInstallationStatus::data (const QModelIndex &index, int role)
 			if (role == Qt::DisplayRole) {
 				if (prow == InstalledPackages) return installed_libpaths.value (irow);
 				else if (prow == NewPackages) return available_repos.value (arow);
-				else return QVariant (installed_libpaths.value (irow) + " -> " + available_repos.value (arow));
+				else {
+					RK_ASSERT (prow == UpdateablePackages);
+					return QVariant (installed_libpaths.value (irow) + " -> " + available_repos.value (arow));
+				}
 			}
 		}
 	}
@@ -1140,6 +1212,7 @@ bool RKRPackageInstallationStatus::packagesToRemove (QStringList *packages, QStr
 
 RKRPackageInstallationStatusSortFilterModel::RKRPackageInstallationStatusSortFilterModel (QObject* parent) : QSortFilterProxyModel (parent) {
 	RK_TRACE (DIALOGS);
+	rkward_only = false;
 }
 
 RKRPackageInstallationStatusSortFilterModel::~RKRPackageInstallationStatusSortFilterModel () {
@@ -1159,12 +1232,80 @@ bool RKRPackageInstallationStatusSortFilterModel::lessThan (const QModelIndex &l
 bool RKRPackageInstallationStatusSortFilterModel::filterAcceptsRow (int source_row, const QModelIndex &source_parent) const {
 	if (!source_parent.isValid ()) return true;		// Never filter the top level item
 
+	if (rkward_only) {
+		bool enhance_rk = source_parent.child (source_row, RKRPackageInstallationStatus::EnhancesRKWard).data (Qt::UserRole).toBool ();
+		if (!enhance_rk) return false;
+	}
 // filter on Name and Title
 	QString name = source_parent.child (source_row, RKRPackageInstallationStatus::PackageName).data ().toString ();
-	if (filterRegExp ().exactMatch (name)) return true;
+	if (name.contains (filterRegExp ())) return true;
 	QString title = source_parent.child (source_row, RKRPackageInstallationStatus::PackageTitle).data ().toString ();
-	return (filterRegExp ().exactMatch (title));
+	return (title.contains (filterRegExp ()));
+}
+
+void RKRPackageInstallationStatusSortFilterModel::setRKWardOnly (bool only) {
+	RK_TRACE (DIALOGS);
+
+	bool old_only = rkward_only;
+	rkward_only = only;
+	if (rkward_only != old_only) invalidate ();
+}
+
+/////////////////////////
+#include "../misc/multistringselector.h"
+RKPluginMapSelectionWidget::RKPluginMapSelectionWidget (RKLoadLibsDialog* dialog) : QWidget (dialog) {
+	RK_TRACE (DIALOGS);
+	model = 0;
+	changes_pending = false;
+
+	QVBoxLayout *vbox = new QVBoxLayout (this);
+	vbox->setContentsMargins (0, 0, 0, 0);
+	vbox->addWidget (new QLabel (i18n ("Installed plugin groups (.pluginmap files)"), this));
+	selector = new RKMultiStringSelectorV2 (QString (), this);
+	vbox->addWidget (selector);
+}
+
+RKPluginMapSelectionWidget::~RKPluginMapSelectionWidget () {
+	RK_TRACE (DIALOGS);
+}
+
+void RKPluginMapSelectionWidget::activated () {
+	RK_TRACE (DIALOGS);
+
+	if (!model) {
+		model = new RKSettingsModulePluginsModel (this);
+		model->init (RKSettingsModulePlugins::knownPluginmaps ());
+		selector->setModel (model, 1);
+		connect (selector, SIGNAL (insertNewStrings(int)), model, SLOT (insertNewStrings(int)));
+		connect (selector, SIGNAL (swapRows(int,int)), model, SLOT (swapRows(int,int)));
+		connect (selector, SIGNAL (listChanged()), this, SLOT (changed()));
+	}
+}
+
+void RKPluginMapSelectionWidget::apply () {
+	RK_TRACE (DIALOGS);
+
+	if (!changes_pending) return;
+	RK_ASSERT (model);
+	RKSettingsModulePlugins::PluginMapList new_list = RKSettingsModulePlugins::setPluginMaps (model->pluginMaps ());
+	selector->setModel (0); // we don't want any extra change notification for this
+	model->init (new_list);
+	selector->setModel (model, 1);
+	changes_pending = false;
+}
+
+void RKPluginMapSelectionWidget::cancel () {
+	RK_TRACE (DIALOGS);
+	deleteLater ();
+}
+
+void RKPluginMapSelectionWidget::ok () {
+	RK_TRACE (DIALOGS);
+
+	if (!changes_pending) return;
+	RK_ASSERT (model);
+	RKSettingsModulePlugins::setPluginMaps (model->pluginMaps ());
+	deleteLater ();
 }
 
 #include "rkloadlibsdialog.moc"
-
