@@ -2,8 +2,8 @@
                           rkloadlibsdialog  -  description
                              -------------------
     begin                : Mon Sep 6 2004
-    copyright            : (C) 2004, 2006, 2007, 2009, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004 - 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -39,6 +39,7 @@ class RCommandChain;
 class QCheckBox;
 class PackageInstallParamsWidget;
 class InstallPackagesWidget;
+class RKDynamicSearchLine;
 
 /**
 Dialog which excapsulates widgets to load/unload, update and install R packages
@@ -63,6 +64,7 @@ public:
 @param chain RCommandChain to run the necessary commands in
 @param package_name name of the required package */
 	static void showInstallPackagesModal (QWidget *parent, RCommandChain *chain, const QString &package_name);
+	static void showPluginmapConfig (QWidget *parent=0, RCommandChain *chain=0);
 	QStringList currentLibraryLocations ()  const { return library_locations; };
 signals:
 	void downloadComplete ();
@@ -87,12 +89,14 @@ private:
 	void addLibraryLocation (const QString &new_loc);
 	void tryDestruct ();
 	void runInstallationCommand (const QString& command, bool as_root, const QString& message, const QString& title);
+	KPageWidgetItem* addChild (QWidget *child_page, const QString &caption);
 friend class LoadUnloadWidget;
 friend class InstallPackagesWidget;
 	RCommandChain *chain;
 
 	InstallPackagesWidget *install_packages_widget;	// needed for automated installation
 	KPageWidgetItem *install_packages_pageitem;
+	KPageWidgetItem *configure_pluginmaps_pageitem;
 
 	QStringList library_locations;
 
@@ -112,7 +116,7 @@ To be used in RKLoadLibsDialog
 class LoadUnloadWidget : public QWidget, public RCommandReceiver {
 Q_OBJECT
 public:
-	LoadUnloadWidget (RKLoadLibsDialog *dialog);
+	explicit LoadUnloadWidget (RKLoadLibsDialog *dialog);
 	
 	~LoadUnloadWidget ();
 signals:
@@ -147,7 +151,7 @@ private:
 class RKRPackageInstallationStatus : public QAbstractItemModel {
 	Q_OBJECT
 public:
-	RKRPackageInstallationStatus (QObject* parent);
+	explicit RKRPackageInstallationStatus (QObject* parent);
 	~RKRPackageInstallationStatus ();
 
 	void initialize (RCommandChain *chain);
@@ -218,11 +222,13 @@ private:
 
 class RKRPackageInstallationStatusSortFilterModel : public QSortFilterProxyModel {
 public:
-	RKRPackageInstallationStatusSortFilterModel (QObject* parent = 0);
+	explicit RKRPackageInstallationStatusSortFilterModel (QObject* parent = 0);
 	~RKRPackageInstallationStatusSortFilterModel ();
+	void setRKWardOnly (bool only);
 protected:
 	bool lessThan (const QModelIndex &left, const QModelIndex &right) const;
 	bool filterAcceptsRow (int source_row, const QModelIndex &source_parent) const;
+	bool rkward_only;
 };
 
 /**
@@ -234,7 +240,7 @@ To be used in RKLoadLibsDialog.
 class InstallPackagesWidget : public QWidget {
 Q_OBJECT
 public:
-	InstallPackagesWidget (RKLoadLibsDialog *dialog);
+	explicit InstallPackagesWidget (RKLoadLibsDialog *dialog);
 	
 	~InstallPackagesWidget ();
 	void trySelectPackage (const QString &package_name);
@@ -243,17 +249,20 @@ public slots:
 	void ok ();
 	void apply ();
 	void cancel ();
-	void filterStringChanged (const QString &new_filter);
+	void filterChanged ();
 	void activated ();
 	void markAllUpdates ();
+	void configureRepositories ();
+	void rowClicked (const QModelIndex& row);
 private:
 	void doInstall (bool refresh);
 	QTreeView *packages_view;
 	RKRPackageInstallationStatus *packages_status;
-	QSortFilterProxyModel *model;
+	RKRPackageInstallationStatusSortFilterModel *model;
 
 	QPushButton *mark_all_updates_button;
-	QLineEdit *filter_edit;
+	RKDynamicSearchLine *filter_edit;
+	QCheckBox *rkward_packages_only;
 	PackageInstallParamsWidget *install_params;
 	
 	RKLoadLibsDialog *parent;
@@ -267,7 +276,7 @@ Simple helper class for RKLoadLibsDialog to allow selection of installation para
 class PackageInstallParamsWidget : public QWidget {
 Q_OBJECT
 public:
-	PackageInstallParamsWidget (QWidget *parent);
+	explicit PackageInstallParamsWidget (QWidget *parent);
 	
 	~PackageInstallParamsWidget ();
 
@@ -280,4 +289,24 @@ private:
 	QCheckBox *suggested_packages;
 };
 
+
+#include "../settings/rksettingsmoduleplugins.h"
+
+class RKPluginMapSelectionWidget : public QWidget {
+Q_OBJECT
+public:
+	explicit RKPluginMapSelectionWidget (RKLoadLibsDialog *dialog);
+	virtual ~RKPluginMapSelectionWidget ();
+public slots:
+	void ok ();
+	void apply ();
+	void cancel ();
+	void activated ();
+	void changed () { changes_pending = true; };
+private:
+	RKMultiStringSelectorV2* selector;
+	RKSettingsModulePluginsModel* model;
+	bool changes_pending;
+};
+
 #endif
