@@ -2,8 +2,8 @@
                           startupdialog  -  description
                              -------------------
     begin                : Thu Aug 26 2004
-    copyright            : (C) 2004, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004, 2011, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -69,7 +69,7 @@ StartupDialog::StartupDialog (QWidget *parent, StartupDialogResult *result, KRec
 	} else restore_workspace_button->setText (i18n ("Load workspace from current directory:\n%1", rdata_file.toLocalFile ()));
 	choser_layout->addWidget (open_button = new QRadioButton (i18n ("Load an existing workspace:"), choser_box));
 	choser->addButton (open_button);
-	connect (open_button, SIGNAL (toggled (bool)), this, SLOT (openButtonSelected (bool)));
+	connect (open_button, SIGNAL (toggled(bool)), this, SLOT (openButtonSelected(bool)));
 	empty_table_button->setChecked (true);
 
 	file_list = new QListWidget (choser_box);
@@ -77,10 +77,13 @@ StartupDialog::StartupDialog (QWidget *parent, StartupDialogResult *result, KRec
 	file_list->setSortingEnabled (false);
 	chose_file_item = new QListWidgetItem (i18n ("<<Open another file>>"), file_list);
 	if (recent_files) {
-		file_list->addItems (recent_files->urls ().toStringList ());
+		KUrl::List urls = recent_files->urls ();
+		for (int i = 0; i < urls.length (); ++i) {
+			file_list->addItem (urls[i].pathOrUrl ());
+		}
 	}
-	connect (file_list, SIGNAL (itemClicked (QListWidgetItem*)), this, SLOT (listClicked (QListWidgetItem*)));
-	connect (file_list, SIGNAL (itemDoubleClicked (QListWidgetItem*)), this, SLOT (listDoubleClicked (QListWidgetItem*)));
+	connect (file_list, SIGNAL (itemClicked(QListWidgetItem*)), this, SLOT (listClicked(QListWidgetItem*)));
+	connect (file_list, SIGNAL (itemDoubleClicked(QListWidgetItem*)), this, SLOT (listDoubleClicked(QListWidgetItem*)));
 	choser_layout->addWidget (file_list);
 	choser_layout->addWidget (remember_box = new QCheckBox (i18n ("Always do this on startup"), choser_box));
 }
