@@ -2,8 +2,8 @@
                           main.cpp  -  description
                              -------------------
     begin                : Tue Oct 29 20:06:08 CET 2002
-    copyright            : (C) 2002, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier 
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002-2014 by Thomas Friedrichsmeier 
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -23,7 +23,7 @@
 **
 **	\section	website	Website
 **
-**	<A HREF="http://rkward.sourceforge.net">RKWard's project page</A>
+**	<A HREF="http://rkward.kde.org">RKWard's project page</A>
 **
 **	\section	description Description
 **
@@ -59,11 +59,13 @@
 #include <QMutex>
 #include <QTemporaryFile>
 #include <QDir>
+#include <QThread>
 
 #include <stdio.h>
 #include <stdlib.h>
 
 #include "rkward.h"
+#include "rkglobals.h"
 #include "rkwardapplication.h"
 #include "settings/rksettingsmoduledebug.h"
 #include "windows/rkdebugmessagewindow.h"
@@ -78,7 +80,7 @@
 #include "version.h"
 
 int RK_Debug_Level = 0;
-int RK_Debug_Flags = ALL;
+int RK_Debug_Flags = DEBUG_ALL;
 int RK_Debug_CommandStep = 0;
 QMutex RK_Debug_Mutex;
 
@@ -96,8 +98,8 @@ void RKDebugMessageOutput (QtMsgType type, const char *msg) {
 }
 
 /** The point of this redirect (to be called via the RK_DEBUG() macro) is to separate RKWard specific debug messages from
- * any other noise, coming from Qt / kdelibs. Also it allows us to retain info on flags and level. Eventually, this could
- * be made available in a tool window, esp. for debugging plugins. */
+ * any other noise, coming from Qt / kdelibs. Also it allows us to retain info on flags and level, and to show messages
+ * in a tool window, esp. for debugging plugins. */
 void RKDebug (int flags, int level, const char *fmt, ...) {
 	const int bufsize = 1024*8;
 	char buffer[bufsize];
@@ -107,43 +109,49 @@ void RKDebug (int flags, int level, const char *fmt, ...) {
 	vsnprintf (buffer, bufsize-1, fmt, ap);
 	va_end (ap);
 	RKDebugMessageOutput (QtDebugMsg, buffer);
-	RKDebugMessageWindow::newMessage (flags, level, QString (buffer));
+	if (QApplication::instance ()->thread () == QThread::currentThread ()) {
+		// not safe to call from any other than the GUI thread
+		RKDebugMessageWindow::newMessage (flags, level, QString (buffer));
+	}
+}
+
+QString decodeArgument (const QString &input) {
+	return (QUrl::fromPercentEncoding (input.toUtf8()));
 }
 
 int main(int argc, char *argv[]) {
-/* #ifdef Q_WS_X11
-	This (along with the proper includes, of course) makes library (gWidgetsRGtk2) work on X11 on some systems.
-	Unfortunately, on others, I causes lockups when plotting.
-
-	XInitThreads ();
-	XtToolkitThreadInitialize ();
-#endif */
 	options.add ("evaluate <Rcode>", ki18n ("After starting (and after loading the specified workspace, if applicable), evaluate the given R code."), 0);
 	options.add ("debug-level <level>", ki18n ("Verbosity of debug messages (0-5)"), "2");
-	options.add ("debug-flags <flags>", ki18n ("Mask for components to debug (see debug.h)"), "8191");
-	options.add ("debugger <command>", ki18n ("Debugger (enclose any debugger arguments in single quotes ('') together with the command)"), "");
-	options.add ("+[File]", ki18n ("R workspace file to open"), 0);
+	options.add ("debug-flags <flags>", ki18n ("Mask for components to debug (see debug.h)"), QString::number (DEBUG_ALL).toLocal8Bit ());
+	options.add ("debugger <command and arguments>", ki18n ("Debugger for the frontend. Specify last, or add '--' after all debugger arguments"), "");
+	options.add ("backend-debugger <command>", ki18n ("Debugger for the backend. (Enclose any debugger arguments in single quotes ('') together with the command. Make sure to re-direct stdout!)"), "");
+	options.add ("r-executable <command>", ki18n ("Use specified R installation, instead of the one configured at compile time (note: rkward R library must be installed to that installation of R)"), "");
+	options.add ("reuse", ki18n ("Reuse a running RKWard instance (if available). If a running instance is reused, only the file arguments will be interpreted, all other options will be ignored."), 0);
+	options.add ("+[Files]", ki18n ("File or files to open, typically a workspace, or an R script file. When loading several things, you should specify the workspace, first."), 0);
 
-	KAboutData aboutData("rkward", QByteArray (), ki18n ("RKWard"), RKWARD_VERSION, ki18n ("Frontend to the R statistics language"), KAboutData::License_GPL, ki18n ("(c) 2002, 2004 - 2013"), KLocalizedString (), "http://rkward.sf.net", "rkward-devel@lists.sourceforge.net");
-	aboutData.addAuthor (ki18n ("%1").subs ("Thomas Friedrichsmeier"), ki18n ("Project leader / main developer"));
-	aboutData.addAuthor (ki18n ("%1").subs ("Pierre Ecochard"), ki18n ("C++ developer between 2004 and 2007"));
-	aboutData.addAuthor (ki18n ("%1").subs ("Prasenjit Kapat"), ki18n ("Many plugins, suggestions, plot history feature"));
-	aboutData.addCredit (ki18n ("%1").subs ("Meik Michalke"), ki18n ("Many plugins, suggestions, rkwarddev package"));
-	aboutData.addAuthor (ki18n ("%1").subs ("Stefan Roediger"), ki18n ("Many plugins, suggestions, marketing, translations"));
+	KAboutData aboutData("rkward", QByteArray (), ki18n ("RKWard"), RKWARD_VERSION, ki18n ("Frontend to the R statistics language"), KAboutData::License_GPL, ki18n ("(c) 2002, 2004 - 2015"), KLocalizedString (), "http://rkward.kde.org", "submit@bugs.kde.org");
+	aboutData.addAuthor (ki18n ("Thomas Friedrichsmeier"), ki18n ("Project leader / main developer"));
+	aboutData.addAuthor (ki18n ("Pierre Ecochard"), ki18n ("C++ developer between 2004 and 2007"));
+	aboutData.addAuthor (ki18n ("Prasenjit Kapat"), ki18n ("Many plugins, suggestions, plot history feature"));
+	aboutData.addAuthor (ki18n ("Meik Michalke"), ki18n ("Many plugins, suggestions, rkwarddev package"));
+	aboutData.addAuthor (ki18n ("Stefan Roediger"), ki18n ("Many plugins, suggestions, marketing, translations"));
 	aboutData.addCredit (ki18n ("Contributors in alphabetical order"));
-	aboutData.addCredit (ki18n ("%1").subs ("Philippe Grosjean"), ki18n ("Several helpful comments and discussions"));
-	aboutData.addCredit (ki18n ("%1").subs ("Adrien d'Hardemare"), ki18n ("Plugins and patches"));
-	aboutData.addCredit (ki18n ("%1").subs ("Yves Jacolin"), ki18n ("New website"));
-	aboutData.addCredit (ki18n ("%1").subs ("Germán Márquez Mejía"), ki18n ("HP filter plugin, spanish translation"), 0);
-	aboutData.addCredit (ki18n ("%1").subs ("Marco Martin"), ki18n ("A cool icon"));
-	aboutData.addCredit (ki18n ("%1").subs ("Daniele Medri"), ki18n ("RKWard logo, many suggestions, help on wording"));
-	aboutData.addCredit (ki18n ("%1").subs ("David Sibai"), ki18n ("Several valuable comments, hints and patches"));
-	aboutData.addCredit (ki18n ("%1").subs ("Ilias Soumpasis"), ki18n ("Translation, Suggestions, plugins"));
-	aboutData.addCredit (ki18n ("%1").subs ("Ralf Tautenhahn"), ki18n ("Many comments, useful suggestions, and bug reports"));
-	aboutData.addCredit (ki18n ("%1").subs ("Jannis Vajen"), ki18n ("German Translation, bug reports"));
-	aboutData.addCredit (ki18n ("%1").subs ("Roland Vollgraf"), ki18n ("Some patches"));
-	aboutData.addCredit (ki18n ("%1").subs ("Roy Qu"), ki18n ("patches and helpful comments"));
-	aboutData.addCredit (ki18n ("Many more people on rkward-devel@lists.sourceforge.net"), ki18n ("Sorry, if we forgot to list you. Please contact us to get added"));
+	aboutData.addCredit (ki18n ("Björn Balazs"), ki18n ("Extensive usability feedback"));
+	aboutData.addCredit (ki18n ("Aaron Batty"), ki18n ("Whealth of feedback, hardware donations"));
+	aboutData.addCredit (ki18n ("Jan Dittrich"), ki18n ("Extensive usability feedback"));
+	aboutData.addCredit (ki18n ("Philippe Grosjean"), ki18n ("Several helpful comments and discussions"));
+	aboutData.addCredit (ki18n ("Adrien d'Hardemare"), ki18n ("Plugins and patches"));
+	aboutData.addCredit (ki18n ("Yves Jacolin"), ki18n ("New website"));
+	aboutData.addCredit (ki18n ("Germán Márquez Mejía"), ki18n ("HP filter plugin, spanish translation"), 0);
+	aboutData.addCredit (ki18n ("Marco Martin"), ki18n ("A cool icon"));
+	aboutData.addCredit (ki18n ("Daniele Medri"), ki18n ("RKWard logo, many suggestions, help on wording"));
+	aboutData.addCredit (ki18n ("David Sibai"), ki18n ("Several valuable comments, hints and patches"));
+	aboutData.addCredit (ki18n ("Ilias Soumpasis"), ki18n ("Translation, Suggestions, plugins"));
+	aboutData.addCredit (ki18n ("Ralf Tautenhahn"), ki18n ("Many comments, useful suggestions, and bug reports"));
+	aboutData.addCredit (ki18n ("Jannis Vajen"), ki18n ("German Translation, bug reports"));
+	aboutData.addCredit (ki18n ("Roland Vollgraf"), ki18n ("Some patches"));
+	aboutData.addCredit (ki18n ("Roy Qu"), ki18n ("patches and helpful comments"));
+	aboutData.addCredit (ki18n ("Many more people on rkward-devel@kde.org"), ki18n ("Sorry, if we forgot to list you. Please contact us to get added"));
 
 	// before initializing the commandline args, remove the ".bin" from "rkward.bin".
 	// This is so it prints "Usage rkward..." instead of "Usage rkward.bin...", etc.
@@ -160,16 +168,23 @@ int main(int argc, char *argv[]) {
 	RK_Debug_Level = DL_FATAL - QString (args->getOption ("debug-level")).toInt ();
 	RK_Debug_Flags = QString (args->getOption ("debug-flags")).toInt ();
 	if (!args->getOption ("debugger").isEmpty ()) {
-		RK_DEBUG (ALL, DL_ERROR, "--debugger option should have been handled by wrapper script. Ignoring.");
+		RK_DEBUG (DEBUG_ALL, DL_ERROR, "--debugger option should have been handled by wrapper script. Ignoring.");
 	}
 
-	RKWardStartupOptions *stoptions = new RKWardStartupOptions;
 	if (args->count ()) {
-		stoptions->initial_url = args->url (0);
+		QVariantList urls_to_open;
+		for (int i = 0; i < args->count (); ++i) {
+			urls_to_open.append (QUrl (KCmdLineArgs::makeURL (decodeArgument (args->arg (i)).toUtf8 ())));
+		}
+		RKGlobals::startup_options["initial_urls"] = urls_to_open;
 	}
-	stoptions->evaluate = args->getOption ("evaluate");
+	RKGlobals::startup_options["evaluate"] = decodeArgument (args->getOption ("evaluate"));
+	RKGlobals::startup_options["backend-debugger"] = decodeArgument (args->getOption ("backend-debugger"));
 
 	RKWardApplication app;
+	// No, I do not really understand the point of separating KDE_LANG from LANGUAGE. We do honor it in so far as not
+	// forcing LANGUAGE on the backend, though. Having language as LANGUAGE makes code in RKMessageCatalog much easier compared to KCatalog.
+	qputenv ("LANGUAGE", QFile::encodeName (KGlobal::locale ()->language ()));
 	// install message handler *after* the componentData has been initialized
 	RKSettingsModuleDebug::debug_file = new QTemporaryFile (QDir::tempPath () + "/rkward.frontend");
 	RKSettingsModuleDebug::debug_file->setAutoRemove (false);
@@ -181,7 +196,7 @@ int main(int argc, char *argv[]) {
 	if (app.isSessionRestored ()) {
 		RESTORE(RKWardMainWindow);	// well, whatever this is supposed to do -> TODO
 	} else {
-		new RKWardMainWindow(stoptions);
+		new RKWardMainWindow ();
 	}
 	args->clear();
 
