@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Sep 21 2004
     copyright            : (C) 2004, 2006, 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -75,7 +75,7 @@ Allows editing of value labels / factor levels for an RKVariable. Use EditLabels
 class EditLabelsDialog : public KDialog {
 protected:
 friend class EditLabelsDialogProxy;
-/** constuctor., the variable to work on.
+/** constructor., the variable to work on.
 @param parent a QWidget parent */
 	EditLabelsDialog (QWidget *parent, const RObject::ValueLabels& labels, const QString& varname);
 
@@ -93,7 +93,7 @@ Simple proxy / wrapper to allow using a modal EditLabelsDialog in a QTableView
 class EditLabelsDialogProxy : public QWidget {
 	Q_OBJECT
 public:
-	EditLabelsDialogProxy (QWidget* parent);
+	explicit EditLabelsDialogProxy (QWidget* parent);
 	~EditLabelsDialogProxy ();
 
 	void initialize (const RObject::ValueLabels& labels, const QString& varname);
