@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Sep 10 2005
     copyright            : (C) 2005, 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
