@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Feb 28 2007
     copyright            : (C) 2007, 2009 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,10 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kapplication.h>
-
 #include "rkdummypart.h"
 
+#include <kglobal.h>
+
 #include "../debug.h"
 
 RKDummyPart::RKDummyPart (QObject *parent, QWidget *widget) : KParts::Part (parent) {
