@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Sep 10 2006
     copyright            : (C) 2006, 2007, 2008, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -189,7 +189,7 @@ QString RKProgressControl::fullCommandOutput() {
 	RK_TRACE (MISC);
 
 	QString ret;
-	foreach (ROutput out, output_log) ret.append (out.output);
+	foreach (const ROutput& out, output_log) ret.append (out.output);
 	return ret;
 }
 
