@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Nov 27 2006
     copyright            : (C) 2006, 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
