@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Nov 18 2007
     copyright            : (C) 2007-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
