@@ -2,8 +2,8 @@
                           xmlhelper.cpp  -  description
                              -------------------
     begin                : Fri May 6 2005
-    copyright            : (C) 2005, 2007, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2007, 2011, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -25,61 +25,54 @@
 #include <qdir.h>
 #include <QTextStream>
 
+#include <rkmessagecatalog.h>
+
 #include "../debug.h"
 
-//static
-XMLHelper *XMLHelper::static_xml_helper=0;
-
-XMLHelper::XMLHelper () {
+XMLHelper::XMLHelper (const QString &filename, const RKMessageCatalog *default_catalog) {
 	RK_TRACE (XML);
-
-	highest_error = 0;
+	XMLHelper::filename = filename;
+	if (!default_catalog) catalog = RKMessageCatalog::nullCatalog ();
+	else catalog = default_catalog;
 }
 
 XMLHelper::~XMLHelper () {
 	RK_TRACE (XML);
 }
 
-//static 
-XMLHelper *XMLHelper::getStaticHelper () {
-	RK_TRACE (XML);
-
-	if (!static_xml_helper) {
-		static_xml_helper = new XMLHelper ();
-	}
-	return static_xml_helper;
-}
-
-QDomElement XMLHelper::openXMLFile (const QString &filename, int debug_level, bool with_includes, bool with_snippets) {
+QDomElement XMLHelper::openXMLFile (int debug_level, bool with_includes, bool with_snippets) {
 	RK_TRACE (XML);
 
 	int error_line, error_column;
 	QString error_message;
 	QDomDocument doc;
 
-	XMLHelper::filename = filename;
-	highest_error = 0;
-	
 	QFile f (filename);
-	if (!f.open (QIODevice::ReadOnly)) displayError (0, i18n("Could not open file for reading"), debug_level, DL_ERROR);
+	if (!f.open (QIODevice::ReadOnly)) displayError (0, i18n("Could not open file %1 for reading", filename), debug_level, DL_ERROR);
 	if (!doc.setContent(&f, false, &error_message, &error_line, &error_column)) {
 		displayError (0, i18n ("Error parsing XML-file. Error-message was: '%1' in line '%2', column '%3'. Expect further errors to be reported below", error_message, error_line, error_column), debug_level, DL_ERROR);
+		return QDomElement ();
 	}
 	f.close();
 
 	QDomElement ret = doc.documentElement ();
+	if (ret.hasAttribute ("po_id")) {
+		QDir path = QFileInfo (filename).absoluteDir ();
+		catalog = RKMessageCatalog::getCatalog ("rkward__" + ret.attribute ("po_id"), path.absoluteFilePath (getStringAttribute (ret, "po_path", "po", DL_INFO)));
+	}
 	if (with_includes) {
 		XMLChildList includes = nodeListToChildList (doc.elementsByTagName ("include"));
 		for (XMLChildList::const_iterator it = includes.constBegin (); it != includes.constEnd (); ++it) {
 			// resolve the file to include
 			QDomElement el = *it;
 
-			QString inc_filename = getStringAttribute (el, "file", QString::null, DL_ERROR);
+			QString inc_filename = getStringAttribute (el, "file", QString (), DL_ERROR);
 			QDir base = QFileInfo (filename).absoluteDir ();
 			inc_filename = base.filePath (inc_filename);
 
 			// import
-			QDomElement included = openXMLFile (inc_filename, debug_level, true, false);
+			XMLHelper inc_xml = XMLHelper (inc_filename);
+			QDomElement included = inc_xml.openXMLFile (debug_level, true, false);
 
 			if (!included.isNull ()) {
 				QDomElement copied = doc.importNode (included, true).toElement ();
@@ -102,7 +95,7 @@ void XMLHelper::replaceWithChildren (QDomNode *replaced, const QDomElement &repl
 	RK_ASSERT (replaced);
 
 	QDomNode parent = replaced->parentNode ();
-	XMLChildList replacement_children = getChildElements (replacement_parent, QString::null, DL_WARNING);
+	XMLChildList replacement_children = getChildElements (replacement_parent, QString (), DL_WARNING);
 	for (XMLChildList::const_iterator it = replacement_children.constBegin (); it != replacement_children.constEnd (); ++it) {
 		parent.insertBefore (*it, *replaced);
 	}
@@ -135,19 +128,19 @@ QDomElement XMLHelper::resolveSnippets (QDomElement &from_doc) {
 
 	for (XMLChildList::const_iterator it = refs.constBegin (); it != refs.constEnd (); ++it) {
 		QDomElement ref = *it;
-		QString id = getStringAttribute (ref, "snippet", QString::null, DL_ERROR);
-		displayError (&ref, "resolving snippet '" + id + "'", DL_DEBUG, DL_DEBUG);
+		QString id = getStringAttribute (ref, "snippet", QString (), DL_ERROR);
+		displayError (&ref, "resolving snippet '" + id + '\'', DL_DEBUG, DL_DEBUG);
 
 		// resolve the reference
 		QDomElement snippet;
 		for (XMLChildList::const_iterator it = snippets.constBegin(); it != snippets.constEnd (); ++it) {
-			if (getStringAttribute (*it, "id", QString::null, DL_ERROR) == id) {
+			if (getStringAttribute (*it, "id", QString (), DL_ERROR) == id) {
 				snippet = *it;
 				break;
 			}
 		}
 		if (snippet.isNull ()) {
-			displayError (&ref, "no such snippet '" + id + "'", DL_ERROR, DL_ERROR);
+			displayError (&ref, "no such snippet '" + id + '\'', DL_ERROR, DL_ERROR);
 		}
 
 		// now insert it.
@@ -235,7 +228,6 @@ XMLChildList XMLHelper::findElementsWithAttribute (const QDomElement &parent, co
 	return ret;
 }
 
-
 QString XMLHelper::getStringAttribute (const QDomElement &element, const QString &name, const QString &def, int debug_level) {
 	RK_TRACE (XML);
 
@@ -247,6 +239,23 @@ QString XMLHelper::getStringAttribute (const QDomElement &element, const QString
 	return (element.attribute (name));
 }
 
+QString XMLHelper::i18nStringAttribute (const QDomElement& element, const QString& name, const QString& def, int debug_level) {
+	RK_TRACE (XML);
+	if (!element.hasAttribute (name)) {
+		const QString no18nname = "noi18n_" + name;
+		if (element.hasAttribute (no18nname)) return element.attribute (no18nname);
+		displayError (&element, i18n ("'%1'-attribute not given. Assuming '%2'", name, def), debug_level);
+		return def;
+	}
+
+	QString attr = element.attribute (name);
+	if (attr.isEmpty ()) return attr;	// Do not translate empty strings!
+
+	const QString context = element.attribute ("i18n_context", QString ());
+	if (!context.isNull ()) return (catalog->translate (context, attr));
+	return (catalog->translate (attr));
+}
+
 int XMLHelper::getMultiChoiceAttribute (const QDomElement &element, const QString &name, const QString &values, int def, int debug_level) {
 	RK_TRACE (XML);
 
@@ -310,29 +319,73 @@ bool XMLHelper::getBoolAttribute (const QDomElement &element, const QString &nam
 	return def;
 }
 
-QString XMLHelper::getRawContents (const QDomElement &element, int debug_level) {
-	RK_TRACE (XML);
-
+QString translateChunk (const QString &chunk, const QString &context, bool add_paragraphs, const RKMessageCatalog *catalog) {
+	// if (!with_paragraphs), text should better not contain double newlines. We treat all the same, though, just as the message extraction script does.
+	QStringList paras = chunk.split ("\n\n");
 	QString ret;
-	QTextStream stream (&ret);
 
-	if (!element.isNull()) {
-		QTextStream stream (&ret, QIODevice::WriteOnly);
-		for (QDomNode node = element.firstChild (); !node.isNull (); node = node.nextSibling ()) {
-			node.save (stream, 0);
+	for (int i = 0; i < paras.count (); ++i) {
+		QString para = paras[i].simplified ();
+		if (para.isEmpty ()) ret.append (QChar (' '));
+		else {
+			if (!ret.isEmpty ()) ret.append ("\n");
+			// Oh, crap. Fix up after some differences between python message extraction and qt's.
+			para.replace ("<li> <", "<li><");
+			para.replace ("br> <", "br><");
+			para.replace ("> </li>", "></li>");
+			para.replace ("&amp;", "&");
+			QString text = context.isNull () ? catalog->translate (para) : catalog->translate (context, para);
+			if (add_paragraphs) ret += "<p>" + text + "</p>";
+			else ret += text;
 		}
-	} else {
-		displayError (&element, i18n ("Trying to retrieve contents of invalid element"), debug_level);
 	}
 
 	return ret;
 }
 
-void XMLHelper::displayError (const QDomNode *in_node, const QString &message, int debug_level, int message_level) {
+QString XMLHelper::i18nElementText (const QDomElement &element, bool with_paragraphs, int debug_level) const {
+	RK_TRACE (XML);
+
+	if (element.isNull ()) {
+		displayError (&element, i18n ("Trying to retrieve contents of invalid element"), debug_level);
+		return QString ();
+	}
+
+	QString ret;
+	QString context = element.attribute ("i18n_context", QString ());
+	QString buffer;
+	QTextStream stream (&buffer, QIODevice::WriteOnly);
+	for (QDomNode node = element.firstChild (); !node.isNull (); node = node.nextSibling ()) {
+		QDomElement e = node.toElement ();
+		if (!e.isNull ()) {
+			if (e.tagName () == QLatin1String ("ul") || e.tagName () == QLatin1String ("ol") || e.tagName () == QLatin1String ("li") || e.tagName () == QLatin1String ("p")) { // split translation units on these elements
+				// split before
+				ret.append (translateChunk (buffer, context, with_paragraphs, catalog));
+				buffer.clear ();
+
+				// serialize the tag with all its attributes but not the children.
+				e.cloneNode (false).save (stream, 0);   // will write: <TAG[ attributes]/>
+				buffer = buffer.left (buffer.lastIndexOf ('/')) + QChar ('>');
+				buffer.append (i18nElementText (e, false, debug_level));
+				buffer.append ("</" + e.tagName () + QChar ('>'));
+
+				// split after
+				ret.append (buffer);
+				buffer.clear ();
+				continue;
+			}
+		}
+		node.save (stream, 0);
+	}
+	ret.append (translateChunk (buffer, context, with_paragraphs, catalog));
+
+	return ret;
+}
+
+void XMLHelper::displayError (const QDomNode *in_node, const QString &message, int debug_level, int message_level) const {
 	RK_TRACE (XML);
 
 	if (message_level < debug_level) message_level = debug_level;
-	if (highest_error < debug_level) highest_error = debug_level;
 
 	if ((RK_Debug_Flags & XML) && (message_level >= RK_Debug_Level)) {
 		QString backtrace = i18n ("XML-parsing '%1' ", filename);
