@@ -2,8 +2,8 @@
                           rkabstractoptionselector  -  description
                              -------------------
     begin                : Tue Mar 20 2007
-    copyright            : (C) 2007, 2009, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2007, 2009, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -27,9 +27,9 @@ RKAbstractOptionSelector::RKAbstractOptionSelector (RKComponent *parent_componen
 
 	// create and register properties
 	addChild ("string", string = new RKComponentPropertyBase (this, false));
-	connect (string, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (propertyChanged (RKComponentPropertyBase *)));
+	connect (string, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (propertyChanged(RKComponentPropertyBase*)));
 	addChild ("number", number = new RKComponentPropertyInt (this, true, -1));
-	connect (number, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (propertyChanged (RKComponentPropertyBase *)));
+	connect (number, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (propertyChanged(RKComponentPropertyBase*)));
 	number->setInternal (true);
 }
 
@@ -45,16 +45,16 @@ void RKAbstractOptionSelector::addOptionsAndInit (const QDomElement &element) {
 	RK_TRACE (PLUGIN);
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parentComponent ()->xmlHelper ();
 
 	// create all the options
 	XMLChildList option_elements = xml->getChildElements (element, "option", DL_ERROR);	
 	int selected = 0;
 	int i = 0;
 	for (XMLChildList::const_iterator it = option_elements.begin (); it != option_elements.end (); ++it) {
-		QString label = xml->getStringAttribute (*it, "label", QString::null, DL_ERROR);
-		QString value = xml->getStringAttribute (*it, "value", QString::null, DL_WARNING);
-		QString name = xml->getStringAttribute (*it, "id", QString::null, DL_INFO);
+		QString label = xml->i18nStringAttribute (*it, "label", QString (), DL_ERROR);
+		QString value = xml->getStringAttribute (*it, "value", QString (), DL_WARNING);
+		QString name = xml->getStringAttribute (*it, "id", QString (), DL_INFO);
 
 		Option *opt = new Option;
 		opt->value = value;
@@ -83,11 +83,11 @@ RKComponentBase* RKAbstractOptionSelector::lookupComponent (const QString &ident
 
 	if (identifier.isEmpty ()) return this;
 
-	QString name = identifier.section (".", 0, 0);
+	QString name = identifier.section ('.', 0, 0);
 	if (named_options.contains (name)) {
 		Option *opt = named_options[name];
 
-		QString mod = identifier.section (".", 1);
+		QString mod = identifier.section ('.', 1);
 		if (mod != "enabled") {
 			RK_DEBUG (PLUGIN, DL_DEBUG, "options do not have property '%s'", mod.toLatin1().data ());
 			return this;
@@ -119,6 +119,11 @@ void RKAbstractOptionSelector::propertyChanged (RKComponentPropertyBase *propert
 	}
 	if (new_id < 0) {
 		RK_DEBUG (PLUGIN, DL_ERROR, "option selector '%s' has no such option:", qPrintable (getIdInParent ()));
+/*		RKComponent *p = this; 
+		while (p) {
+			qDebug ("p: %s", qPrintable (p->getIdInParent ()));
+			p = p->parentComponent();
+		} */
 		if (property == string) {
 			RK_DEBUG (PLUGIN, DL_ERROR, "'%s'", qPrintable (fetchStringValue (string)));
 		} else {
@@ -170,6 +175,7 @@ void RKAbstractOptionSelector::ItemPropertyChanged (RKComponentPropertyBase *pro
 			}
 			if (settable_opt >= 0) itemSelected (settable_opt);
 			else RK_DEBUG (PLUGIN, DL_ERROR, "No option left enabled. Disable the entire component '%s', instead!", qPrintable (getIdInParent ()));
+			// TODO: Error message below can also trigger, if items first get disabled, then others enabled. Delay it, instead.
 		}
 	}
 
