@@ -2,8 +2,8 @@
                           rkcheckbox  -  description
                              -------------------
     begin                : Fri Jul 30 2004
-    copyright            : (C) 2004, 2006, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004, 2006, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,6 +41,7 @@ public:
 		if (modifier.isEmpty ()) return state->value ("labeled");
 		return (state->value (modifier));
 	};
+	QStringList getUiLabelPair () const;
 public slots:
 	void changedState (int);
 	void changedState (RKComponentPropertyBase *);
