@@ -2,8 +2,8 @@
                           rkcomponent  -  description
                              -------------------
     begin                : Tue Dec 13 2005
-    copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2011, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -63,6 +63,7 @@ public:
 		ComponentFrame = 2016,
 		ComponentOptionSet = 2017,
 		ComponentMatrixInput = 2018,
+		ComponentValueSelector = 2019,
 		ComponentStandard = 2100,
 		ComponentContextHandler = 2900,
 		ComponentUser = 3000	/**< for user expansion */
@@ -92,16 +93,18 @@ public:
 /** Locate the component.subcomponent.property.value described by identifier and return its value as a string. Especially useful as a callback in code templates! Recursively walks subcomponents/properties until the requested value is found. @See RKComponentBase::lookupComponent */
 	QString fetchStringValue (const QString &identifier);
 	static QString fetchStringValue (RKComponentBase* prop, const QString &modifier=QString ());
-/** returns the "value" of this component or property. Properties generally return their value, components typically return the value of their "most important" property. Default implementation returns QString::null, and writes a debug message */
+/** returns the "value" of this component or property. Properties generally return their value, components typically return the value of their "most important" property. Default implementation returns QString (), and writes a debug message */
 	virtual QVariant value (const QString &modifier=QString ());
 	enum ValueTypeHint {
 		TraditionalValue,
 		BooleanValue,
 		StringValue,
 		StringlistValue,
-		NumericValue
+		NumericValue,
+		UiLabelPair
 	};
 	QVariant fetchValue (const QString &identifier, const int type_hint);
+	virtual QStringList getUiLabelPair () const { return QStringList (); };
 /** returns true, if this is a property */
 	bool isProperty () { return (type () <= PropertyEnd); };
 	bool isComponent () { return (type () >= ComponentBase); };
@@ -153,6 +156,7 @@ private:
 
 #include "rkcomponentproperties.h"
 
+class XMLHelper;
 /** abstract base class of all RKComponents, including component widgets */
 class RKComponent : public QWidget, public RKComponentBase {
 	Q_OBJECT
@@ -202,9 +206,11 @@ public:
 /** The parent of this component. Should be notified, whenever isSatisfied () or recursiveStatus () changed. */
 	RKComponent *parentComponent () const { return _parent; };
 /** The standard component containing this component (if any). If @param id_adjust is given, it will be set to a relative path to the standard component. */
-	RKStandardComponent *standardComponent (QString *id_adjust=0);
+	RKStandardComponent *standardComponent (QString *id_adjust=0) const;
 /** Like standardcomponent, but will return the topmost component in case of embedding. */
 	RKStandardComponent *topmostStandardComponent ();
+/** Return a properly initialize helper for parsing XML in this component. */
+	XMLHelper *xmlHelper () const;
 
 /** Find the id of this component. NOTE: this is slow. Better to store the id in the first place, if needed */
 	QString getIdInParent () const;
@@ -223,6 +229,8 @@ protected:
 	void createDefaultProperties ();
 /** This function is needed internally, to set the Qt enabledness of this widget, and all child component widgets. Note that the enabledness as stored in the enabledness_property is not necessarily the same as the enabledness in the GUI (and is not affected by this call). In general, a component is enabled in the GUI, if and only if a) it's enabledness_property is set to true, b) its parent widget is enabled in Qt, and c) it's parent component is also enabled. */
 	void updateEnablednessRecursive (bool parent_component_enabled);
+/** Helper for getUiLabelPair(): Strips accelator key markup ("&") from strings */
+	static QString stripAccelerators (const QString &in);
 };
 
 #endif
