@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Nov 25 2005
     copyright            : (C) 2005, 2006, 2007, 2009, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef RKCOMPONETPROPERTIES_H
-#define RKCOMPONETPROPERTIES_H
+#ifndef RKCOMPONENTPROPERTIES_H
+#define RKCOMPONENTPROPERTIES_H
 
 #include <qobject.h>
 
@@ -54,7 +54,7 @@ public:
 /** connect this property to a governor property (given as argument). If reconcile_requirements, the requirements of both properties are reconciled to the least common denominator. The dependent property will be notified on all changes made in the governing property, so it can update its value. 
 Generally with few exceptions, you can only connect to properties that are either of the same class as this property, or of an extended class. Maybe in the future we will add some sophisticated converters allowing to connect vastly different types of properties in a meaningful way.
 If you specify a modifier, only the sub-value indicated by the modifier will be retrieved from the governing property on governorValueChanged. In this case reconcile_requirements is ignored. */
-	virtual void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	virtual void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 signals:
 /** property has changed its value. Any connected RKComponentPropertys/RKComponents should update their state
 @param property A pointer to the changed property for easy reference */
@@ -70,10 +70,41 @@ protected:
 	QString governor_modifier;
 };
 
+//////////////////////////////////////////////// AbstractList //////////////////////////////////////////////////
+/** Base class for list properties (RKComponentPropertyStringList and RKComponentPropertyRObjects) */
+class RKComponentPropertyAbstractList : public RKComponentPropertyBase {
+public:
+	RKComponentPropertyAbstractList (QObject* parent, bool required);
+	virtual ~RKComponentPropertyAbstractList ();
+/** how many items can this property hold? Use default values (0) to remove constraints
+@param min_num_items Minimum number of items for this property to be valid
+@param min_num_items_if_any Some properties may be valid, if they hold either no items at all, or at least a certain number of items
+@param max_num_items Maximum number of items for this property to be valid */
+	void setAllowedLength (int min_num_items=0, int min_num_items_if_any=0, int max_num_items=0);
+/** @returns true, if the property holds the maximum number of items (or more) */
+	bool atMaxLength () const { return (max_num_items && (max_num_items <= listLength ())); };
+/** reimplemented from RKComponentPropertyBase to actually reconcile requirements with other list properties */
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
+/** If set to true, duplicate values are dropped, silently */
+	void setStripDuplicates (bool strip) { strip_duplicates = strip; };
+	virtual void removeAt (int index) = 0;
+	virtual int listLength () const = 0;
+	virtual bool setValueList (const QStringList &new_values) = 0;
+protected:
+	bool getStripDuplicates () const { return strip_duplicates; };
+	bool checkListLength ();
+	void reconcileLengthRequirements (RKComponentPropertyAbstractList *governor);
+	static QString sep;
+private:
+	int min_num_items;
+	int min_num_items_if_any;
+	int max_num_items;
+	bool strip_duplicates;
+};
 
 /////////////////////////////////////////////// StringList /////////////////////////////////////////////////////
 /** RKComponentProperty, which can handle lists of strings, better */
-class RKComponentPropertyStringList : public RKComponentPropertyBase {
+class RKComponentPropertyStringList : public RKComponentPropertyAbstractList {
 public:
 	RKComponentPropertyStringList (QObject *parent, bool required);
 /** destructor */
@@ -92,12 +123,14 @@ public:
 /** get all current strings as a QStringList */
 	const QStringList& values () const { return storage; };
 /** set current strings as a QStringList */
-	void setValues (const QStringList &new_values) { storage = new_values; doChange (); };
+	bool setValueList (const QStringList &new_values) { storage = new_values; checkStripDuplicates (); doChange (); return true; };
 /** reimplemented from RKComponentPropertyBase to use special handling for list properties */
 	void governorValueChanged (RKComponentPropertyBase *property);
+	int listLength () const { return (storage.size ()); };
+	void removeAt (int index);
 private:
-	void doChange () { _value.clear (); emit (valueChanged (this)); };
-	QString sep;	// always "\n". TODO: remove
+	void doChange ();
+	void checkStripDuplicates ();
 	QStringList storage;
 };
 
@@ -173,7 +206,7 @@ public:
 /** reimplemented from RKComponentPropertyBase to test whether conversion to int value is possible according to current settings (is a number, and within limits min and max) */
 	bool isStringValid (const QString &string);
 /** reimplemented from RKComponentPropertyBase to actually reconcile requirements with other numeric slots */
-	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 /** reimplemented from RKComponentPropertyBase to use special handling for int and double properties (ints are copied directly, doubles are rounded) */
 	void governorValueChanged (RKComponentPropertyBase *property);
 /** RTTI */
@@ -222,7 +255,7 @@ public:
 /** reimplemented from RKComponentPropertyBase to test whether conversion to int value is possible according to current settings (is a number, and within limits min and max) */
 	bool isStringValid (const QString &string);
 /** reimplemented from RKComponentPropertyBase to actually reconcile requirements with other numeric slots */
-	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 /** reimplemented from RKComponentPropertyBase to use special handling for int and double properties (ints and doubles are copied directly) */
 	void governorValueChanged (RKComponentPropertyBase *property);
 /** RTTI */
@@ -251,18 +284,13 @@ class RKObjectListView;
 #include "../core/rkmodificationtracker.h"
 
 /** special type of RKComponentProperty, that prepresents one or more RObject (s) */
-class RKComponentPropertyRObjects : public RKComponentPropertyBase, public RObjectListener {
+class RKComponentPropertyRObjects : public RKComponentPropertyAbstractList, public RObjectListener {
 	Q_OBJECT
 public:
 /** constructor */
 	RKComponentPropertyRObjects (QObject *parent, bool required);
 /** destructor */
 	~RKComponentPropertyRObjects ();
-/** how many objects can this property hold? Use default values (0) to remove constraints
-@param min_num_objects Minimum number of objects for this property to be valid
-@param min_num_objects_if_any Some properties may be valid, if they hold either no objects at all, or at least a certain number of objects
-@param max_num_objects Maximum number of objects for this property to be valid */
-	void setListLength (int min_num_objects=0, int min_num_objects_if_any=0, int max_num_objects=0);
 /** add an object value */
 	bool addObjectValue (RObject *object);
 /** Set property to only accept certain classes. If you provide an empty list, all classes will be accepted*/
@@ -287,25 +315,26 @@ public:
 /** Get current list of objects. Do not modify this list! It is the very same list, the property uses internally!
 @returns an empty list if no valid object is selected */
 	RObject::ObjectList objectList ();
-/** reimplemented from RKComponentPropertyBase. Modifier "label" returns label(s). Modifier "shortname" returns short name(s). Modifier QString::null returns full name. If no object is set, returns an empty string / variant */
+/** reimplemented from RKComponentPropertyBase. Modifier "label" returns label(s). Modifier "shortname" returns short name(s). Modifier QString () returns full name. If no object is set, returns an empty string / variant */
 	QVariant value (const QString &modifier=QString ());
 /** reimplemented from RKComponentPropertyBase to convert to RObject with current constraints
 @returns false if no such object(s) could be found or the object(s) are invalid */
 	bool setValue (const QString &value);
 /** overload of setValue() which accepts a list of names of RObjects
 @returns false if no such object(s) could be found or the object(s) are invalid */
-	bool setValue (const QStringList &values);
+	bool setValueList (const QStringList &values);
 /** reimplemented from RKComponentPropertyBase to test whether conversion to RObject is possible with current constraints */
 	bool isStringValid (const QString &value);
 /** RTTI */
 	int type () { return PropertyRObjects; };
 /** reimplemented from RKComponentPropertyBase to actually reconcile requirements with other object properties */
-	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 /** reimplemented from RKComponentPropertyBase to use special handling for object properties */
 	void governorValueChanged (RKComponentPropertyBase *property);
-/** @returns true, if the property holds the maximum number of items (or more) */
-	bool atMaxLength ();
-	void removeObjectValue (RObject* object) { objectRemoved (object); };
+	void removeAt (int index);
+	RObject* objectAt (int index) const { return object_list.value (index); };
+	int listLength () const { return (object_list.size ()); };
+	void setObjectProblemsAreErrors (bool errors);
 protected:
 /** remove an object value. reimplemented from RObjectListener::objectRemoved (). This is so we get notified if the object currently selected is removed TODO: is this effectively a duplication of setFromList? */
 	void objectRemoved (RObject *removed);
@@ -314,25 +343,23 @@ protected:
 private:
 /** check all objects currently in the list for validity. And set validity state accordingly. */
 	void validizeAll (bool silent=false);
-/** simple helper function: Check whether the the list is valid (*after* each object had been validized!), and set the valid state accordingly */
+/** simple helper function: Check whether the list is valid (*after* each object had been validized!), and set the valid state accordingly */
 	void updateValidity ();
 /** internal helper to add the object (and check it for problems).
  * @returns true, if the list was changed, false, if the object was already in the list or is 0. */
-	bool appendObject (RObject *object);
+	bool addObjectValueSilent (RObject *object);
+	bool setObjectValueSilent (RObject *object);
 /** Check any object for problems */
 	QString checkObjectProblems (RObject *object) const;
 	RObject::ObjectList object_list;
 	QMap<RObject*, QString> problems;
+	bool problems_are_errors;
 	int dims;
 	int min_length;
 	int max_length;
-	int min_num_objects;
-	int min_num_objects_if_any;
-	int max_num_objects;
 	QStringList classes;
 /** TODO: use a list of enums instead for internal purposes! */
 	QStringList types;
-	QString separator;	// always "\n". TODO: remove
 };
 
 ///////////////////////////////////////////////// Code ////////////////////////////////////////////////////////
@@ -357,7 +384,7 @@ public:
 	QVariant value (const QString &modifier=QString ());
 
 /** set the preprocess code.
-@param code The code to set. If this is QString::null, the property is seen to lack preprocess code and hence is not valid (see isValid ()). In contrast, empty strings are seen as valid */
+@param code The code to set. If this is QString (), the property is seen to lack preprocess code and hence is not valid (see isValid ()). In contrast, empty strings are seen as valid */
 	void setPreprocess (const QString &code) { preprocess_code = code; emit (valueChanged (this)); };
 /** see setPreprocess () */
 	void setCalculate (const QString &code) { calculate_code = code; emit (valueChanged (this)); };
@@ -385,7 +412,7 @@ class RKComponentPropertyConvert : public RKComponentPropertyBool {
 	Q_OBJECT
 public:
 /** constructor. Note that this property *requires* an RKComponent as parent (the one at the top of all the source properties) */
-	RKComponentPropertyConvert (RKComponent *parent);
+	explicit RKComponentPropertyConvert (RKComponent *parent);
 	~RKComponentPropertyConvert ();
 	int type () { return PropertyConvert; };
 
@@ -415,7 +442,7 @@ public:
 /** string represenation of the options in ConvertMode. For use in XMLHelper::getMultiChoiceAttribute */
 	static QString convertModeOptionString () { return ("equals;notequals;range;and;or"); };
 /** reimplemented to do raise a warning, and do nothing else. */
-	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 /** reimplemented to do raise a warning, and do nothing else. */
 	bool setValue (const QString &value);
 public slots:
@@ -449,7 +476,7 @@ public:
 /** set the sources, i.e. the properties to operate on */
 	void setSources (const QString &condition_prop, const QStringList &value_props);
 /** reimplemented to do raise a warning, and do nothing else. */
-	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString::null, bool reconcile_requirements=true);
+	void connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier=QString (), bool reconcile_requirements=true);
 /** reimplemented to do raise a warning, and do nothing else. */
 	bool setValue (const QString &value);
 
