@@ -2,8 +2,8 @@
                           rkformula  -  description
                              -------------------
     begin                : Thu Aug 12 2004
-    copyright            : (C) 2004, 2006, 2007, 2009, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004, 2006, 2007, 2009, 2011, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,11 +41,11 @@ RKFormula::RKFormula (const QDomElement &element, RKComponent *parent_component,
 
 	// create and register properties
 	fixed_factors = new RKComponentPropertyRObjects (this, true);
-	connect (fixed_factors, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (factorsChanged (RKComponentPropertyBase *)));
+	connect (fixed_factors, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (factorsChanged(RKComponentPropertyBase*)));
 	addChild ("fixed_factors", fixed_factors);
 	fixed_factors->setInternal (true);
 	dependent = new RKComponentPropertyRObjects (this, true);
-	connect (dependent, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (factorsChanged (RKComponentPropertyBase *)));
+	connect (dependent, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (factorsChanged(RKComponentPropertyBase*)));
 	addChild ("dependent", dependent);
 	dependent->setInternal (true);
 	model = new RKComponentPropertyBase (this, true);
@@ -59,13 +59,14 @@ RKFormula::RKFormula (const QDomElement &element, RKComponent *parent_component,
 	labels->setInternal (true);
 
 	// get xmlHelper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create layout
 	QVBoxLayout *vbox = new QVBoxLayout (this);
 	vbox->setContentsMargins (0, 0, 0, 0);
 
-	vbox->addWidget (new QLabel (xml->getStringAttribute (element, "label", i18n ("Specify model"), DL_INFO), this));
+	label_string = xml->i18nStringAttribute (element, "label", i18n ("Specify model"), DL_INFO);
+	vbox->addWidget (new QLabel (label_string, this));
 
 	type_selector = new QButtonGroup (this);
 	QRadioButton* button;
@@ -75,7 +76,7 @@ RKFormula::RKFormula (const QDomElement &element, RKComponent *parent_component,
 	type_selector->addButton (button, (int) MainEffects);
 	vbox->addWidget (button = new QRadioButton (i18n ("Custom Model:"), this));
 	type_selector->addButton (button, (int) Custom);
-	connect (type_selector, SIGNAL (buttonClicked (int)), this, SLOT (typeChange (int)));
+	connect (type_selector, SIGNAL (buttonClicked(int)), this, SLOT (typeChange(int)));
 
 	custom_model_widget = new QWidget (this);
 	QHBoxLayout *model_hbox = new QHBoxLayout (custom_model_widget);
@@ -89,13 +90,13 @@ RKFormula::RKFormula (const QDomElement &element, RKComponent *parent_component,
 	
 	QVBoxLayout *model_vbox = new QVBoxLayout ();
 	model_hbox->addLayout (model_vbox);
-	add_button = new QPushButton (QString::null, custom_model_widget);
+	add_button = new QPushButton (QString (), custom_model_widget);
 	add_button->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionAddRight));
-	connect (add_button, SIGNAL (clicked ()), this, SLOT (addButtonClicked ()));
+	connect (add_button, SIGNAL (clicked()), this, SLOT (addButtonClicked()));
 	model_vbox->addWidget (add_button);
-	remove_button = new QPushButton (QString::null, custom_model_widget);
+	remove_button = new QPushButton (QString (), custom_model_widget);
 	remove_button->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionRemoveLeft));
-	connect (remove_button, SIGNAL (clicked ()), this, SLOT (removeButtonClicked ()));
+	connect (remove_button, SIGNAL (clicked()), this, SLOT (removeButtonClicked()));
 	model_vbox->addWidget (remove_button);
 	level_box = new QSpinBox (custom_model_widget);
 	level_box->setRange (0, 0);
@@ -406,4 +407,14 @@ bool RKFormula::isValid () {
 	return (model_ok);
 }
 
+QStringList RKFormula::getUiLabelPair () const {
+	RK_TRACE (PLUGIN);
+
+	QStringList ret (label_string);
+	QString m = stripAccelerators (type_selector->checkedButton ()->text ());
+	if (model_type == Custom) m.append (' ' + model->value ().toString ());
+	ret.append (m);
+	return ret;
+}
+
 #include "rkformula.moc"
