@@ -2,8 +2,8 @@
                           rkinput  -  description
                              -------------------
     begin                : Sat Mar 10 2005
-    copyright            : (C) 2005, 2006, 2007, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2006, 2007, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -35,20 +35,23 @@ RKInput::RKInput (const QDomElement &element, RKComponent *parent_component, QWi
 	lineedit = 0;
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create and add property
 	addChild ("text", text = new RKComponentPropertyBase (this, false));
-	connect (text, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (textChanged (RKComponentPropertyBase *)));
+	connect (text, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (textChanged(RKComponentPropertyBase*)));
 
 	setRequired (xml->getBoolAttribute (element, "required", false, DL_INFO));
-	connect (requirednessProperty (), SIGNAL (valueChanged (RKComponentPropertyBase*)), this, SLOT (requirednessChanged (RKComponentPropertyBase*)));
+	connect (requirednessProperty (), SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (requirednessChanged(RKComponentPropertyBase*)));
 
 	// do all the layouting
 	QVBoxLayout *vbox = new QVBoxLayout (this);
 	vbox->setContentsMargins (0, 0, 0, 0);
-	QLabel *label = new QLabel (xml->getStringAttribute (element, "label", i18n ("Enter text"), DL_INFO), this);
-	vbox->addWidget (label);
+	label_string = xml->i18nStringAttribute (element, "label", i18n ("Enter text"), DL_INFO);
+	if (!label_string.isEmpty ()) {
+		QLabel *label = new QLabel (label_string, this);
+		vbox->addWidget (label);
+	}
 
 	int size = xml->getMultiChoiceAttribute (element, "size", "small;medium;large", 1, DL_INFO);
 	if (size == 2) {
@@ -59,18 +62,18 @@ RKInput::RKInput (const QDomElement &element, RKComponent *parent_component, QWi
 		textedit->setMinimumSize (250, lheight * 4 + margin);
 
 		vbox->addWidget (textedit);
-		connect (textedit, SIGNAL (textChanged ()), SLOT (textChanged ()));
+		connect (textedit, SIGNAL (textChanged()), SLOT (textChanged()));
 	} else {
 		lineedit = new QLineEdit (this);
 		vbox->addWidget (lineedit);
-		connect (lineedit, SIGNAL (textChanged (const QString&)), SLOT (textChanged (const QString&)));
+		connect (lineedit, SIGNAL (textChanged(QString)), SLOT (textChanged(QString)));
 	}
 
 	vbox->addStretch (1);		// to keep the label attached
 
 	// initialize
 	updating = false;
-	// DO NOT replace "" with QString::null, here! it is important, that this is actually an empty string, not a null string.
+	// DO NOT replace "" with QString (), here! it is important, that this is actually an empty string, not a null string.
 	text->setValue (xml->getStringAttribute (element, "initial", "", DL_INFO));
 }
 
@@ -153,4 +156,12 @@ bool RKInput::isValid () {
 	return (!(fetchStringValue (text).isEmpty ()));
 }
 
+QStringList RKInput::getUiLabelPair () const {
+	RK_TRACE (PLUGIN);
+
+	QStringList ret (label_string);
+	ret.append (text->value ().toString ());
+	return ret;
+}
+
 #include "rkinput.moc"
