@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Oct 09 2012
     copyright            : (C) 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -67,6 +67,7 @@ private:
 	bool allow_user_resize_columns;
 	int trailing_rows;
 	int trailing_columns;
+	int min_rows, min_columns;
 
 	bool isValueValid (const QString &value) const;
 	void updateAll ();
