@@ -2,8 +2,8 @@
                           rkradio.cpp  -  description
                              -------------------
     begin                : Thu Nov 7 2002
-    copyright            : (C) 2002, 2006, 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002, 2006, 2007, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -34,7 +34,7 @@ RKRadio::RKRadio (const QDomElement &element, RKComponent *parent_component, QWi
 	RK_TRACE (PLUGIN);
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create layout
 	QVBoxLayout *vbox = new QVBoxLayout (this);
@@ -42,13 +42,13 @@ RKRadio::RKRadio (const QDomElement &element, RKComponent *parent_component, QWi
 
 	// create ButtonGroup
 	group = new QButtonGroup (this);
-	group_box = new QGroupBox (xml->getStringAttribute (element, "label", i18n ("Select one:"), DL_INFO), this);
+	group_box = new QGroupBox (xml->i18nStringAttribute (element, "label", i18n ("Select one:"), DL_INFO), this);
 	new QVBoxLayout (group_box);
 
 	addOptionsAndInit (element);
 
 	vbox->addWidget (group_box);
-	connect (group, SIGNAL (buttonClicked (int)), this, SLOT (itemSelected (int)));
+	connect (group, SIGNAL (buttonClicked(int)), this, SLOT (itemSelected(int)));
 }
 
 RKRadio::~RKRadio(){
@@ -78,4 +78,12 @@ void RKRadio::setItemEnabledInGUI (int id, bool enabled) {
 	button->setEnabled (enabled);
 }
 
+QStringList RKRadio::getUiLabelPair () const {
+	RK_TRACE (PLUGIN);
+
+	QStringList ret (stripAccelerators (group_box->title ()));
+	ret.append (stripAccelerators (group->checkedButton ()->text ()));
+	return ret;
+}
+
 #include "rkradio.moc"
