@@ -2,8 +2,8 @@
                           rkstandardcomponent  -  description
                              -------------------
     begin                : Sun Feb 19 2006
-    copyright            : (C) 2006, 2007, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2006, 2007, 2009, 2010, 2011, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,6 +31,7 @@
 #include <khbox.h>
 
 #include "rkstandardcomponentgui.h"
+#include "rkcomponentmap.h"
 #include "../scriptbackends/qtscriptbackend.h"
 #include "../scriptbackends/simplebackend.h"
 #include "../scriptbackends/rkcomponentscripting.h"
@@ -56,22 +57,24 @@
 #include "rktabpage.h"
 #include "rkpluginframe.h"
 #include "rkoptionset.h"
+#include "rkvalueselector.h"
 
 #include "../rkglobals.h"
 
 #include "../debug.h"
 
 
-RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget *parent_widget, const QString &filename, RKComponentHandle *handle) : RKComponent (parent_component, parent_widget) {
+RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget *parent_widget, const QString &filename, const QString &id) : RKComponent (parent_component, parent_widget) {
 	RK_TRACE (PLUGIN);
 
 	RKStandardComponent::filename = filename;
-	RKStandardComponent::handle = handle;
+	RKStandardComponent::id = id;
 	command_chain = 0;
 	backend = 0;
 	scripting = 0;
 	gui = 0;
 	wizard = 0;
+	xml = 0;
 	created = false;
 	killed = false;
 	addChild ("code", code = new RKComponentPropertyCode (this, true));		// do not change this name!
@@ -88,9 +91,9 @@ RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget
 	addChild ("current_dataframe", current_dataframe_property);
 
 	// open the main description file for parsing
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
-	QDomElement doc_element = xml->openXMLFile (filename, DL_ERROR);
-	if (xml->highestError () >= DL_ERROR) {
+	XMLHelper* xml = getXmlHelper ();
+	QDomElement doc_element = xml->openXMLFile (DL_ERROR);
+	if (doc_element.isNull ()) {
 		KMessageBox::error (this, i18n ("There has been an error while trying to parse the description of this plugin ('%1'). Please refer to stdout for details.", filename), i18n ("Could not create plugin"));
 		kill ();
 		return;
@@ -101,18 +104,18 @@ RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget
 	if (element.hasAttribute ("file")) {
 		QString dummy = QFileInfo (filename).path() + '/' + xml->getStringAttribute (element, "file", "code.js", DL_WARNING);
 
-		backend = new QtScriptBackend (dummy);
+		backend = new QtScriptBackend (dummy, xml->messageCatalog ());
 	} else {
 		SimpleBackend *back = new SimpleBackend ();
-		back->setPreprocessTemplate (xml->getStringAttribute (element, "preprocess", QString::null, DL_INFO));
-		back->setPrintoutTemplate (xml->getStringAttribute (element, "printout", QString::null, DL_INFO));
-		back->setCalculateTemplate (xml->getStringAttribute (element, "calculate", QString::null, DL_INFO));
-		back->setPreviewTemplate (xml->getStringAttribute (element, "preview", QString::null, DL_INFO));
+		back->setPreprocessTemplate (xml->getStringAttribute (element, "preprocess", QString (), DL_INFO));
+		back->setPrintoutTemplate (xml->getStringAttribute (element, "printout", QString (), DL_INFO));
+		back->setCalculateTemplate (xml->getStringAttribute (element, "calculate", QString (), DL_INFO));
+		back->setPreviewTemplate (xml->getStringAttribute (element, "preview", QString (), DL_INFO));
 		backend = back;
 	}
-	connect (backend, SIGNAL (idle ()), this, SLOT (backendIdle ()));
-	connect (backend, SIGNAL (requestValue (const QString&, const int)), this, SLOT (getValue (const QString&, const int)));
-	connect (backend, SIGNAL (haveError ()), this, SLOT (kill ()));
+	connect (backend, SIGNAL (idle()), this, SLOT (backendIdle()));
+	connect (backend, SIGNAL (requestValue(QString,int)), this, SLOT (getValue(QString,int)));
+	connect (backend, SIGNAL (haveError()), this, SLOT (kill()));
 	if (!backend->initialize (code, parent_component == 0)) return;
 
 	// check for existence of help file
@@ -169,7 +172,8 @@ RKStandardComponent::~RKStandardComponent () {
 	RK_TRACE (PLUGIN);
 
 	if (gui) delete gui;	// NOTE: *NOT* using gui->deleteLater (). Destructing the GUI immediately is necessary to get rid of child components, immediately. Otherwise these could try to access their (destroyed) parent, e.g. if they have a timer running that gets triggered before the deletion event arrives.
-	backend->destroy ();	// it will self-destruct, when it has closed the process.
+	if (backend) backend->destroy ();	// it will self-destruct, when it has closed the process.
+	delete xml;
 }
 
 void RKStandardComponent::kill () {
@@ -188,7 +192,7 @@ RKComponentScriptingProxy* RKStandardComponent::scriptingProxy () {
 
 	if (!scripting) {
 		scripting = new RKComponentScriptingProxy (this);
-		connect (scripting, SIGNAL (haveError ()), this, SLOT (kill ()));
+		connect (scripting, SIGNAL (haveError()), this, SLOT (kill()));
 	}
 	return scripting;
 }
@@ -218,10 +222,20 @@ void RKStandardComponent::setCaption (const QString &caption) {
 	gui->setWindowTitle (caption);
 }
 
+XMLHelper* RKStandardComponent::getXmlHelper () {
+	RK_TRACE (PLUGIN);
+
+	if (!xml) {
+		RKComponentHandle *handle = RKComponentMap::getComponentHandle (id);
+		xml = new XMLHelper (filename, handle ? handle->messageCatalog () : 0);
+	}
+	return xml;
+}
+
 bool RKStandardComponent::createTopLevel (const QDomElement &doc_element, int force_mode, bool enslaved) {
 	RK_TRACE (PLUGIN);
 
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
+	XMLHelper* xml = getXmlHelper ();
 	bool build_wizard = false;
 	QDomElement dialog_element;
 	QDomElement wizard_element;
@@ -276,8 +290,8 @@ void RKStandardComponent::switchInterface () {
 	RK_ASSERT (gui);		// this should only ever happen on top level
 
 	// open the main description file for parsing (again)
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
-	QDomElement doc_element = xml->openXMLFile (filename, DL_ERROR);
+	XMLHelper* xml = getXmlHelper ();
+	QDomElement doc_element = xml->openXMLFile (DL_ERROR);
 	int force_mode = 2;
 	if (isWizardish ()) force_mode = 1;
 
@@ -323,15 +337,15 @@ void RKStandardComponent::discard () {
 void RKStandardComponent::buildAndInitialize (const QDomElement &doc_element, const QDomElement &gui_element, QWidget *parent_widget, bool build_wizard, bool enslaved) {
 	RK_TRACE (PLUGIN);
 
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
+	XMLHelper* xml = getXmlHelper ();
 
 	// create a builder
 	RKComponentBuilder *builder = new RKComponentBuilder (this, doc_element);
 
 	// go
-	builder->buildElement (gui_element, parent_widget, build_wizard);
-	builder->parseLogic (xml->getChildElement (doc_element, "logic", DL_INFO));
-	setCaption (xml->getStringAttribute (gui_element, "label", QString::null, DL_WARNING));
+	builder->buildElement (gui_element, *xml, parent_widget, build_wizard);
+	builder->parseLogic (xml->getChildElement (doc_element, "logic", DL_INFO), *xml);
+	setCaption (xml->i18nStringAttribute (gui_element, "label", QString (), DL_WARNING));
 
 	// initialize
 	builder->makeConnections ();
@@ -342,7 +356,7 @@ void RKStandardComponent::buildAndInitialize (const QDomElement &doc_element, co
 	if (gui && (!enslaved)) {
 		// somehow, when switching the interface, and we show before the old GUI has been fully deleted (it is deleted via deleteLater (), then there may be strange graphical glitches until the GUI is first redrawn completely.
 		// Likely a difficult bug in Qt. Delaying the show until the next event loop solves the problem.
-		QTimer::singleShot (0, gui, SLOT (show ()));
+		QTimer::singleShot (0, gui, SLOT (show()));
 	}
 	changed ();
 	standardInitializationComplete ();
@@ -372,7 +386,7 @@ void RKStandardComponent::close () {
 	RK_TRACE (PLUGIN);
 
 	if (gui && (!parentComponent ())) {
-		QTimer::singleShot (0, gui, SLOT (close ()));
+		QTimer::singleShot (0, gui, SLOT (close()));
 	} else {
 		RK_ASSERT (false);
 	}
@@ -387,7 +401,7 @@ void RKStandardComponent::changed () {
 	// don't trigger update twice
 	if (!update_pending) {
 		update_pending = true;
-		QTimer::singleShot (0, this, SLOT (handleChange ()));
+		QTimer::singleShot (0, this, SLOT (handleChange()));
 	}
 }
 
@@ -497,8 +511,6 @@ void RKStandardComponent::addComponentToCurrentPage (RKComponent *component) {
 
 /////////////////////////////////////// RKComponentBuilder /////////////////////////////////////////
 
-#include "rkcomponentmap.h"
-
 #include <qpushbutton.h>
 
 RKComponentBuilder::RKComponentBuilder (RKComponent *parent_component, const QDomElement &document_element) {
@@ -514,19 +526,18 @@ RKComponentBuilder::~RKComponentBuilder () {
 	RK_TRACE (PLUGIN);
 }
 
-QDomElement RKComponentBuilder::doElementCopy (const QString id, const QDomElement &copy) {
+QDomElement RKComponentBuilder::doElementCopy (const QString id, XMLHelper &xml, const QDomElement &copy) {
 	RK_TRACE (PLUGIN);
 
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
 	QDomElement res;
 
 	if (id.isEmpty ()) {
-		xml->displayError (&copy, "no id given for copy element", DL_ERROR, DL_ERROR);
+		xml.displayError (&copy, "no id given for copy element", DL_ERROR, DL_ERROR);
 		return res;	// null
 	}
 
 	// find matching element to copy from
-	XMLChildList candidates = xml->findElementsWithAttribute (doc_elem, "id", id, true, DL_ERROR);
+	XMLChildList candidates = xml.findElementsWithAttribute (doc_elem, "id", id, true, DL_ERROR);
 	XMLChildList::const_iterator it;
 	for (it = candidates.constBegin (); it != candidates.constEnd (); ++it) {
 		if ((*it).tagName () == QLatin1String ("copy")) continue;
@@ -534,7 +545,7 @@ QDomElement RKComponentBuilder::doElementCopy (const QString id, const QDomEleme
 		break;
 	}
 	if (res.isNull ()) {
-		xml->displayError (&copy, "no matching element found to copy from", DL_ERROR, DL_ERROR);
+		xml.displayError (&copy, "no matching element found to copy from", DL_ERROR, DL_ERROR);
 		return res;
 	}
 
@@ -550,20 +561,19 @@ QDomElement RKComponentBuilder::doElementCopy (const QString id, const QDomEleme
 	return res;
 }
 
-void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *parent_widget, bool allow_pages) {
+void RKComponentBuilder::buildElement (const QDomElement &element, XMLHelper &xml, QWidget *parent_widget, bool allow_pages) {
 	RK_TRACE (PLUGIN);
 
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
-	XMLChildList children = xml->getChildElements (element, QString::null, DL_ERROR);
+	XMLChildList children = xml.getChildElements (element, QString (), DL_ERROR);
 	
 	XMLChildList::const_iterator it;
 	for (it = children.constBegin (); it != children.constEnd (); ++it) {
 		RKComponent *widget = 0;
 		QDomElement e = *it;		// shorthand
-		QString id = xml->getStringAttribute (e, "id", QString::null, DL_INFO);
+		QString id = xml.getStringAttribute (e, "id", QString (), DL_INFO);
 
 		if (e.tagName () == QLatin1String ("copy")) {
-			e = doElementCopy (id, e);
+			e = doElementCopy (id, xml, e);
 		}	// no else, here. e may be changed to some entirely different element, now.
 
 		if (allow_pages && (e.tagName () == QLatin1String ("page"))) {
@@ -571,14 +581,14 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 			QVBoxLayout *layout = new QVBoxLayout (widget);
 			KVBox *box = new KVBox (widget);
 			layout->addWidget (box);
-			buildElement (e, box, false);
+			buildElement (e, xml, box, false);
 		} else if (e.tagName () == QLatin1String ("row")) {
 			widget = new RKComponent (component (), parent_widget);		// wrapping this (and column, below) inside an RKComponent has the benefit, that it can have an id, and hence can be set to visibile/hidden, enabled/disabled
 			QVBoxLayout *layout = new QVBoxLayout (widget);
 			layout->setContentsMargins (0, 0, 0, 0);
 			KHBox *box = new KHBox (widget);
 			layout->addWidget (box);
-			buildElement (e, box, false);
+			buildElement (e, xml, box, false);
 		} else if (e.tagName () == QLatin1String ("stretch")) {
 			QWidget *stretch = new QWidget (parent_widget);
 			stretch->setSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
@@ -591,11 +601,11 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 			layout->setContentsMargins (0, 0, 0, 0);
 			KVBox *box = new KVBox (widget);
 			layout->addWidget (box);
-			buildElement (e, box, false);
+			buildElement (e, xml, box, false);
 		} else if (e.tagName () == QLatin1String ("frame")) {
 			RKPluginFrame *frame = new RKPluginFrame (e, component (), parent_widget);
 			widget = frame;
-			buildElement (e, frame->getPage (), false);
+			buildElement (e, xml, frame->getPage (), false);
 		} else if (e.tagName () == QLatin1String ("tabbook")) {
 			QTabWidget *tabbook = new QTabWidget (parent_widget);
 			QDomNodeList tabs = e.childNodes ();
@@ -603,8 +613,8 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 				QDomElement tab_e = tabs.item (t).toElement ();
 				if (tab_e.tagName () == QLatin1String ("tab")) {
 					RKTabPage *tabpage = new RKTabPage (tab_e, component (), tabbook);
-					buildElement (tab_e, tabpage->getPage (), false);
-					QString tab_id = xml->getStringAttribute (tab_e, "id", QString::null, DL_INFO);
+					buildElement (tab_e, xml, tabpage->getPage (), false);
+					QString tab_id = xml.getStringAttribute (tab_e, "id", QString (), DL_INFO);
 					if (!tab_id.isNull ()) {
 						parent->addChild (tab_id, tabpage);
 					}
@@ -612,13 +622,17 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 			}
 		} else if (e.tagName () == QLatin1String ("varselector")) {
 			widget = new RKVarSelector (e, component (), parent_widget);
-		} else if (e.tagName () == QLatin1String ("varslot")) {
+		} else if ((e.tagName () == QLatin1String ("varslot")) || (e.tagName () == QLatin1String ("valueslot"))) {
 			widget = new RKVarSlot (e, component (), parent_widget);
-			addConnection (id, "source", xml->getStringAttribute (e, "source", "#noid#", DL_INFO), "selected", false, e);
+			QString source = xml.getStringAttribute (e, "source_property", QString (), DL_INFO);
+			if (source.isEmpty ()) source = xml.getStringAttribute (e, "source", "#noid#", DL_WARNING) + ".selected";
+			addConnection (id, "source", source, QString (), false, e);
+		} else if ((e.tagName () == QLatin1String ("valueselector")) || (e.tagName () == QLatin1String ("select"))) {
+			widget = new RKValueSelector (e, component (), parent_widget);
 		} else if (e.tagName () == QLatin1String ("formula")) {
 			widget = new RKFormula (e, component (), parent_widget);
-			addConnection (id, "dependent", xml->getStringAttribute (e, "dependent", "#noid#", DL_INFO), "available", false, e);
-			addConnection (id, "fixed_factors", xml->getStringAttribute (e, "fixed_factors", "#noid#", DL_INFO), "available", false, e);
+			addConnection (id, "dependent", xml.getStringAttribute (e, "dependent", "#noid#", DL_INFO), "available", false, e);
+			addConnection (id, "fixed_factors", xml.getStringAttribute (e, "fixed_factors", "#noid#", DL_INFO), "available", false, e);
 		} else if (e.tagName () == QLatin1String ("radio")) {
 			widget = new RKRadio (e, component (), parent_widget);
 		} else if (e.tagName () == QLatin1String ("dropdown")) {
@@ -640,42 +654,35 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 		} else if (e.tagName () == QLatin1String ("saveobject")) {
 			widget = new RKPluginSaveObject (e, component (), parent_widget);
 		} else if (e.tagName () == QLatin1String ("embed")) {
-			QString component_id = xml->getStringAttribute (e, "component", QString::null, DL_ERROR);
+			QString component_id = xml.getStringAttribute (e, "component", QString (), DL_ERROR);
 			RKComponentHandle *handle = RKComponentMap::getComponentHandle (component_id);
 			if (handle) {
-				if (xml->getBoolAttribute (e, "as_button", false, DL_INFO)) {
+				if (xml.getBoolAttribute (e, "as_button", false, DL_INFO)) {
 					RKStandardComponent* swidget = handle->invoke (component (), 0);
 					widget = swidget;
-					QString dummy = xml->getStringAttribute (e, "label", "Options", DL_WARNING);
+					QString dummy = xml.i18nStringAttribute (e, "label", i18n ("Options"), DL_WARNING);
 					swidget->setCaption (dummy);
 // TODO we should use a specialized pushbutton, that changes color if the corresponding component is dissatisfied!
 					QPushButton *button = new QPushButton (dummy, parent_widget);
-					component ()->connect (button, SIGNAL (clicked ()), widget, SLOT (showGUI ()));
+					component ()->connect (button, SIGNAL (clicked()), widget, SLOT (showGUI()));
 				} else {
 					widget = handle->invoke (component (), parent_widget);
 				}
 			} else {
-				xml->displayError (&e, QString ("Could not embed component '%1'. Not found").arg (component_id), DL_ERROR);
+				xml.displayError (&e, QString ("Could not embed component '%1'. Not found").arg (component_id), DL_ERROR);
 			}
 		} else if (e.tagName () == QLatin1String ("optionset")) {
 			widget = new RKOptionSet (e, component (), parent_widget);
 		} else if (e.tagName () == QLatin1String ("optiondisplay")) {
-			RKComponent *set = component ()->parentComponent ();
-			if (set->type () == RKComponentBase::ComponentOptionSet) {
-				widget = static_cast<RKOptionSet *> (set)->createDisplay (xml->getBoolAttribute (e, "index", true, DL_INFO), parent_widget);
-			} else {
-				xml->displayError (&e, QString ("optiondisplay element is not allowed outside of an optionset"), DL_ERROR);
-			}
-		} else if (e.tagName () == QLatin1String ("scriptable")) {
-			widget = new RKComponent (component (), parent_widget);
-			QVBoxLayout *layout = new QVBoxLayout (widget);
-			layout->setContentsMargins (0, 0, 0, 0);
-			KVBox *box = new KVBox (widget);
-			layout->addWidget (box);
-			QString id_adjust;
-			parent->standardComponent (&id_adjust)->scriptingProxy ()->addScriptableWidget (id_adjust + id, widget);
+			// TODO: Remove after grace period. Last release to support optiondisplay: 0.6.3
+			xml.displayError (&e, QString ("<optiondisplay> element is obsolete. Ignoring."), DL_WARNING);
+/*		} else if (e.tagName () == QLatin1String ("scriptable")) {
+ * TODO: We used to have some purely experimental code, here, to support fully custom elements (scripted via Kross->Forms). We will want 
+ * to have something like that, eventually. After porting to KF5, Qt5, and thus dropping legacy support, the natural way to add this will
+ * be QML.
+ */
 		} else {
-			xml->displayError (&e, QString ("Invalid tagname '%1'").arg (e.tagName ()), DL_ERROR);
+			xml.displayError (&e, QString ("Invalid tagname '%1'").arg (e.tagName ()), DL_ERROR);
 		}
 
 		if (widget && (!(id.isNull ()))) {
@@ -684,112 +691,101 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 	}
 }
 
-void RKComponentBuilder::parseLogic (const QDomElement &element, bool allow_script_tag) {
+void RKComponentBuilder::parseLogic (const QDomElement &element, XMLHelper &xml, bool allow_script_tag) {
 	RK_TRACE (PLUGIN);
 
 	if (element.isNull ()) return;
 
-	// find connect elements
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
-	XMLChildList children = xml->getChildElements (element, "connect", DL_INFO);
-
-	XMLChildList::const_iterator it;
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		addConnection (xml->getStringAttribute (*it, "client", "#noid#", DL_WARNING), QString::null, xml->getStringAttribute (*it, "governor", "#noid#", DL_WARNING), QString::null, xml->getBoolAttribute (*it, "reconcile", false, DL_INFO), element);
-	}
-
-	// find initialize elements
-	children = xml->getChildElements (element, "set", DL_INFO);
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		initial_values.insert (xml->getStringAttribute (*it, "id", "#noid#", DL_WARNING), xml->getStringAttribute (*it, "to", "false", DL_WARNING));
-	}
-	children = xml->getChildElements (element, "dependency_check", DL_INFO);
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		RKComponentPropertyBool *dep = new RKComponentPropertyBool (component (), false);
-		dep->setInternal (true);
-		dep->setBoolValue (RKComponentDependency::isRKWardVersionCompatible (*it) && RKComponentDependency::isRVersionCompatible (*it));
-		component ()->addChild (xml->getStringAttribute (*it, "id", "#noid#", DL_WARNING), dep);
-	}
-
-	// find outside elements
-	children = xml->getChildElements (element, "external", DL_INFO);
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		QString id = xml->getStringAttribute (*it, "id", "#noid#", DL_WARNING);
-		RKComponentPropertyBase *prop = new RKComponentPropertyBase (component (), xml->getBoolAttribute (*it, "required", false, DL_INFO));
-		component ()->addChild (id, prop);
-		prop->setInternal (true);
-		component ()->connect (prop, SIGNAL (valueChanged (RKComponentPropertyBase *)), component (), SLOT (outsideValueChanged (RKComponentPropertyBase *)));
-
-		QString dummy = xml->getStringAttribute (*it, "default", QString::null, DL_INFO);
-		if (!dummy.isNull ()) {
-			initial_values.insert (id, dummy);
-		}
-		// TODO add more options
-	}
-
-	// find convert elements
 	QMap<RKComponentPropertyBase*, QStringList> switch_convert_sources;
-	children = xml->getChildElements (element, "convert", DL_INFO);
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		RKComponentPropertyConvert *convert = new RKComponentPropertyConvert (component ());
-		convert->setInternal (true);
-		QString id = xml->getStringAttribute (*it, "id", "#noid#", DL_WARNING);
-		int mode = xml->getMultiChoiceAttribute (*it, "mode", convert->convertModeOptionString (), 0, DL_WARNING);
-		convert->setMode ((RKComponentPropertyConvert::ConvertMode) mode);
-		if ((mode == RKComponentPropertyConvert::Equals) || (mode == RKComponentPropertyConvert::NotEquals)) {
-			convert->setStandard (xml->getStringAttribute (*it, "standard", QString::null, DL_WARNING));
-		} else if (mode == RKComponentPropertyConvert::Range) {
-			convert->setRange (xml->getDoubleAttribute (*it, "min", -FLT_MAX, DL_INFO), xml->getDoubleAttribute (*it, "max", FLT_MAX, DL_INFO));
-		}
-		switch_convert_sources.insert (convert, xml->getStringAttribute (*it, "sources", QString::null, DL_WARNING).split (';'));
-		convert->setRequireTrue (xml->getBoolAttribute (*it, "require_true", false, DL_INFO));
-		component ()->addChild (id, convert);
-	}
 
-	// find switch elements
-	children = xml->getChildElements (element, "switch", DL_INFO);
-	for (it = children.constBegin (); it != children.constEnd (); ++it) {
-		QDomElement t = xml->getChildElement (*it, "true", DL_INFO);
-		QDomElement f = xml->getChildElement (*it, "false", DL_INFO);
-		if (t.isNull () != f.isNull ()) {
-			xml->displayError (&(*it), "One of <true> / <false> was provided for boolean <switch>, but not the other. Skipping switch.", DL_ERROR);
-			continue;
-		}
+	const XMLChildList children = xml.getChildElements (element, QString (), DL_ERROR);
+	for (int i = 0; i < children.size (); ++i) {
+		const QDomElement &cel = children[i];
+		const QString tagName = cel.tagName ();
+		if (tagName == QLatin1String ("connect")) {
+			addConnection (xml.getStringAttribute (cel, "client", "#noid#", DL_WARNING), QString (), xml.getStringAttribute (cel, "governor", "#noid#", DL_WARNING), QString (), xml.getBoolAttribute (cel, "reconcile", false, DL_INFO), element);
+		} else if (tagName == QLatin1String ("dependency_check")) {
+			RKComponentPropertyBool *dep = new RKComponentPropertyBool (component (), false);
+			dep->setInternal (true);
+			dep->setBoolValue (RKComponentDependency::isRKWardVersionCompatible (cel) && RKComponentDependency::isRVersionCompatible (cel));
+			component ()->addChild (xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING), dep);
+		} else if (tagName == QLatin1String ("external")) {
+			QString id = xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING);
+			RKComponentPropertyBase *prop = new RKComponentPropertyBase (component (), xml.getBoolAttribute (cel, "required", false, DL_INFO));
+			component ()->addChild (id, prop);
+			prop->setInternal (true);
+			component ()->connect (prop, SIGNAL (valueChanged(RKComponentPropertyBase*)), component (), SLOT (outsideValueChanged(RKComponentPropertyBase*)));
 
-		XMLChildList case_elems = xml->getChildElements (*it, "case", DL_INFO);
-		QDomElement default_elem = xml->getChildElement (*it, "default", DL_INFO);
-		if (!default_elem.isNull ()) case_elems.append (default_elem);
-
-		if (t.isNull ()) {
-			if (case_elems.isEmpty ()) {
-				xml->displayError (&(*it), "Neither <true> / <false> nor <case> / <default> were provided. Skipping switch.", DL_ERROR);
+			QString dummy = xml.getStringAttribute (cel, "default", QString (), DL_INFO);
+			if (!dummy.isNull ()) {
+				initial_values.insert (id, dummy);
+			}
+		} else if (tagName == QLatin1String ("set")) {
+			// NOTE: It is by design that if there are several initializations for a single id, the latest one takes precedence. Useful in some cases of inclusion.
+			initial_values.insert (xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING), xml.getStringAttribute (cel, "to", "false", DL_WARNING));
+		} else if (tagName == QLatin1String ("i18n")) {
+			QString id = xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING);
+			RKComponentPropertyBase *prop = new RKComponentPropertyBase (component (), false);
+			component ()->addChild (id, prop);
+			prop->setInternal (true);
+			initial_values.insert (id, xml.i18nStringAttribute (cel, "label", QString (), DL_WARNING));
+		} else if (tagName == QLatin1String ("convert")) {
+			RKComponentPropertyConvert *convert = new RKComponentPropertyConvert (component ());
+			convert->setInternal (true);
+			QString id = xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING);
+			int mode = xml.getMultiChoiceAttribute (cel, "mode", convert->convertModeOptionString (), 0, DL_WARNING);
+			convert->setMode ((RKComponentPropertyConvert::ConvertMode) mode);
+			if ((mode == RKComponentPropertyConvert::Equals) || (mode == RKComponentPropertyConvert::NotEquals)) {
+				convert->setStandard (xml.getStringAttribute (cel, "standard", QString (), DL_WARNING));
+			} else if (mode == RKComponentPropertyConvert::Range) {
+				convert->setRange (xml.getDoubleAttribute (cel, "min", -FLT_MAX, DL_INFO), xml.getDoubleAttribute (cel, "max", FLT_MAX, DL_INFO));
+			}
+			switch_convert_sources.insert (convert, xml.getStringAttribute (cel, "sources", QString (), DL_WARNING).split (';'));
+			convert->setRequireTrue (xml.getBoolAttribute (cel, "require_true", false, DL_INFO));
+			component ()->addChild (id, convert);
+		} else if (tagName == QLatin1String ("switch")) {
+			QDomElement t = xml.getChildElement (cel, "true", DL_INFO);
+			QDomElement f = xml.getChildElement (cel, "false", DL_INFO);
+			if (t.isNull () != f.isNull ()) {
+				xml.displayError (&(cel), "One of <true> / <false> was provided for boolean <switch>, but not the other. Skipping switch.", DL_ERROR);
 				continue;
 			}
-		} else {
-			if (!case_elems.isEmpty ()) {
-				xml->displayError (&(*it), "One <true> / <false> *or* <case> / <default> may be provided a <switch>. Proceeding with boolean switch.", DL_ERROR);
-				case_elems.clear ();
+
+			XMLChildList case_elems = xml.getChildElements (cel, "case", DL_INFO);
+			QDomElement default_elem = xml.getChildElement (cel, "default", DL_INFO);
+			if (!default_elem.isNull ()) case_elems.append (default_elem);
+
+			if (t.isNull ()) {
+				if (case_elems.isEmpty ()) {
+					xml.displayError (&cel, "Neither <true> / <false> nor <case> / <default> were provided. Skipping switch.", DL_ERROR);
+					continue;
+				}
+			} else {
+				if (!case_elems.isEmpty ()) {
+					xml.displayError (&cel, "One <true> / <false> *or* <case> / <default> may be provided a <switch>. Proceeding with boolean switch.", DL_ERROR);
+					case_elems.clear ();
+				}
+				case_elems.append (f);
+				case_elems.append (t);
 			}
-			case_elems.append (f);
-			case_elems.append (t);
+
+			QStringList def_strings;
+			QStringList standards;
+			QStringList sources;
+			sources.append (xml.getStringAttribute (cel, "condition", QString (), DL_ERROR));	// store condition prop as first "source"
+
+			for (XMLChildList::const_iterator cit = case_elems.constBegin (); cit != case_elems.constEnd (); ++cit) {
+				def_strings.append (xml.getStringAttribute (*cit, "fixed_value", QString (), DL_INFO));
+				sources.append (xml.getStringAttribute (*cit, "dynamic_value", QString (), DL_INFO));
+				if ((*cit).tagName () == "case") standards.append (xml.getStringAttribute (*cit, "standard", QString (), DL_WARNING));
+			}
+
+			QString id = xml.getStringAttribute (cel, "id", "#noid#", DL_WARNING);
+			RKComponentPropertySwitch *switchel = new RKComponentPropertySwitch (component (), def_strings, standards);
+			switchel->setInternal (true);
+			switch_convert_sources.insert (switchel, sources);
+			component ()->addChild (id, switchel);
 		}
-
-		QStringList def_strings;
-		QStringList standards;
-		QStringList sources;
-		sources.append (xml->getStringAttribute (*it, "condition", QString (), DL_ERROR));	// store condition prop as first "source"
-
-		for (XMLChildList::const_iterator cit = case_elems.constBegin (); cit != case_elems.constEnd (); ++cit) {
-			def_strings.append (xml->getStringAttribute (*cit, "fixed_value", QString (), DL_INFO));
-			sources.append (xml->getStringAttribute (*cit, "dynamic_value", QString (), DL_INFO));
-			if ((*cit).tagName () == "case") standards.append (xml->getStringAttribute (*cit, "standard", QString (), DL_WARNING));
-		}
-
-		QString id = xml->getStringAttribute (*it, "id", "#noid#", DL_WARNING);
-		RKComponentPropertySwitch *switchel = new RKComponentPropertySwitch (component (), def_strings, standards);
-		switchel->setInternal (true);
-		switch_convert_sources.insert (switchel, sources);
-		component ()->addChild (id, switchel);
 	}
 
 	// resolve source properties for switch and convert elements, *after* all properties have been created
@@ -807,13 +803,13 @@ void RKComponentBuilder::parseLogic (const QDomElement &element, bool allow_scri
 		}
 	}
 
-	QDomElement e = xml->getChildElement (element, "script", DL_INFO);
+	QDomElement e = xml.getChildElement (element, "script", DL_INFO);
 	if (!e.isNull () && allow_script_tag) {
-		QString file = xml->getStringAttribute (e, "file", QString (), DL_INFO);
+		QString file = xml.getStringAttribute (e, "file", QString (), DL_INFO);
 		QString inline_command = e.text ();
 		parent->standardComponent ()->scriptingProxy ()->initialize (file, inline_command);
 	} else if (!e.isNull ()) {
-		xml->displayError (&e, "<script> element is not allowed inside this <logic> section.", DL_ERROR);
+		xml.displayError (&e, "<script> element is not allowed inside this <logic> section.", DL_ERROR);
 	}
 }
 
@@ -835,7 +831,7 @@ void RKComponentBuilder::makeConnections () {
 
 	component ()->setPropertyValues (&initial_values);
 
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = component ()->xmlHelper ();
 
 	for (ConnectionList::const_iterator it = connection_list.constBegin (); it != connection_list.constEnd (); ++it) {
 		RK_DEBUG (PLUGIN, DL_DEBUG, "Connecting '%s' to '%s'", (*it).client_property.toLatin1 ().data (), (*it).governor_property.toLatin1 ().data ());
