@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Mar 19 2006
     copyright            : (C) 2006, 2007, 2009, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -145,7 +145,7 @@ void RKStandardComponentGUI::showEvent (QShowEvent *e) {
 
 	QWidget::showEvent (e);
 
-	// HACK: Workaround for this issue (caused by a mysterious Qt bug, apparently): http://www.mail-archive.com/rkward-devel@lists.sourceforge.net/msg01340.html
+	// HACK: Workaround for this issue (caused by a mysterious Qt bug, apparently): https://mail.kde.org/pipermail/rkward-devel/2011-June/002831.html
 	QSize min = minimumSize ();
 	if ((min.width () < 50) || (min.height () < 50)) min = sizeHint ();
 	setMinimumSize (min.expandedTo (QSize (50, 50)));
@@ -312,10 +312,10 @@ void RKStandardComponentWizard::createWizard (bool switchable) {
 	if (enslaved) cancel_button->hide ();
 	help_button = new QPushButton (i18n ("Help"), this);
 	main_grid->addWidget (help_button, 2, 1, Qt::AlignLeft);
-	prev_button = new QPushButton (QString::null, this);
+	prev_button = new QPushButton (QString (), this);
 	prev_button->setEnabled (false);
 	main_grid->addWidget (prev_button, 2, 2, Qt::AlignRight);
-	next_button = new QPushButton (QString::null, this);
+	next_button = new QPushButton (QString (), this);
 	main_grid->addWidget (next_button, 2, 3, Qt::AlignRight);
 	connect (next_button, SIGNAL (clicked()), this, SLOT (next()));
 	connect (prev_button, SIGNAL (clicked()), this, SLOT (prev()));
