@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Apr 5 2006
     copyright            : (C) 2006, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -30,8 +30,8 @@
 RKTabPage::RKTabPage (const QDomElement &element, RKComponent *parent_component, QTabWidget *parent_widget) : RKComponent (parent_component, parent_widget) {
 	RK_TRACE (PLUGIN);
 
-	XMLHelper* xml = XMLHelper::getStaticHelper ();
-	label = xml->getStringAttribute (element, "label", QString::null, DL_WARNING);
+	XMLHelper* xml = parent_component->xmlHelper ();
+	label = xml->i18nStringAttribute (element, "label", QString (), DL_WARNING);
 
 	QVBoxLayout *layout = new QVBoxLayout (this);
 	page = new KVBox (this);
@@ -44,8 +44,8 @@ RKTabPage::RKTabPage (const QDomElement &element, RKComponent *parent_component,
 	page->setSizePolicy (QSizePolicy (QSizePolicy::Expanding, QSizePolicy::Expanding));
 
 	inserted = true;
-	connect (visibility_property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (visibleEnabledChanged (RKComponentPropertyBase *)));
-	connect (enabledness_property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (visibleEnabledChanged (RKComponentPropertyBase *)));
+	connect (visibility_property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (visibleEnabledChanged(RKComponentPropertyBase*)));
+	connect (enabledness_property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (visibleEnabledChanged(RKComponentPropertyBase*)));
 }
 
 RKTabPage::~RKTabPage () {
@@ -58,7 +58,9 @@ void RKTabPage::visibleEnabledChanged (RKComponentPropertyBase *property) {
 	if (property == visibility_property) {
 		if (visibility_property->boolValue ()) {
 			if (!inserted) {
-#warning this may not be reliable, if an earlier page is invisible as well
+#ifdef __GNUC__
+#	warning this may not be reliable, if an earlier page is invisible as well
+#endif
 				tabbook->insertTab (index, this, label);
 				inserted = true;
 			}
