@@ -2,8 +2,8 @@
                           rktext.cpp  -  description
                              -------------------
     begin                : Sun Nov 10 2002
-    copyright            : (C) 2002, 2006, 2007, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002, 2006, 2007, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,7 +31,7 @@ RKText::RKText (const QDomElement &element, RKComponent *parent_component, QWidg
 	RK_TRACE (PLUGIN);
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create layout and label
 	QVBoxLayout *vbox = new QVBoxLayout (this);
@@ -41,10 +41,6 @@ RKText::RKText (const QDomElement &element, RKComponent *parent_component, QWidg
 	label->setWordWrap (true);
 	vbox->addWidget (label);
 
-	QString initial_text = xml->getRawContents (element, DL_ERROR);
-	if (!initial_text.isEmpty ()) initial_text = "<p>" + initial_text + "</p>";
-	initial_text.replace ("\n\n", "</p>\n<p>");
-
 	int type = xml->getMultiChoiceAttribute (element, "type", "normal;warning;error", 0, DL_INFO);
 	if (type != 0) {
 		QFont font = label->font ();
@@ -60,13 +56,12 @@ RKText::RKText (const QDomElement &element, RKComponent *parent_component, QWidg
 		label->setFont (font);
 	}
 
-	// strip final newline
-	initial_text.truncate (initial_text.length () -1);
+	QString initial_text = xml->i18nElementText (element, true, DL_ERROR);
 
 	// create and add property
 	addChild ("text", text = new RKComponentPropertyBase (this, true));
 	text->setInternal (true);
-	connect (text, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (textChanged (RKComponentPropertyBase *)));
+	connect (text, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (textChanged(RKComponentPropertyBase*)));
 
 	// initialize
 	text->setValue (initial_text);
