@@ -2,8 +2,8 @@
                           rcommandreceiver  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004, 2006, 2007, 2010 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -35,14 +35,6 @@ RCommandReceiver::~RCommandReceiver () {
 	}
 }
 
-void RCommandReceiver::rCommandDone (RCommand *) {
-	RK_TRACE (RBACKEND);
-}
-
-void RCommandReceiver::newOutput (RCommand *, ROutput *) {
-	RK_TRACE (RBACKEND);
-}
-
 void RCommandReceiver::cancelOutstandingCommands () {
 	RK_TRACE (RBACKEND);
 
