@@ -2,8 +2,8 @@
                           rinterface.h  -  description
                              -------------------
     begin                : Fri Nov 1 2002
-    copyright            : (C) 2002, 2004, 2005, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002 - 2013 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -27,7 +27,7 @@
 class RCommand;
 class RKWardMainWindow;
 class RKRBackend;
-struct RBackendRequest;
+class RBackendRequest;
 
 /** This class provides the main interface to the R-processor.
 
@@ -52,7 +52,7 @@ public:
 /** issues the given command in the given chain */
 	void issueCommand (RCommand *command, RCommandChain *chain=0);
 /** convenience function to create a new command and issue it. See documentation on RCommand::RCommand () and RInterface::issueCommand () */
-	void issueCommand (const QString &command, int type = 0, const QString &rk_equiv = QString::null, RCommandReceiver *receiver=0, int flags=0, RCommandChain *chain=0);
+	void issueCommand (const QString &command, int type = 0, const QString &rk_equiv = QString (), RCommandReceiver *receiver=0, int flags=0, RCommandChain *chain=0);
 
 /** opens a new command chain. Returns a pointer to the new chain. If you specify a parent, the new chain will be a sub-chain of that chain. */
 	RCommandChain *startChain (RCommandChain *parent=0);
@@ -62,6 +62,8 @@ public:
 /** Ensures that the given command will not be executed, or, if it is already running, interrupts it. Note that commands marked RCommand::Sync can
 not be interrupted. */
 	void cancelCommand (RCommand *command);
+/** Cancels the given command, unless it has already been submitted to the backend. Returns true, if command was cancelled, false otherwise. */
+	bool softCancelCommand (RCommand *command);
 /** Cancels all running or outstanding commands. @See cancelCommand() */
 	void cancelAll ();
 
@@ -101,18 +103,22 @@ private:
 	RBackendRequest* currentCommandRequest () const { return (command_requests.isEmpty () ? 0 : command_requests.last ()); };
 	void tryNextCommand ();
 	void doNextCommand (RCommand *command);
-	RCommand *popPreviousCommand ();
+	RCommand *popPreviousCommand (int id);
 	void handleCommandOut (RCommand *command);
 	bool previously_idle;
 
+	RCommandChain* openSubcommandChain (RCommand *parent_command);
+	QList<RCommand *> current_commands_with_subcommands;
+	void closeSubcommandChain (RCommand *parent_command);
+
 /** @see locked */
 	enum LockType {
 		User=1		/**< locked on user request */
 	};
 
-/** Used for locking the backend, meaning not further commands will be given to the backend. This is used, when the currently running command is to be cancelled. It is used to make sure that the backend thread does not proceed with further commands, before the main thread takes notice. Also it is called, if the RThread is paused on User request. Further, the thread is initially locked so the main thread can check for some conditions before the backend thread may produce
-more errors/crashes. @see RInterface::cancelCommand @see RInterface::pauseProcessing
-May be an OR'ed combination of several LockType s */
+/** Used for locking the backend, meaning not further commands will be given to the backend. It is called, if the RThread is paused on User request.
+ * @see RInterface::pauseProcessing
+ * May be an OR'ed combination of several LockType s, but currently, there is only one LockType */
 	int locked;
 
 	QString startup_errors;
@@ -120,6 +126,7 @@ May be an OR'ed combination of several LockType s */
 	int num_active_output_record_requests;
 	ROutput::ROutputType previous_output_type;
 	QString recorded_output;
+	RCommand *dummy_command_on_stack;
 friend class RKRBackendProtocolFrontend;
 	bool backend_dead;
 	static double na_real;
@@ -191,7 +198,7 @@ private:
 
 
 void MyReceiver::someFunction () {
-	RKGlobals::rInterface ()->issueCommand ("print (1+1)", RCommand::App, QString::null, this);
+	RKGlobals::rInterface ()->issueCommand ("print (1+1)", RCommand::App, QString (), this);
 }
 
 void MyReceiver::rCommandDone (RCommand *command) {
@@ -223,7 +230,7 @@ To illustrate the option of using "FLAGS", here is a reduced example of how RKVa
 
 void RKVariable::updateFromR () {
 	//...
-	RCommand *command = new RCommand ("length (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetIntVector, QString::null, this, UPDATE_DIM_COMMAND);
+	RCommand *command = new RCommand ("length (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetIntVector, QString (), this, UPDATE_DIM_COMMAND);
 	RKGlobals::rInterface ()->issueCommand (command, RKGlobals::rObjectList()->getUpdateCommandChain ());
 }
 
@@ -231,7 +238,7 @@ void RKVariable::rCommandDone (RCommand *command) {
 	//...
 	if (command->getFlags () == UPDATE_DIM_COMMAND) {
 		// ...
-		RCommand *ncommand = new RCommand ("class (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString::null, this, UPDATE_CLASS_COMMAND);
+		RCommand *ncommand = new RCommand ("class (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString (), this, UPDATE_CLASS_COMMAND);
 		RKGlobals::rInterface ()->issueCommand (ncommand, RKGlobals::rObjectList()->getUpdateCommandChain ());
 	} else if (command->getFlags () == UPDATE_CLASS_COMMAND) {
 		//...
@@ -356,7 +363,7 @@ This is typically used in plugins: When you specify this modifier, the plain tex
 These are special modifiers helpful when transferring data from R to RKWard (used primarily in the editor classes and in conjunction with RCommand::Sync): They tell the backend to try to fetch the result as an array of int, char*, or double, respectively. For instance, if you know object "myobject" is an integer vector, you may get the data using
 
 \code
-RKGlobals::rInterface ()->issueCommand ("myobject", RCommand::Sync | RCommand::GetIntVector, QString::null, this);
+RKGlobals::rInterface ()->issueCommand ("myobject", RCommand::Sync | RCommand::GetIntVector, QString (), this);
 \endcode
 
 Assuming the data can in fact be converted to a vector of integers, you can then access the data using these members in RCommand:
