@@ -2,8 +2,8 @@
                           rkfrontendtransmitter  -  description
                              -------------------
     begin                : Thu Nov 04 2010
-    copyright            : (C) 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2010-2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,12 +18,14 @@
 #include "rkfrontendtransmitter.h"
 
 #include "rkrbackendprotocol_frontend.h"
+#include "rkwarddevice/rkgraphicsdevice_frontendtransmitter.h"
 #include "../misc/rkcommonfunctions.h"
 #include "../settings/rksettingsmodulegeneral.h"
+#include "../rkglobals.h"
 
-#include "klocale.h"
-#include "krandom.h"
-#include "kstandarddirs.h"
+#include <klocale.h>
+#include <krandom.h>
+#include <kstandarddirs.h>
 #include <QCoreApplication>
 #include <QProcess>
 #include <QLocalServer>
@@ -33,15 +35,31 @@
 #include "../version.h"
 #include "../debug.h"
 
+QString findBackendAtPath (const QString &path) {
+	QDir dir (path);
+	dir.makeAbsolute ();
+#ifdef Q_WS_WIN
+	QString ret = dir.filePath ("rkward.rbackend.exe");
+#else
+	QString ret = dir.filePath ("rkward.rbackend");
+#endif
+	RK_DEBUG (RBACKEND, DL_DEBUG, "Looking for backend at %s", qPrintable (ret));
+	QFileInfo fi (ret);
+	if (fi.exists () && fi.isExecutable ()) return ret;
+	return QString ();
+}
+
 RKFrontendTransmitter::RKFrontendTransmitter () : RKAbstractTransmitter () {
 	RK_TRACE (RBACKEND);
 
+	rkd_transmitter = new RKGraphicsDeviceFrontendTransmitter ();
 	start ();
 }
 
 RKFrontendTransmitter::~RKFrontendTransmitter () {
 	RK_TRACE (RBACKEND);
 
+	delete rkd_transmitter;
 	RK_ASSERT (!server->isListening ());
 }
 
@@ -53,7 +71,7 @@ void RKFrontendTransmitter::run () {
 	// we add a bit of randomness to the servername, as in general the servername must be unique
 	// there could be conflicts with concurrent or with previous crashed rkward sessions.
 	if (!server->listen ("rkward" + KRandom::randomString (8))) handleTransmissionError ("Failure to start frontend server: " + server->errorString ());
-	connect (server, SIGNAL (newConnection ()), this, SLOT (connectAndEnterLoop ()), Qt::QueuedConnection);
+	connect (server, SIGNAL (newConnection()), this, SLOT (connectAndEnterLoop()), Qt::QueuedConnection);
 
 	// start backend
 	backend = new QProcess (this);
@@ -68,16 +86,29 @@ void RKFrontendTransmitter::run () {
 	QStringList args;
 	args.append ("--debug-level=" + QString::number (RK_Debug_Level));
 	args.append ("--server-name=" + server->fullServerName ());
+	args.append ("--rkd-server-name=" + rkd_transmitter->serverName ());
 	args.append ("--data-dir=" + RKSettingsModuleGeneral::filesPath ());
 	args.append ("--locale-dir=" + KGlobal::dirs()->findResourceDir ("locale", KGlobal::locale ()->language () + "/LC_MESSAGES/rkward.mo"));
-	connect (backend, SIGNAL (finished (int, QProcess::ExitStatus)), this, SLOT (backendExit (int)));
-	QString backend_executable = KStandardDirs::findExe (QDir::toNativeSeparators (QCoreApplication::applicationDirPath () + "/rkward.rbackend"));
-	if (backend_executable.isEmpty ()) backend_executable = KStandardDirs::findExe (QDir::toNativeSeparators (QCoreApplication::applicationDirPath () + "/rbackend/rkward.rbackend"));	// for running directly from the build-dir
+	connect (backend, SIGNAL (finished(int,QProcess::ExitStatus)), this, SLOT (backendExit(int)));
+	QString backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath ());
+	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/rbackend");	// for running directly from the build-dir
 #ifdef Q_WS_MAC
-        if (backend_executable.isEmpty ()) backend_executable = KStandardDirs::findExe (QDir::toNativeSeparators (QCoreApplication::applicationDirPath () + "/../../../rbackend/rkward.rbackend"));
+        if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../../../rbackend");
 #endif
-	RK_ASSERT (!backend_executable.isEmpty ());
-	backend->start (backend_executable, args, QIODevice::ReadOnly);
+	if (backend_executable.isEmpty ()) handleTransmissionError (i18n ("The backend executable could not be found. This is likely to be a problem with your installation."));
+	QString debugger = RKGlobals::startup_options["backend-debugger"].toString ();
+	if (!debugger.isEmpty ()) {
+		args.prepend (backend_executable);
+		QStringList l = debugger.split (' ');
+		args = l.mid (1) + args;
+		backend->start (l.first (), args, QIODevice::ReadOnly);
+	} else {
+		backend->start (backend_executable, args, QIODevice::ReadOnly);
+	}
+
+	if (!backend->waitForStarted ()) {
+		handleTransmissionError (i18n ("The backend executable could not be started. Error message was: %1").arg (backend->errorString ()));
+	}
 
 	// fetch security token
 	if (!backend->canReadLine ()) backend->waitForReadyRead ();
@@ -91,9 +122,6 @@ void RKFrontendTransmitter::run () {
 		RK_ASSERT (false);
 		return;
 	}
-
-	connection->close ();
-	backend->waitForFinished ();
 }
 
 void RKFrontendTransmitter::connectAndEnterLoop () {
@@ -131,6 +159,7 @@ void RKFrontendTransmitter::requestReceived (RBackendRequest* request) {
 
 			delete (out);
 		}
+		delete list;
 		request->output = 0;
 		RK_ASSERT (request->synchronous);
 		writeRequest (request);	// to tell the backend, that we are keeping up. Also deletes the request.
@@ -144,7 +173,9 @@ void RKFrontendTransmitter::requestReceived (RBackendRequest* request) {
 void RKFrontendTransmitter::backendExit (int exitcode) {
 	RK_TRACE (RBACKEND);
 
-	handleTransmissionError ("Backend process has exited with code " + QString::number (exitcode));
+	if (!exitcode && token.isEmpty ()) handleTransmissionError (i18n ("The backend process could not be started. Please check your installation."));
+	else if (token.isEmpty ()) handleTransmissionError (i18n ("The backend process failed to start with exit code %1.", exitcode));
+	else handleTransmissionError (i18n ("Backend process has exited with code %1.", exitcode));
 }
 
 void RKFrontendTransmitter::writeRequest (RBackendRequest *request) {
@@ -158,6 +189,7 @@ void RKFrontendTransmitter::writeRequest (RBackendRequest *request) {
 void RKFrontendTransmitter::handleTransmissionError (const QString &message) {
 	RK_TRACE (RBACKEND);
 
+	connection->close ();
 	RBackendRequest* req = new RBackendRequest (false, RBackendRequest::BackendExit);
 	req->params["message"] = message;
 	RKRBackendEvent* event = new RKRBackendEvent (req);
