@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Nov 04 2010
     copyright            : (C) 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -22,6 +22,7 @@
 
 class QProcess;
 class QLocalServer;
+class RKGraphicsDeviceFrontendTransmitter;
 
 class RKFrontendTransmitter : public RKAbstractTransmitter, public RKROutputBuffer {
 Q_OBJECT
@@ -43,10 +44,9 @@ private slots:
 private:
 	void handleTransmissionError (const QString &message);
 
-	int current_request_length;
 	QProcess* backend;
 	QLocalServer* server;
-	QString token;
+	RKGraphicsDeviceFrontendTransmitter* rkd_transmitter;
 };
 
 #endif
