@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Jul 25 2004
     copyright            : (C) 2004 - 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef R_EMBED_H
-#define R_EMBED_H
+#ifndef RKRBACKEND_H
+#define RKRBACKEND_H
 
 #include <stddef.h>
 
