@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Nov 04 2010
     copyright            : (C) 2010, 2011, 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -28,7 +28,7 @@ class RCommandProxy;
 
 class RKRBackendProtocolFrontend : public QObject {
 public:
-	RKRBackendProtocolFrontend (RInterface* parent);
+	explicit RKRBackendProtocolFrontend (RInterface* parent);
 	~RKRBackendProtocolFrontend ();
 
 	static void setRequestCompleted (RBackendRequest *request);
