@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 08 2011
     copyright            : (C) 2011, 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,8 +18,17 @@
 #include "rksessionvars.h"
 
 #include "rinterface.h"
+#include "../settings/rksettingsmoduledebug.h"
+#include "../settings/rksettingsmodulegeneral.h"
 #include "../version.h"
 
+#include <kdeversion.h>
+#include <ktemporaryfile.h>
+#include <kstandarddirs.h>
+
+#include <QLibraryInfo>
+#include <QSysInfo>
+
 #include "../debug.h"
 
 RKSessionVars* RKSessionVars::_instance = 0;
@@ -81,7 +90,7 @@ quint32 RKSessionVars::parseVersionString (const QString &version, QString *suff
 			}
 		}
 	}
-	if (opos < (version.size () - 1)) {
+	if (opos <= (version.size () - 1)) {
 		if (suffix) *suffix = version.mid (opos);
 		else RK_DEBUG (MISC, DL_WARNING, "Non numeric portion ('%s') of version specification '%s' will be ignored.", qPrintable (version.mid (opos)), qPrintable (version));
 	}
@@ -110,4 +119,24 @@ int RKSessionVars::compareRVersion (const QString& version) {
 	return 0;
 }
 
+QStringList RKSessionVars::frontendSessionInfo () {
+	QStringList lines;
+	lines.append ("RKWard version: " RKWARD_VERSION);
+	lines.append ("KDE version (runtime): " + QString (KDE::versionString ()));
+	lines.append ("KDE version (compile time): " KDE_VERSION_STRING);
+	lines.append ("Qt build key: " + QLibraryInfo::buildKey ());
+#if defined Q_WS_WIN
+	lines.append ("Windows runtime version (refer to QSysInfo documentation to translate code into human readable form): 0x" + QString::number (QSysInfo::windowsVersion (), 16));
+#elif defined Q_WS_MAC
+	lines.append ("MacOS runtime version (refer to QSysInfo documentation to translate code into human readable form): 0x" + QString::number (QSysInfo::MacintoshVersion, 16));
+#endif
+	lines.append ("Local KDE directory: " + KGlobal::dirs ()->localkdedir ());
+	lines.append ("RKWard storage directory: " + RKSettingsModuleGeneral::filesPath ());
+	lines.append ("Backend version (as known to the frontend): " + r_version_string);
+	lines.append (QString());
+	lines.append ("Debug message file (this may contain relevant diagnostic output in case of trouble):");
+	lines.append (RKSettingsModuleDebug::debug_file->fileName ());
+	return lines;
+}
+
 #include "rksessionvars.moc"
