@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 08 2011
     copyright            : (C) 2011, 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -39,6 +39,7 @@ public:
 Anything else (everything after the fourth dot, or after the first character that is neither dot, nor digit)
 is returned as suffix (via the suffix pointer; if that is 0, an error is reported, instead). */
 	static quint32 parseVersionString (const QString &version, QString *suffix);
+	static QStringList frontendSessionInfo ();
 signals:
 	void installedPackagesChanged ();
 protected:
