@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Apr 11 2007
     copyright            : (C) 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -193,29 +193,42 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 
 	// get classes
 	SEXP classes_s;
+	QStringList classes;
 
 	if ((TYPEOF (value) == LANGSXP) || (TYPEOF (value) == SYMSXP)) {	// if it's a call, we should NEVER send it through eval
-		extern SEXP R_data_class (SEXP, Rboolean);
-		classes_s = R_data_class (value, (Rboolean) 0);
+		// stripped down and adjusted from R_data_class
+		PROTECT (classes_s = Rf_getAttrib (value, R_ClassSymbol));
+		if (Rf_length (classes_s)) classes = RKRSupport::SEXPToStringList(classes_s);
+		UNPROTECT (1);
+		if (classes.isEmpty ()) {
+			if (TYPEOF (value) == LANGSXP) {
+				SEXP symb = PROTECT (CAR (value));
+				QString cl;
+				if (TYPEOF (symb) == SYMSXP) cl = CHAR (PRINTNAME (symb));
+				UNPROTECT (1);
+				if ((cl != "if") && (cl != "while") && (cl != "for") && (cl != "=") && (cl != "<-") && (cl != "(") && (cl != "{")) cl = "call";
+				classes = QStringList (cl);
+			} else {
+				classes = QStringList ("name");
+			}
+		}
 
 		REPROTECT (value = Rf_coerceVector (value, EXPRSXP), value_index);	// make sure the object is safe for everything to come
-
-		PROTECT (classes_s);
 	} else {
-		classes_s = RKRSupport::callSimpleFun (class_fun, value, baseenv);
-		PROTECT (classes_s);
+		PROTECT (classes_s = RKRSupport::callSimpleFun (class_fun, value, baseenv));
+		classes = RKRSupport::SEXPToStringList (classes_s);
+		UNPROTECT (1);
 	}
 
-	QStringList classes = RKRSupport::SEXPToStringList (classes_s);
-	UNPROTECT (1);	/* classes_s */
-
 	// store classes
 	RData *classdata = new RData;
 	classdata->setData (classes);
 
 	// basic classification
 	for (int i = classes.size () - 1; i >= 0; --i) {
-#warning: Using is.data.frame() may be more reliable (would need to be called only on List-objects, thus no major performance hit)
+#ifdef __GNUC__
+#	warning: Using is.data.frame() may be more reliable (would need to be called only on List-objects, thus no major performance hit)
+#endif
 		if (classes[i] == "data.frame") type |= RObject::DataFrame;
 	}
 
@@ -351,7 +364,7 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 
 		RData::RDataStorage children (childcount, 0);
 		for (int i = 0; i < childcount; ++i) {
-			children[i] = new RData ();		// NOTE: RData-ctor pre-initalizes these to empty. Thus, we're safe even if there is an error while fetching one of the children.
+			children[i] = new RData ();		// NOTE: RData-ctor pre-initializes these to empty. Thus, we're safe even if there is an error while fetching one of the children.
 		}
 
 		if (do_env) {
@@ -381,7 +394,7 @@ void RKStructureGetter::getStructureWorker (SEXP val, const QString &name, int a
 		} else if (do_cont) {
 			RK_DEBUG (RBACKEND, DL_DEBUG, "recurse into list %s", name.toLatin1().data ());
 			// fewer elements than names() can happen, although I doubt it is supposed to happen.
-			// see http://sourceforge.net/tracker/?func=detail&aid=3002439&group_id=50231&atid=459007
+			// see http://sourceforge.net/p/rkward/bugs/67/
 			bool may_be_special = Rf_length (value) < childcount;
 			if (Rf_isList (value) && (!may_be_special)) {		// old style list
 				for (int i = 0; i < childcount; ++i) {
