@@ -2,8 +2,8 @@
                           rktransmitter  -  description
                              -------------------
     begin                : Thu Nov 18 2010
-    copyright            : (C) 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2010, 2013 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,20 +19,17 @@
 #define RKTRANSMITTER_H
 
 #include "rkrbackendprotocol_shared.h"
+#include "rkasyncdatastreamhelper.h"
 
 #include <QThread>
 #include <QByteArray>
 
-#ifndef RKWARD_SPLIT_PROCESS
-#	error This should only be compiled for split process backends.
-#endif
-
 /** functions for serialization / unserialization of communication between backend and frontend.
 NOTE: This could really be a namespace, instead of a class, but "friending" a class is simply easier... */
 class RKRBackendSerializer {
 public:
-	static QByteArray serialize (const RBackendRequest &request);
-	static RBackendRequest *unserialize (const QByteArray &buffer);
+	static void serialize (const RBackendRequest &request, QDataStream &buffer);
+	static RBackendRequest *unserialize (QDataStream &buffer);
 
 private:
 	static void serializeOutput (const ROutputList &list, QDataStream &stream);
@@ -50,6 +47,9 @@ Q_OBJECT
 public:
 	static RKAbstractTransmitter* instance () { return _instance; };
 	virtual ~RKAbstractTransmitter ();
+
+/** returns the magic token negotiated between frontend and backend (for validating incoming connections) */
+	QString connectionToken () { return token; };
 protected:
 	RKAbstractTransmitter ();
 
@@ -61,13 +61,14 @@ protected:
 	void customEvent (QEvent *e);
 	void setConnection (QLocalSocket *connection);
 	QLocalSocket *connection;
+	QString token;
 private slots:
 	/** Note: this blocks until a compelete request has been received. Connected to the "readyRead"-signal of the connection. Calls requestReceived() once the request has been read. */
 	void fetchTransmission ();
 	void disconnected ();
 private:
 	static RKAbstractTransmitter* _instance;
-	bool fetching_transmission;
+	RKAsyncDataStreamHelper<quint64> streamer;
 };
 
 #endif
