@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Mar 18 20:06:08 CET 2013
     copyright            : (C) 2013-2014 by Thomas Friedrichsmeier 
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -105,7 +105,7 @@ static QPen readSimplePen (QDataStream &instream) {
 	instream >> lwd >> lty;
 	if (!col.isValid () || (lty == -1L)) return QPen (Qt::NoPen);
 
-	lwd = qMax (qreal(1.0), lwd);	// minimum 1 px as in X11 device
+	lwd = qMax (double(qreal(1.0)), lwd);	// minimum 1 px as in X11 device
 	QPen ret;
 	if (lty != 0) {	// solid
 		QVector<qreal> dashes;
