@@ -17,7 +17,7 @@
 #' \bold{Warning}: It is advised to use \code{rk.graph.off} and \bold{not} \code{dev.off} to close the device opened by
 #' \code{rk.graph.on}. \code{dev.print(device = rk.graph.on)} is a \bold{wrong} usage for this "device," and will result in errors.
 #' 
-#' @author Thomas Friedrichsmeier \email{rkward-devel@@lists.sourceforge.net}
+#' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' 
 #' @seealso \link{rk.results} \link{rk.print} \link{rk.get.output.html.file} \link{dev.off} \link{svg} \link{png} \link{jpg}
 #'
@@ -43,7 +43,7 @@
 #' @export
 #' @aliases rk.graph.on rk.graph.off
 #' @rdname rk.graph.on
-rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOption ("rk.graphics.width"), height=getOption ("rk.graphics.height"), quality, ...) 
+"rk.graph.on" <- function (device.type=getOption ("rk.graphics.type"), width=getOption ("rk.graphics.width"), height=getOption ("rk.graphics.height"), quality, ...) 
 {
 	if (!is.numeric (width)) width <- 480
 	if (!is.numeric (height)) height <- 480
@@ -100,6 +100,130 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	ret
 }
 
+#' Plot graphics to RKWard native device
+#'
+#' \code{RK()} creates an R on-screen device that will be rendered in the RKWard frontend. 
+#' The default settings for \code{width}, and \code{height} can be modified from Settings -> Configure RKWard -> Onscreen Graphics.
+#'
+#' @param width Width of the device in inches. The default is to use the heigth configured in Settings -> Configure RKWard -> Onscreen Graphics.
+#' @param height Height of the device in inchesgraphics in pixels. The default is to use the heigth configured in Settings -> Configure RKWard -> Onscreen Graphics.
+#' @param pointsize Default pointsize
+#' @param family Default font family. This can be a character vector of length 1 or 2. The second value is used for
+#'               plotting symbols. Effectively the default is c("Helvetica", "Symbol"). A wide variety of sepcification is supported,
+#'               including the device independent fonts names "sans", "serif", and "mono"
+#' @param bg Background color.
+#' @param title Window title.
+#' @param antialias Antialiasing. Can be turned off for somewhat faster drawing.
+#'
+#' @keywords devices
+#'
+#' @export
+#' @aliases RK
+#' @rdname RKdevice
+"RK" <- function (width=getOption("rk.screendevice.width"), height=getOption("rk.screendevice.height"), pointsize=12, family=NULL, bg="white", title="", antialias=TRUE) {
+	if (is.null (width)) width <- 7
+	if (is.null (height)) height <- 7
+	ret <- .Call ("rk.graphics.device", as.integer (width), as.integer (height), as.integer (pointsize), family, bg, title, isTRUE (antialias), PACKAGE="(embedding)")
+	rk.record.plot$onAddDevice (dev.cur ())
+	invisible (ret)	# Current always NULL
+}
+
+#' Embed non-RKWard device windows
+#'
+#' \code{rk.embed.device} evaluates the given expression, and if this has created a window on the screen, tries to embed it as an RKWard window.
+#'
+#' @param expr  Expression to evaluate. 
+#'
+#' @details Theoretically, \code{expr} can be any valid R expression. However typically this should be calls to X11(), Windows(), or, perhaps dev.copy().
+#'       Importantly, the expression should create exactly one new window for \code{rk.embed.device()} to work. Keep in mind, that this is not
+#'       always the case for \code{plot(...)} and similar commands, which will re-use an existing plot window, if available.
+#'
+#' @note \code{rk.embed.device()} will not work on all platforms (most importantly, not in most MacOSX binaries). Further, note that a captured
+#'       \code{X11()} or \code{Windows} device may look similar to an \code{RK()} device, but is actually a very different thing. Capturing a
+#'       window already "owned" by RKWard (importantly, \code{RK()} device windows) may lead to unexpected results, including crashes.
+#'
+#' @seealso \link{RK}
+#' @examples
+#' 
+#' ## Not run:
+#' rk.embed.device (grDevices::X11(title="X11 device window"))
+#' plot (rnorm (10))
+#'
+#' @export
+"rk.embed.device" <- function (expr) {
+	oldd <- dev.cur ()
+	.rk.do.call ("startOpenX11", as.character (oldd));
+	on.exit (.rk.do.call ("endOpenX11", as.character (dev.cur())));
+
+	x <- eval.parent (expr)
+
+	if (oldd != dev.cur ()) on.exit (rk.record.plot$onAddDevice (), add=TRUE)
+	else warning ("No device appears to have been created (dev.cur() has not changed)");
+	invisible (x)
+}
+
+# Internal function to create wrapper around an R device function (used for X11(), windows(), and quartz()).
+".rk.make.device.wrapper" <- function (devicename) {
+	ret <- eval (substitute (
+		function (width=getOption("rk.screendevice.width"), height=getOption("rk.screendevice.height"), pointsize=12) {
+			rk.mode <- getOption ("rk.override.platform.devices")
+			if (identical (rk.mode, "replace") || !exists (devicename, envir=asNamespace ("grDevices"), inherits=FALSE)) {
+				if (!identical (rk.mode, "replace")) {
+					warning (paste (devicename, "()-device is not available. Falling back to RK()"))
+				}
+				args <- list ()
+				if (exists ("width", inherits=FALSE) && !missing (width)) args$width <- width
+				if (exists ("height", inherits=FALSE) && !missing (height)) args$height <- height
+				if (exists ("pointsize", inherits=FALSE) && !missing (pointsize)) args$pointsize <- pointsize
+				if (exists ("bg", inherits=FALSE) && !missing (bg)) args$bg <- bg
+				if (exists ("title", inherits=FALSE) && !missing (title)) args$title <- title
+				if (exists ("antialias", inherits=FALSE) && !missing (antialias)) args$antialias <- !identical (antialias, "none")
+				do.call (rkward::RK, args)
+			} else if (identical (rk.mode, "embed")) {
+				if (missing (width)) width <- getOption ("rk.screendevice.width")
+				if (!is.numeric (width)) width <- 7
+				if (missing (height)) height <- getOption ("rk.screendevice.height")
+				if (!is.numeric (height)) height <- 7
+				rk.embed.device (eval (body (grDevices::devicename)))
+			} else {
+				eval (body (grDevices::devicename))
+			}
+		}
+	))
+	if (exists (devicename, envir=asNamespace ("grDevices"), inherits=FALSE)) {
+		devfun <- get (devicename, asNamespace ("grDevices"))
+		formals (ret) <- formals (devfun)
+		environment (ret) <- environment (devfun)
+	}
+	ret
+}
+
+## NOTE: Adding an Rd-page for these makes "?X11" fail (R 3.0.0).
+# Overrides for platform specific R plotting devices
+#
+# These functions override the platform specific on-screen plotting devices by the same names.
+# The exact behavior depends on configuration settings, and can be one of: The original R device,
+# the original R device embedded using \code{rk.embed.device()}, or the call can be re-directed
+# to the \code{RK()} device. In the last case not all function arguments may be honored.
+#
+# @note If you want to use the \link{RK} device, you should call that, explicitly. These
+#       overrides are provided to make it easy to use scripts that refer to the platform specific
+#       plotting devices provided by R.
+#
+# @seealso \link{RK} \link{rk.embed.device} \link[grDevices]{X11} \link[grDevices]{Windows}
+#
+# @rdname DeviceOverrides
+#' @export
+"X11" <- .rk.make.device.wrapper ("X11")
+#' @export
+"x11" <- X11
+#' @export
+"windows" <- .rk.make.device.wrapper ("windows")
+#' @export
+"win.graph" <- .rk.make.device.wrapper ("win.graph")  # NOTE: Has different formals() than windows()
+#' @export
+"quartz" <- .rk.make.device.wrapper ("quartz")
+
 #' Device for printing using the KDE print dialog
 #' 
 #' Creates a device operating on a temporary file (internally a
@@ -111,7 +235,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 #' 
 #' @param ... arguments are passed to \code{\link{postscript}}
 #' @return Returns the name of the underlying temporary file, invisibly.
-#' @author Thomas Friedrichsmeier \email{rkward-devel@@lists.sourceforge.net}
+#' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' @seealso \code{\link{postscript}}, \code{\link{dev.print}},
 #'   \code{\link{rk.graph.on}}
 #' @keywords utilities device
@@ -135,8 +259,10 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 #' @export
 "rk.duplicate.device" <- function (devId = dev.cur ())
 {
+	rk.record.plot$duplicating.from.device <- devId
+	on.exit (rk.record.plot$duplicating.from.device <- 1)	# NULL device
 	dev.set (devId)
-	dev.copy (device = x11, is.being.duplicated = TRUE)
+	dev.copy (device = dev.new)
 }
 
 # A global history of various graphics calls;
@@ -165,9 +291,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 		pkg = "", call = NA_character_, plot = NA, tlo.ls = NA)
 	# this list stores the details for currently displayed plots on the devices; tagged by device number
 	histPositions <- list ("1" = .hP.template)
-	.hP.names <- names (histPositions)
-	.set.hP.names <- function () .hP.names <<- names (histPositions)
-	
+
 	.ss.used <- FALSE # split.screen variable
 	.pop.notify <- TRUE # used when hist limit is reached
 	.cll <- 50 # no. of characters used in the "goto plot" drop down list
@@ -175,7 +299,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	
 	## Generic functions:
 	.get.sys.time <- function () format (Sys.time (), "%Y%m%d%H%M%OS3")
-	.is.device.managed <- function (devId) as.character (devId) %in% .hP.names[-1]
+	.is.device.managed <- function (devId) as.character (devId) %in% names(histPositions)[-1]
 	.set.trellis.last.object <- function (devId = dev.cur ())
 	{
 		# called only from dev.set (); this appropriately sets the "lattice.status"
@@ -208,16 +332,15 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	}
 	
 	## Device specific functions:
-	onAddDevice <- function (devId.from = 1, devId = dev.cur (), 
-		is.being.duplicated = FALSE, is.preview.device = FALSE)
+	onAddDevice <- function (devId = dev.cur ())
 	{
-		if (is.preview.device) return (invisible ())
+		if (!isTRUE (getOption ("rk.enable.graphics.history"))) return (invisible ())
 		
-		devId.from <- as.character (devId.from)
+		devId.from <- as.character (env$duplicating.from.device)
 		devId <- as.character (devId)
 		
 		histPositions [[devId]] <<- .hP.template
-		if (is.being.duplicated && !histPositions [[devId.from]]$is.this.dev.new) {
+		if ((env$duplicating.from.device > 1) && !histPositions [[devId.from]]$is.this.dev.new) {
 			# devId.from > 1
 			## TODO: see if so many "[[" calls can be reduced?
 			histPositions [[devId]]$is.this.plot.new <<- TRUE
@@ -229,7 +352,6 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 			histPositions [[devId]]$plot <<- histPositions [[devId.from]]$plot
 			histPositions [[devId]]$tlo.ls <<- histPositions [[devId.from]]$tlo.ls
 		}
-		.set.hP.names ()
 		.rk.update.hist.actions ()
 		invisible ()
 	}
@@ -258,18 +380,15 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 					list (is.this.plot.new = TRUE, is.this.dev.new = FALSE, pkg = "unknown"))
 		}
 		.rk.backups$dev.set (d.cur)
-		.set.hP.names ()
 	}
 	onDelDevice <- function (devId = dev.cur())
 	{
 		devId <- as.character (devId)
-		if (!(devId %in% .hP.names[-1])) return (invisible ())
+		if (!(devId %in% names(histPositions)[-1])) return (invisible ())
 		
 		## TODO: ask for confirmation before appending a plot
 		record (devId, action = "dev.off")
 		histPositions [[devId]] <<- NULL
-		.set.hP.names ()
-		
 		invisible ()
 	}
 	flushout.histPositions <- function ()
@@ -279,7 +398,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 		# cleans out the device specific lists
 		
 		# save any unsaved plots and "close" the device w/o actually closing the window:
-		for (d in .hP.names)
+		for (d in names(histPositions))
 			record (devId = d, action = "dev.off")
 		.rk.update.hist.actions (enable.plot.hist = FALSE)
 		histPositions <<- list ("1" = .hP.template)
@@ -467,7 +586,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	.check.other.dev.at.same.pos <- function (devId, .n.)
 	{
 		# length (.n.) >= 1 when .verify.hist.limits () calls remove ()
-		odnames <- .hP.names [!(.hP.names %in% c("1", devId))]
+		odnames <- names(histPositions) [!(names(histPositions) %in% c("1", devId))]
 		if (length (odnames) == 0) return (invisible ())
 		
 		odpos <- sapply (histPositions [odnames], "[[", "pos.cur") # names kept
@@ -558,7 +677,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 		savedPlots <<- list ()
 		.unsavedPlot <<- list (plot = NULL, tlo.ls = NULL, pkg = NA_character_, is.os = NA, tryerr = NA)
 		.ss.used <<- FALSE
-		for (d in .hP.names[-1]) {
+		for (d in names(histPositions)[-1]) {
 			if (!histPositions [[d]]$is.this.dev.new)
 				histPositions [[d]]$is.this.plot.new <<- TRUE
 			histPositions [[d]]$pos.cur <<- NA_integer_
@@ -596,9 +715,9 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 			# access it
 			if (cur.devId != as.numeric (devId))
 				tlo.ls <- get ("lattice.status", envir = lattice:::.LatticeEnv)
-			options (rk.enable.graphics.history=FALSE); on.exit (options (rk.enable.graphics.history=TRUE))
-			plot (savedPlots [[st]]$plot, save.object = (cur.devId == as.numeric (devId)))
-			options (rk.enable.graphics.history=TRUE)
+			rk.without.plot.history ({
+				plot (savedPlots [[st]]$plot, save.object = (cur.devId == as.numeric (devId)))
+			})
 			if (cur.devId != as.numeric (devId))
 				assign ("lattice.status", tlo.ls, envir = lattice:::.LatticeEnv)
 		}
@@ -718,7 +837,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	.get.plot.info.str <- function (devId = dev.cur (), l=0)
 	{
 		devId <- as.character (devId)
-		if (!(devId %in% .hP.names)) return (paste ("Device", devId, "is not managed."))
+		if (!(devId %in% names(histPositions))) return (paste ("Device", devId, "is not managed."))
 		
 		n <- histPositions [[devId]]$pos.cur
 		if (is.na (n)) {
@@ -796,7 +915,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 		paste (substr (.lab.str, 1, l), "...", sep = "")
 	}
 	.plot.new.hook <- function (.callstr) {
-		if (dev.cur() == 1) rk.screen.device ()
+		if (dev.cur() == 1) dev.new ()
 		if (getOption ("rk.enable.graphics.history")) {
 			.callstr <- sys.call (-sys.parents()[sys.nframe ()])
 			record (nextplot.pkg = "graphics", nextplot.call = .callstr)
@@ -804,7 +923,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	}
 	
 	## Utility / R - C++ connection functions:
-	.rk.update.hist.actions <- function (devIds = .hP.names, enable.plot.hist = TRUE)
+	.rk.update.hist.actions <- function (devIds = names(histPositions), enable.plot.hist = TRUE)
 	{
 		# this function is called whenever the history length changes
 		# or the position changes in any device.
@@ -843,6 +962,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 		# Existing plots are not checked for their sizes, only the new ones are.
 	}
 
+	env$duplicating.from.device <- 1 # NULL device
 	env
 }
 rk.record.plot <- rk.record.plot ()
@@ -931,3 +1051,15 @@ rk.record.plot <- rk.record.plot ()
 			NULL)
 	ret
 }
+#' Run a (plotting) action, without recording anything in the plot history.
+#' Internally, the plot history option is turned off for the duration of the action.
+#' 
+#' @export
+"rk.without.plot.history" <- function (expr)
+{
+	if (getOption ("rk.enable.graphics.history")) {
+		on.exit (options ("rk.enable.graphics.history" = TRUE))
+	}
+	options ("rk.enable.graphics.history" = FALSE)
+	eval.parent(expr)
+}
