@@ -48,7 +48,7 @@
 #'   they are plain row numbers.
 #' @return \code{rk.describe.alternatives} returns a string while all other
 #'   functions return \code{NULL}, invisibly.
-#' @author Thomas Friedrichsmeier \email{rkward-devel@@lists.sourceforge.net}
+#' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' @seealso \code{\link{HTML}}, \code{\link{rk.get.output.html.file}},
 #'   \code{\link{rk.get.description}}, \code{\link{rk.call.plugin}},
 #'   \url{rkward://page/rkward_output}
@@ -128,6 +128,7 @@
 	if (length (parameters)) {
 		# legacy handling: parameter=value used to be passed as parameter, value
 		if (is.null (names (parameters))) {
+			warning ("Unnamed parameter lists are deprecated in rk.header()")
 			s <- seq.int (1, length (parameters), by=2)
 			pnames <- as.character (parameters[s])
 			parameters <- parameters[s+1]
@@ -155,7 +156,7 @@
 	on.exit (sink ())
 
 	# convert 2d tables to data.frames with values labelled
-	if (is.table(x) && (length(dim(x)) == 2)) {
+	if ((is.table(x) || is.matrix(x)) && (length(dim(x)) == 2)) {
 		rows = dim(x)[1]
 		cols = dim(x)[2]
 		if (is.null(titles)) {
@@ -192,6 +193,7 @@
 			cat ("</tr>\n")
 	
 			if (is.data.frame (x)) {
+				x <- as.data.frame (lapply (x, format), stringsAsFactors=FALSE)
 				for (row in 1:dim (x)[1]) {
 					cat ("<tr>")
 					for (col in 1:dim (x)[2]) {
