@@ -5,6 +5,9 @@
 .rktest.tmp.storage <- new.env()
 
 .rk.rerun.plugin.link.replacement <- function (plugin, settings, label) {
+	op <- options (useFancyQuotes = FALSE)
+	on.exit (options (op))
+
 	.rk.cat.output("<h3>Rerun code:</h3>")
 	.rk.cat.output("<pre>")
 	.rk.cat.output("rk.call.plugin (")
@@ -155,6 +158,10 @@ rktest.runRKTest <- function (test, standard.path, suite.id) {
 		else result@error <- "no"
 	}
 
+	rktest.cleanTestFile (output_file)
+	rktest.cleanTestFile (code_file)
+	rktest.cleanTestFile (message_file)
+
 	result@output_match = rktest.compare.against.standard (output_file, standard.path, test@fuzzy_output)
 	if (result@output_match == "MISMATCH") passed <- FALSE
 	result@message_match = rktest.compare.against.standard (message_file, standard.path)
@@ -167,6 +174,15 @@ rktest.runRKTest <- function (test, standard.path, suite.id) {
 	result
 }
 
+# Make replacements to stabilize comparison. Currently strips tempdir path.
+rktest.cleanTestFile <- function (filename) {
+	if (file.exists (filename)) {
+		raw <- readLines (filename)
+		cleaned <- gsub (getwd (), "PATH", raw, fixed=TRUE)
+		writeLines (cleaned, filename)
+	}
+}
+
 rktest.cleanRKTestSuite <- function (suite) {
       # kept for backwards compatibility ;-)
       rktest.removeTempSuiteDir(suite@id)
@@ -234,6 +250,7 @@ rktest.initializeEnvironment <- function () {
 	if (.Platform$OS.type == "unix"){
 		invisible (Sys.setlocale (category="LC_MESSAGES", locale="C"))
 	}
+	rk.switch.frontend.language ("C")
 	options (useFancyQuotes=FALSE)
 
 	# This version of rk.set.output.html.file does not notify the frontend of the change. Without this, you'll get lots of output windows.
