@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Aug 19 2004
     copyright            : (C) 2004, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -224,6 +224,13 @@ bool RKConsole::handleKeyPress (QKeyEvent *e) {
 
 	if (para < doc->lines () - 1 || pos < prefix.length ()) {	// not inside the last line?
 		if (!is_modifier_key) cursorAtTheEnd ();	// adjust position before interpreting non-modifier keystroke
+
+		// KDE 4.13.3 (may have started, earlier): Apparently, cursor adjustment does not take effect, immediately.
+		if (para < doc->lines () - 1 || pos < prefix.length ()) { // still not inside the last line?
+			// HACK ish workaround:
+			// qApp->postEvent (this, e); // not quite as easy to re-post, as event will be deleted
+			return true;	// at least prevent kate part form interpreting it
+		}
 	}
 
 	if (current_command) {
@@ -361,7 +368,7 @@ QString RKConsole::provideContext (int line_rev) {
 	QString ret;
 	if (line_rev == 0) ret = currentEditingLine ().left (currentCursorPositionInCommand ()); 
 	else if (!incomplete_command.isEmpty ()) {
-		QStringList lines = incomplete_command.split ("\n");
+		QStringList lines = incomplete_command.split ('\n');
 		if (lines.size () > line_rev) {
 			ret = lines[lines.size () - line_rev - 1];
 		}
@@ -451,7 +458,7 @@ void RKConsole::doTabCompletion () {
 	QString current_symbol = current_line.mid (word_start, word_end - word_start);
 
 	// as a very simple heuristic: If the current symbol starts with a quote, we should probably attempt file name completion, instead of symbol name completion
-	if (current_symbol.startsWith ("\"") || current_symbol.startsWith ("\'") || current_symbol.startsWith ("`")) {
+	if (current_symbol.startsWith ('\"') || current_symbol.startsWith ('\'') || current_symbol.startsWith ('`')) {
 		KUrlCompletion comp (KUrlCompletion::FileCompletion);
 		comp.setDir (QDir::currentPath ());
 		comp.makeCompletion (current_symbol.mid (1));
@@ -473,7 +480,7 @@ bool RKConsole::eventFilter (QObject *o, QEvent *e) {
 		return RKMDIWindow::eventFilter (o, e);
 	}
 
-	if (e->type () == QEvent::KeyPress) {
+	if ((e->type () == QEvent::KeyPress) || (e->type () == QEvent::Shortcut)) {
 		QKeyEvent *k = (QKeyEvent *)e;
 		return (handleKeyPress (k));
 	} else if (e->type () == QEvent::MouseButtonPress) {
@@ -646,7 +653,7 @@ void RKConsole::newOutput (RCommand *, ROutput *output) {
 
 	if (RKSettingsModuleConsole::maxConsoleLines ()) {
 		uint c = (uint) doc->lines();
-// We remove the superflous lines in chunks of 20 while handling output for better performance. Later, in showPrompt(), we trim down to the correct size.
+// We remove the superfluous lines in chunks of 20 while handling output for better performance. Later, in showPrompt(), we trim down to the correct size.
 		if (c > (RKSettingsModuleConsole::maxConsoleLines () + 20)) {
 // KDE4: does the setUpdatesEnabled (false) still affect performance?
 			view->setUpdatesEnabled (false);		// major performance boost while removing lines!
@@ -785,7 +792,7 @@ void RKConsole::userSaveHistory (const KUrl &_url) {
 
 	KTemporaryFile tempfile;
 	tempfile.open ();
-	tempfile.write (QString (commandHistory ().join ("\n") + "\n").toLocal8Bit ().data ());
+	tempfile.write (QString (commandHistory ().join ("\n") + '\n').toLocal8Bit ().data ());
 	tempfile.close ();
 
 	KIO::NetAccess::upload (tempfile.fileName (), url, this);
@@ -796,8 +803,8 @@ QString RKConsole::cleanSelection (const QString &origin) {
 
 	QString ret;
 	ret.reserve (origin.length ());
-	QStringList lines = origin.split ("\n");
-	foreach (QString line, lines) {
+	QStringList lines = origin.split ('\n');
+	foreach (const QString& line, lines) {
 		if (line.startsWith (nprefix)) {
 			ret.append (line.mid (nprefix.length ()));
 		} else if (line.startsWith (iprefix)) {
@@ -818,7 +825,7 @@ void RKConsole::copyCommands () {
 	if (!sel.isValid ()) return;
 
 	// we use this somewhat cumbersome (and inefficient) approach as it should also be correct in case of blockwise selections
-	QStringList command_lines = view->selectionText ().split ("\n");
+	QStringList command_lines = view->selectionText ().split ('\n');
 	int i = 0;
 	for (int l = sel.start ().line (); l <= sel.end ().line (); ++l) {
 		QString line = doc->line (l);
@@ -889,7 +896,7 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 #endif
 	RKStandardActions::copyLinesToOutput (this, this, SLOT (copyLinesToOutput()));
 	context_help_action = RKStandardActions::functionHelp (this, this, SLOT(showContextHelp()));
-	run_selection_action = RKStandardActions::runSelection (this, this, SLOT (runSelection()));
+	run_selection_action = RKStandardActions::runCurrent (this, this, SLOT (runSelection()));
 
 	interrupt_command_action = ac->addAction ("interrupt", this, SLOT (resetConsole()));
 	interrupt_command_action->setText (i18n ("Interrupt running command"));
@@ -904,7 +911,7 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 	copy_commands_action = ac->addAction ("rkconsole_copy_commands", this, SLOT (copyCommands()));
 	copy_commands_action->setText (i18n ("Copy commands, only"));
 
-	RKStandardActions::pasteSpecial (this, this, SLOT (submitBatch(const QString&)));
+	RKStandardActions::pasteSpecial (this, this, SLOT (submitBatch(QString)));
 
 	ac->addAction (KStandardAction::Clear, "rkconsole_clear", this, SLOT (clear()));
 	paste_action = ac->addAction (KStandardAction::Paste, "rkconsole_paste", this, SLOT (paste()));
@@ -915,9 +922,9 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 	addProxyAction ("view_inc_font_sizes");
 	addProxyAction ("view_dec_font_sizes");
 
-	KAction *action = ac->addAction ("loadhistory", this, SLOT (userLoadHistory ()));
+	KAction *action = ac->addAction ("loadhistory", this, SLOT (userLoadHistory()));
 	action->setText (i18n ("Import command history..."));
-	action = ac->addAction ("savehistory", this, SLOT (userSaveHistory ()));
+	action = ac->addAction ("savehistory", this, SLOT (userSaveHistory()));
 	action->setText (i18n ("Export command history..."));
 }
 
@@ -974,7 +981,7 @@ void RKConsole::contextMenuEvent (QContextMenuEvent * event) {
 void RKConsole::activate (bool with_focus) {
 	RK_TRACE (APP);
 
-	// see http://www.mail-archive.com/rkward-devel@lists.sourceforge.net/msg00933.html
+	// see https://mail.kde.org/pipermail/rkward-devel/2010-September/002422.html
 	if (with_focus) view->removeSelection ();
 	RKMDIWindow::activate (with_focus);
 }
