@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Aug 18 2004
     copyright            : (C) 2004 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
