@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Oct 29 20:06:08 CET 2002
     copyright            : (C) 2002-2013 by Thomas Friedrichsmeier 
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -16,19 +16,11 @@
  ***************************************************************************/
 
 // include files for QT
-#include <qprinter.h>
-#include <qpainter.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
 #include <qtimer.h>
-#include <QDBusConnection>
 #include <QDesktopWidget>
-#include <QLabel>
 #include <QCloseEvent>
 
 // include files for KDE
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kencodingfiledialog.h>
 #include <kmenubar.h>
@@ -64,6 +56,7 @@
 #include "misc/rkstandardicons.h"
 #include "misc/rkcommonfunctions.h"
 #include "misc/rkxmlguisyncer.h"
+#include "misc/rkdbusapi.h"
 #include "rkglobals.h"
 #include "dialogs/startupdialog.h"
 #include "dialogs/rkloadlibsdialog.h"
@@ -115,11 +108,14 @@ void bogusCalls () {
 //static
 RKWardMainWindow *RKWardMainWindow::rkward_mainwin = 0;
 
-RKWardMainWindow::RKWardMainWindow (RKWardStartupOptions *options) : KParts::MainWindow ((QWidget *)0, (Qt::WindowFlags) KDE_DEFAULT_WINDOWFLAGS) {
+RKWardMainWindow::RKWardMainWindow () : KParts::MainWindow ((QWidget *)0, (Qt::WindowFlags) KDE_DEFAULT_WINDOWFLAGS) {
 	RK_TRACE (APP);
 	RK_ASSERT (rkward_mainwin == 0);
 
 	gui_rebuild_locked = true;
+	no_ask_save = true;
+	workspace_modified = false;
+	merge_loads = false;
 	rkward_mainwin = this;
 	RKGlobals::rinter = 0;
 	RKSettings::settings_tracker = new RKSettingsTracker (this);
@@ -133,13 +129,13 @@ RKWardMainWindow::RKWardMainWindow (RKWardStartupOptions *options) : KParts::Mai
 	new RKWorkplace (this);
 	RKWorkplace::mainWorkplace ()->initActions (actionCollection (), "left_window", "right_window");
 	setCentralWidget (RKWorkplace::mainWorkplace ());
-	connect (RKWorkplace::mainWorkplace ()->view (), SIGNAL (captionChanged (const QString &)), this, SLOT (setCaption (const QString &)));
-	connect (RKWorkplace::mainWorkplace (), SIGNAL (workspaceUrlChanged(const KUrl&)), this, SLOT (addWorkspaceUrl(const KUrl&)));
+	connect (RKWorkplace::mainWorkplace ()->view (), SIGNAL (captionChanged(QString)), this, SLOT (setCaption(QString)));
+	connect (RKWorkplace::mainWorkplace (), SIGNAL (workspaceUrlChanged(KUrl)), this, SLOT (addWorkspaceUrl(KUrl)));
 
 	part_manager = new KParts::PartManager (this);
 	// When the manager says the active part changes,
 	// the builder updates (recreates) the GUI
-	connect (partManager (), SIGNAL (activePartChanged (KParts::Part *)), this, SLOT (partChanged (KParts::Part *)));
+	connect (partManager (), SIGNAL (activePartChanged(KParts::Part*)), this, SLOT (partChanged(KParts::Part*)));
 
 	readOptions();
 	RKGlobals::mtracker = new RKModificationTracker (this);
@@ -159,10 +155,8 @@ RKWardMainWindow::RKWardMainWindow (RKWardStartupOptions *options) : KParts::Mai
 
 	RKComponentMap::initialize ();
 
-	startup_options = options;
-
 	// stuff which should wait until the event loop is running
-	QTimer::singleShot (0, this, SLOT (doPostInit ()));
+	QTimer::singleShot (0, this, SLOT (doPostInit()));
 }
 
 RKWardMainWindow::~RKWardMainWindow() {
@@ -200,14 +194,11 @@ void RKWardMainWindow::doPostInit () {
 	// Check installation first
 	QFile resource_ver (RKCommonFunctions::getRKWardDataDir () + "resource.ver");
 	if (!(resource_ver.open (QIODevice::ReadOnly) && (resource_ver.read (100).trimmed () == RKWARD_VERSION))) {
-		KMessageBox::error (this, i18n ("<p>RKWard either could not find its resource files at all, or only an old version of those files. The most likely cause is that the last installation failed to place the files in the correct place. This can lead to all sorts of problems, from single missing features to complete failure to function.</p><p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://p.sf.net/rkward/compiling\">http://p.sf.net/rkward/compiling</a>.</p>"), i18n ("Broken installation"), KMessageBox::Notify | KMessageBox::AllowLink);
+		KMessageBox::error (this, i18n ("<p>RKWard either could not find its resource files at all, or only an old version of those files. The most likely cause is that the last installation failed to place the files in the correct place. This can lead to all sorts of problems, from single missing features to complete failure to function.</p><p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://rkward.kde.org/compiling\">http://rkward.kde.org/compiling</a>.</p>"), i18n ("Broken installation"), KMessageBox::Notify | KMessageBox::AllowLink);
 	}
 
-	// startup options will be deleted from the R thread (TODO correct this!), so we need to copy the initial_url here, or run into race conditions
-	KUrl open_url = startup_options ? startup_options->initial_url : KUrl ();
-	QString evaluate_code = startup_options ? startup_options->evaluate : QString ();
-	delete startup_options;
-	startup_options = 0;
+	QVariantList open_urls = RKGlobals::startup_options.take ("initial_urls").toList ();
+	QString evaluate_code = RKGlobals::startup_options.take ("evaluate").toString ();
 
 	initPlugins ();
 	gui_rebuild_locked = false;
@@ -227,41 +218,62 @@ void RKWardMainWindow::doPostInit () {
 #endif
 
 	KUrl recover_url = RKRecoverDialog::checkRecoverCrashedWorkspace ();
-	if (!recover_url.isEmpty ()) open_url = recover_url;
-	if (!open_url.isEmpty () && (open_url.isRelative ())) {
-		// make sure local urls are absolute, as we may be changing wd before loading
-		open_url = KUrl::fromLocalFile (QDir::current ().absoluteFilePath (open_url.toLocalFile ()));
+	if (!recover_url.isEmpty ()) {
+		open_urls.clear ();
+		open_urls.append (recover_url);		// Well, not a perfect solution. But we certainly don't want to overwrite the just recovered workspace.
 	}
 
+	setMergeLoads (true);
+	for (int i = 0; i < open_urls.size (); ++i) {
+		// make sure local urls are absolute, as we may be changing wd before loading
+		KUrl url = open_urls[i].toUrl ();
+		if (url.isRelative ()) {
+			open_urls[i] = KUrl::fromLocalFile (QDir::current ().absoluteFilePath (url.toLocalFile ()));
+		}
+	}
+	setMergeLoads (false);
+
 	QString cd_to = RKSettingsModuleGeneral::initialWorkingDirectory ();
 	if (!cd_to.isEmpty ()) {
 		RKGlobals::rInterface ()->issueCommand ("setwd (" + RObject::rQuote (cd_to) + ")\n", RCommand::App);
 	}
 
-	if (!open_url.isEmpty()) {
-		openWorkspace (open_url);
+	if (!open_urls.isEmpty()) {
+		// this is also done when there are no urls specified on the command line. But in that case _after_ loading any workspace, so
+		// the help window will be on top
+		if (RKSettingsModuleGeneral::showHelpOnStartup ()) toplevel_actions->showRKWardHelp ();
+
+		for (int i = 0; i < open_urls.size (); ++i) {
+			RKWorkplace::mainWorkplace ()->openAnyUrl (open_urls[i].toUrl ());
+		}
 	} else {
 		StartupDialog::StartupDialogResult result = StartupDialog::getStartupAction (this, fileOpenRecentWorkspace);
 		if (!result.open_url.isEmpty ()) {
 			openWorkspace (result.open_url);
 		} else {
 			if (result.result == StartupDialog::ChoseFile) {
-				fileOpenNoSave (KUrl());
+				askOpenWorkspace (KUrl());
 			} else if (result.result == StartupDialog::EmptyTable) {
 				RKWorkplace::mainWorkplace ()->editNewDataFrame (i18n ("my.data"));
 			}
 		}
-	}
 
-	if (RKSettingsModuleGeneral::workplaceSaveMode () == RKSettingsModuleGeneral::SaveWorkplaceWithSession) {
-		RKWorkplace::mainWorkplace ()->restoreWorkplace (RKSettingsModuleGeneral::getSavedWorkplace (KGlobal::config ().data ()).split ('\n'));
+		if (RKSettingsModuleGeneral::workplaceSaveMode () == RKSettingsModuleGeneral::SaveWorkplaceWithSession) {
+			RKWorkplace::mainWorkplace ()->restoreWorkplace (RKSettingsModuleGeneral::getSavedWorkplace (KGlobal::config ().data ()).split ('\n'));
+		}
+		if (RKSettingsModuleGeneral::showHelpOnStartup ()) toplevel_actions->showRKWardHelp ();
 	}
+	setNoAskSave (false);
 
-	if (RKSettingsModuleGeneral::showHelpOnStartup ()) {
-		toplevel_actions->showRKWardHelp ();
-	}
+	// up to this point, no "real" save-worthy stuff can be pending in the backend. So mark this point as "clean".
+	RCommand *command = new RCommand (QString (), RCommand::EmptyCommand | RCommand::Sync | RCommand::App);
+	connect (command->notifier (), SIGNAL (commandFinished(RCommand*)), this, SLOT (setWorkspaceUnmodified()));
+	RKGlobals::rInterface ()->issueCommand (command);
 
 	if (!evaluate_code.isEmpty ()) RKConsole::pipeUserCommand (evaluate_code);
+	RKDBusAPI *dbus = new RKDBusAPI (this);
+	connect (this, SIGNAL(aboutToQuitRKWard()), dbus, SLOT(deleteLater()));	// RKWard sometimes needs to wait for R to quit. We don't want it sticking
+	// around on the bus in this case.
 
 	setCaption (QString ());	// our version of setCaption takes care of creating a correct caption, so we do not need to provide it here
 }
@@ -272,12 +284,12 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 
 	QStringList all_maps = RKSettingsModulePlugins::pluginMaps ();
 	if (all_maps.isEmpty()) {
-		KMessageBox::information (0, i18n ("Plugins are needed: you may manage these through \"Settings->Configure RKWard\".\n"), i18n ("No active plugin maps"));
+		KMessageBox::information (0, i18n ("Plugins are needed: you may manage these through \"Settings->Manage R package and plugins\".\n"), i18n ("No active plugin maps"));
 		return;
 	}
 
 	factory ()->removeClient (RKComponentMap::getMap ());
-	RKComponentMap::clearAll ();
+	RKComponentMap::getMap ()->clearAll ();
 
 	QStringList completely_broken_maps;
 	QStringList completely_broken_maps_details;
@@ -285,7 +297,7 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 	QStringList somewhat_broken_maps_details;
 	for (int i = 0; i < all_maps.size (); ++i) {
 		const QString &map = all_maps[i];
-		RKPluginMapParseResult result = RKComponentMap::addPluginMap (map);
+		RKPluginMapParseResult result = RKComponentMap::getMap ()->addPluginMap (map);
 		if (!result.valid_plugins) {
 			RKSettingsModulePlugins::markPluginMapAsBroken (map);
 			completely_broken_maps.append (map);
@@ -300,6 +312,7 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 		}
 	}
 
+	RKComponentMap::getMap ()->finalizeAll ();
 	factory ()->addClient (RKComponentMap::getMap ());
 
 	if (!automatically_added.isEmpty ()) {
@@ -353,8 +366,8 @@ void RKWardMainWindow::configureCarbonCopy () {
 	dialog->setMainWidget (settings);
 	dialog->setButtons (KDialog::Ok | KDialog::Apply | KDialog::Cancel);
 	dialog->setAttribute (Qt::WA_DeleteOnClose);
-	connect (dialog, SIGNAL (okClicked()), settings, SLOT (applyChanges ())); 
-	connect (dialog, SIGNAL (applyClicked()), settings, SLOT (applyChanges ())); 
+	connect (dialog, SIGNAL (okClicked()), settings, SLOT (applyChanges())); 
+	connect (dialog, SIGNAL (applyClicked()), settings, SLOT (applyChanges())); 
 	dialog->show ();
 }
 
@@ -407,7 +420,7 @@ void RKWardMainWindow::initActions() {
 	KAction *action;
 
 	// TODO: is there a way to insert actions between standard actions without having to give all standard actions custom ids?
-	new_data_frame = actionCollection ()->addAction ("new_data_frame", this, SLOT (slotNewDataFrame ()));
+	new_data_frame = actionCollection ()->addAction ("new_data_frame", this, SLOT (slotNewDataFrame()));
 	new_data_frame->setText (i18n ("Dataset"));
 	new_data_frame->setIcon (RKStandardIcons::getIcon (RKStandardIcons::WindowDataFrameEditor));
 	new_data_frame->setStatusTip (i18n ("Creates new empty dataset and opens it for editing"));
@@ -419,16 +432,21 @@ void RKWardMainWindow::initActions() {
 	fileOpen = actionCollection ()->addAction (KStandardAction::Open, "file_openy", this, SLOT(slotOpenCommandEditor()));
 	fileOpen->setText (i18n ("Open R Script File..."));
 
-	fileOpenRecent = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recenty", this, SLOT(slotOpenCommandEditor (const KUrl&))));
+	fileOpenRecent = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recenty", this, SLOT(slotOpenCommandEditor(KUrl))));
 	fileOpenRecent->setText (i18n ("Open Recent R Script File"));
 
+#if 0
+	// TODO: Fix import dialog and re-enable it: https://mail.kde.org/pipermail/rkward-devel/2015-June/004156.html
 #ifdef Q_WS_WIN
-	// TODO: find the cause and fix it! http://sourceforge.net/tracker/?func=detail&aid=2848341&group_id=50231&atid=459007
-#	warning TODO: import data dialog is disabled on windows due to bug in kdelibs
+	// TODO: find the cause and fix it! http://sourceforge.net/p/rkward/bugs/54/
+#	ifdef __GNUC__
+#		warning TODO: import data dialog is disabled on windows due to bug in kdelibs
+#	endif
 #else
 	action = actionCollection ()->addAction ("import_data", this, SLOT (importData()));
 	action->setText (i18n ("Import Data"));
 	action->setStatusTip (i18n ("Import data from a variety of file formats"));
+#endif
 #endif
 
 	fileOpenWorkspace = actionCollection ()->addAction (KStandardAction::Open, "file_openx", this, SLOT(slotFileOpenWorkspace()));
@@ -436,7 +454,7 @@ void RKWardMainWindow::initActions() {
 	fileOpenWorkspace->setShortcut (Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_O);
 	fileOpenWorkspace->setStatusTip (i18n ("Opens an existing document"));
 
-	fileOpenRecentWorkspace = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recentx", this, SLOT(slotFileOpenRecentWorkspace(const KUrl&))));
+	fileOpenRecentWorkspace = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recentx", this, SLOT(askOpenWorkspace(KUrl))));
 	fileOpenRecentWorkspace->setText (i18n ("Open Recent Workspace"));
 	fileOpenRecentWorkspace->setStatusTip (i18n ("Opens a recently used file"));
 
@@ -458,16 +476,16 @@ void RKWardMainWindow::initActions() {
 	interrupt_all_commands->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInterrupt));
 	interrupt_all_commands->setEnabled (false);		// enabled from within setRStatus()
 
-	action = actionCollection ()->addAction ("carbon_copy", this, SLOT (configureCarbonCopy ()));
+	action = actionCollection ()->addAction ("carbon_copy", this, SLOT (configureCarbonCopy()));
 	action->setText (i18n ("CC commands to output..."));
 
 	// These two currently do the same thing
 	action = actionCollection ()->addAction ("load_unload_libs", this, SLOT (slotFileLoadLibs()));
-	action->setText (i18n ("Manage R packages..."));
+	action->setText (i18n ("Manage R packages and plugins..."));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionConfigurePackages));
 
 	action = actionCollection ()->addAction ("configure_packages", this, SLOT (slotFileLoadLibs()));
-	action->setText (i18n ("Manage R packages..."));
+	action->setText (i18n ("Manage R packages and plugins..."));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionConfigurePackages));
 
 	setStandardToolBarMenuEnabled (true);
@@ -639,7 +657,7 @@ void RKWardMainWindow::openWorkspace (const KUrl &url) {
 	RK_TRACE (APP);
 	if (url.isEmpty ()) return;
 
-	new RKLoadAgent (url, false);
+	new RKLoadAgent (url, merge_loads);
 }
 
 void RKWardMainWindow::saveOptions () {
@@ -703,7 +721,7 @@ bool RKWardMainWindow::doQueryQuit () {
 
 //	if (!RObjectList::getGlobalEnv ()->isEmpty ()) {
 	int res;
-	res = KMessageBox::questionYesNoCancel (this, i18n ("Quitting RKWard: Do you want to save the workspace?"), i18n ("Save Workspace?"), KStandardGuiItem::save (), KStandardGuiItem::discard (), KGuiItem (i18n ("Don't quit")));
+	res = KMessageBox::questionYesNoCancel (this, i18n ("Quitting RKWard: Do you want to save the workspace?"), i18n ("Save Workspace?"), KStandardGuiItem::save (), KStandardGuiItem::discard (), KGuiItem (i18n ("Do Not Quit")));
 	if (res == KMessageBox::Yes) {
 		new RKSaveAgent (RKWorkplace::mainWorkplace ()->workspaceURL (), false, RKSaveAgent::DoNothing);
 	} else if (res == KMessageBox::Cancel) {
@@ -738,9 +756,19 @@ void RKWardMainWindow::slotNewDataFrame () {
 	if (ok) RKWorkplace::mainWorkplace ()->editNewDataFrame (name);
 }
 
-void RKWardMainWindow::fileOpenNoSave (const KUrl &url) {
+void RKWardMainWindow::askOpenWorkspace (const KUrl &url) {
 	RK_TRACE (APP);
 
+	if (!no_ask_save && ((!RObjectList::getGlobalEnv ()->isEmpty () && workspace_modified) || !RKGlobals::rInterface ()->backendIsIdle ())) {
+		int res;
+		res = KMessageBox::questionYesNoCancel (this, i18n ("Do you want to save the current workspace?"), i18n ("Save Workspace?"));
+		if (res == KMessageBox::Yes) {
+			new RKSaveAgent (RKWorkplace::mainWorkplace ()->workspaceURL (), false, RKSaveAgent::Load, url);
+		} else if (res != KMessageBox::No) { // Cancel
+			return;
+		}
+	}
+
 	slotCloseAllEditors ();
 
 	slotSetStatusBarText(i18n("Opening workspace..."));
@@ -748,7 +776,9 @@ void RKWardMainWindow::fileOpenNoSave (const KUrl &url) {
 	if (lurl.isEmpty ()) {
 #ifdef Q_WS_WIN
 	// getOpenUrl(KUrl("kfiledialog:///<rfiles>"), ...) causes a hang on windows (KDElibs 4.2.3).
-#	warning Track this bug down and/or report it
+#	ifdef __GNUC__
+#		warning Track this bug down and/or report it
+#	endif
 		lurl = KFileDialog::getOpenUrl (KUrl (), i18n("%1|R Workspace Files (%1)\n*|All files", RKSettingsModuleGeneral::workspaceFilenameFilter ()), this, i18n("Select workspace to open..."));
 #else
 		lurl = KFileDialog::getOpenUrl (KUrl ("kfiledialog:///<rfiles>"), i18n("%1|R Workspace Files (%1)\n*|All files", RKSettingsModuleGeneral::workspaceFilenameFilter ()), this, i18n("Select workspace to open..."));
@@ -760,32 +790,9 @@ void RKWardMainWindow::fileOpenNoSave (const KUrl &url) {
 	slotSetStatusReady ();
 }
 
-void RKWardMainWindow::fileOpenAskSave (const KUrl &url) {
-	RK_TRACE (APP);
-	if (RObjectList::getObjectList ()->isEmpty ()) {
-		fileOpenNoSave (url);
-		return;
-	}
-	
-	int res;
-	res = KMessageBox::questionYesNoCancel (this, i18n ("Do you want to save the current workspace?"), i18n ("Save Workspace?"));
-	if (res == KMessageBox::No) {
-		fileOpenNoSave (url);
-	} else if (res == KMessageBox::Yes) {
-		new RKSaveAgent (RKWorkplace::mainWorkplace ()->workspaceURL (), false, RKSaveAgent::Load, url);
-	}
-	// else: cancel. Don't do anything
-}
-
 void RKWardMainWindow::slotFileOpenWorkspace () {
 	RK_TRACE (APP);
-	fileOpenAskSave (KUrl ());
-}
-
-void RKWardMainWindow::slotFileOpenRecentWorkspace(const KUrl& url)
-{
-	RK_TRACE (APP);
-	fileOpenAskSave (url);
+	askOpenWorkspace (KUrl ());
 }
 
 void RKWardMainWindow::slotFileLoadLibs () {
@@ -808,7 +815,7 @@ void RKWardMainWindow::addWorkspaceUrl (const KUrl &url) {
 	RK_TRACE (APP);
 
 	if (!url.isEmpty ()) fileOpenRecentWorkspace->addUrl (url);
-	setCaption (QString::null);	// trigger update of caption
+	setCaption (QString ());	// trigger update of caption
 }
 
 void RKWardMainWindow::updateCWD () {
@@ -822,7 +829,7 @@ void RKWardMainWindow::slotSetStatusBarText (const QString &text) {
 
 //KDE4: still needed?
 	QString ntext = text.trimmed ();
-	ntext.replace ("<qt>", "");	// WORKAROUND: what the ?!? is going on? The KTHMLPart seems to post such messages.
+	ntext.replace ("<qt>", QString ());	// WORKAROUND: what the ?!? is going on? The KTHMLPart seems to post such messages.
 	if (ntext.isEmpty ()) {
 		statusBar ()->clearMessage ();
 	} else {
@@ -907,7 +914,9 @@ void RKWardMainWindow::slotOpenCommandEditor () {
 
 #ifdef Q_WS_WIN
 	// getOpenUrls(KUrl("kfiledialog:///<rfiles>"), ...) causes a hang on windows (KDElibs 4.2.3).
-#	warning Track this bug down and/or report it
+#	ifdef __GNUC__
+#		warning Track this bug down and/or report it
+#	endif
 	res = KEncodingFileDialog::getOpenUrlsAndEncoding (QString (), QString (), QString ("%1|R Script Files (%1)\n*|All Files (*)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()), this, i18n ("Open script file(s)"));
 #else
 	res = KEncodingFileDialog::getOpenUrlsAndEncoding (QString (), "kfiledialog:///<rfiles>", QString ("%1|R Script Files (%1)\n*|All Files (*)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()), this, i18n ("Open script file(s)"));
@@ -917,12 +926,6 @@ void RKWardMainWindow::slotOpenCommandEditor () {
 	}
 };
 
-void RKWardMainWindow::openHTML (const KUrl &url) {
-	RK_TRACE (APP);
-
-	RKWorkplace::mainWorkplace ()->openHelpWindow (url);
-}
-
 void RKWardMainWindow::setCaption (const QString &) {
 	RK_TRACE (APP);
 
