@@ -2,8 +2,8 @@
                           rkward.h  -  description
                              -------------------
     begin                : Tue Oct 29 20:06:08 CET 2002
-    copyright            : (C) 2002-2013 by Thomas Friedrichsmeier 
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002-2014 by Thomas Friedrichsmeier 
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,33 +31,20 @@ class KRecentFilesAction;
 class KSqueezedTextLabel;
 class QAction;
 
-struct RKWardStartupOptions {
-	KUrl initial_url;	/**< The workspace file to load on startup. If empty, show a dialog asking what to do. **/
-	QString evaluate;	/**< R code to run after startup */
-};
-
 /**
-The main class of rkward. This is where all strings are tied togther, controlls the initialization, and there are some of the most important slots for user actions. All real work is done elsewhere.
+The main class of rkward. This is where all strings are tied together, controls the initialization, and there are some of the most important slots for user actions. All real work is done elsewhere.
 */
 class RKWardMainWindow : public KParts::MainWindow {
 	Q_OBJECT
 public:
-/** construtor
-@param options Options from command line. RKWardMainWindow will take ownership of this pointer, and delete it, once not longer needed. */
-	RKWardMainWindow (RKWardStartupOptions *options = 0);
+/** construtor */
+	RKWardMainWindow ();
 /** destructor */
 	~RKWardMainWindow ();
 
 /** initialize the backend */
 	void startR ();
 
-/** open a workspace. Do not ask whether to save the old one. The old workspace is deleted! */
-	void fileOpenNoSave (const KUrl &url);
-/** open a workspace. If the current workspace is not empty, ask wether to save first. */
-	void fileOpenAskSave (const KUrl &url);
-/** opens the given url, assuming it is an HTML-help page. */
-	void openHTML (const KUrl &url);
-
 	KParts::PartManager *partManager () { return part_manager; };
 
 	static RKWardMainWindow *getMain () { return rkward_mainwin; };
@@ -65,8 +52,14 @@ public:
 /** (try to) close all windows, and ask whether it is ok to quit */
 	bool doQueryQuit ();
 	void lockGUIRebuild (bool lock);
+/** Set whether not to ask for saving, although the workspace @em might be modified */
+	void setNoAskSave (bool no_ask) { no_ask_save = no_ask; };
+/** Set whether workspace is known to be unmodified, or could be modified.
+    TODO: Some less guessing would be nice... */
+	void setWorkspaceMightBeModified (bool modified) { workspace_modified = modified; };
+/** Merge files to be loaded, instead of closing windows / clearing workspace */
+	void setMergeLoads (bool merge) { merge_loads = merge; };
 protected:
-	void openWorkspace (const KUrl &url);
 	/** save Options/Settings. Includes general Options like all bar positions and status as well as the geometry and the recent file list */
 	void saveOptions();
 /** read general Options again and initialize all variables like the recent file list */
@@ -83,12 +76,15 @@ protected:
 signals:
 	void aboutToQuitRKWard ();
 public slots:
+	void setWorkspaceUnmodified () { setWorkspaceMightBeModified (false); };
+	/** open a workspace. If the current workspace is not empty, ask whether to save first.
+    @see setNoAskSave ()
+    @see setWorkspaceMightBeModified () */
+	void askOpenWorkspace (const KUrl &url);
 	/** creates a new (empty) data.frame */
 	void slotNewDataFrame ();
 	/** open a file and load it into the document*/
 	void slotFileOpenWorkspace();
-	/** opens a file from the recent files menu */
-	void slotFileOpenRecentWorkspace(const KUrl& url);
 	/** save a document */
 	void slotFileSaveWorkspace();
 	/** save a document by a new filename*/
@@ -105,8 +101,8 @@ public slots:
 	void slotCancelAllCommands ();
 	void configureCarbonCopy ();
 	void slotSetStatusBarText (const QString &text);
-/** Basically a shortcut to slotSetStatusBarText (QString::null). Needed as a slot without parameters. */
-	void slotSetStatusReady () { slotSetStatusBarText (QString::null); };
+/** Basically a shortcut to slotSetStatusBarText (QString ()). Needed as a slot without parameters. */
+	void slotSetStatusReady () { slotSetStatusBarText (QString ()); };
 
 /** configures RKward-settings */
 	void slotConfigure ();
@@ -140,6 +136,9 @@ public slots:
 private slots:
 	void partChanged (KParts::Part *new_part);
 private:
+/** Opens a new workspace, without asking or closing anything. */
+	void openWorkspace (const KUrl &url);
+
 	QLabel* statusbar_r_status;
 	KSqueezedTextLabel* statusbar_cwd;
 	QLabel* statusbar_ready;
@@ -177,12 +176,11 @@ private:
 	friend class RKSettingsModule;
 	friend class RKSettingsModulePlugins;
 	friend class RKSettings;
+	friend class RKComponentMap;
 
 	/** Finds plugins and inserts them into the menu-structure */
 	void initPlugins (const QStringList &automatically_added = QStringList ());
 
-	RKWardStartupOptions *startup_options;
-
 	static RKWardMainWindow *rkward_mainwin;
 
 	friend class RInterface;
@@ -198,6 +196,9 @@ private:
 
 	RKTopLevelWindowGUI *toplevel_actions;
 	bool gui_rebuild_locked;
+	bool no_ask_save;
+	bool workspace_modified;
+	bool merge_loads;
 };
 
 #endif // RKWARD_H
