@@ -2,8 +2,8 @@
                           qtscriptbackend  -  description
                              -------------------
     begin                : Mon Sep 28 2009
-    copyright            : (C) 2009, 2010, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2009, 2010, 2012, 2014, 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -23,14 +23,16 @@
 #include "kmessagebox.h"
 
 #include "../misc/rkcommonfunctions.h"
+#include "qtscripti18n.h"
 
 #include "../debug.h"
 
-QtScriptBackend::QtScriptBackend (const QString &filename) : ScriptBackend () {
+QtScriptBackend::QtScriptBackend (const QString &filename, const RKMessageCatalog *catalog) : ScriptBackend () {
 	RK_TRACE (PHP);
 
 	script_thread = 0;
 	QtScriptBackend::filename = filename;
+	QtScriptBackend::catalog = catalog;
 	dead = false;
 	busy = true;
 }
@@ -53,10 +55,10 @@ bool QtScriptBackend::initialize (RKComponentPropertyCode *code_property, bool a
 	QDir files_path (RKCommonFunctions::getRKWardDataDir () + "phpfiles/");
 	QString common_js (files_path.absoluteFilePath ("common.js"));
 
-	script_thread = new QtScriptBackendThread (common_js, filename, this);
-	connect (script_thread, SIGNAL (error(const QString&)), this, SLOT (threadError(const QString&)));
-	connect (script_thread, SIGNAL (commandDone(const QString&)), this, SLOT (commandDone(const QString&)));
-	connect (script_thread, SIGNAL (needData(const QString&, const int)), this, SLOT (needData(const QString&, const int)));
+	script_thread = new QtScriptBackendThread (common_js, filename, this, catalog);
+	connect (script_thread, SIGNAL (error(QString)), this, SLOT (threadError(QString)));
+	connect (script_thread, SIGNAL (commandDone(QString)), this, SLOT (commandDone(QString)));
+	connect (script_thread, SIGNAL (needData(QString,int)), this, SLOT (needData(QString,int)));
 	current_type = ScriptBackend::Ignore;
 	script_thread->start ();
 
@@ -141,13 +143,16 @@ void QtScriptBackend::needData (const QString &identifier, const int hint) {
 
 #include <kurl.h>
 
-QtScriptBackendThread::QtScriptBackendThread (const QString &commonfile, const QString &scriptfile, QtScriptBackend *parent) : QThread (parent) {
+QtScriptBackendThread::QtScriptBackendThread (const QString &commonfile, const QString &scriptfile, QtScriptBackend *parent, const RKMessageCatalog *catalog) : QThread (parent), engine (0) {
 	RK_TRACE (PHP);
 
+	// you'd think the engine already was in this thread, but no, it is not. You'd also think, this was fixable by setting "this" as the engine's parent, instead of 0, but no, somehow not.
+	engine.moveToThread (this);
 	_commonfile = commonfile;
 	_scriptfile = scriptfile;
 	killed = false;
 	sleeping = false;
+	QtScriptBackendThread::catalog = catalog;
 }
 
 QtScriptBackendThread::~QtScriptBackendThread () {
@@ -226,6 +231,10 @@ QVariant QtScriptBackendThread::getBoolean (const QString &identifier) {
 	return getValue (identifier, RKStandardComponent::BooleanValue);
 }
 
+QVariant QtScriptBackendThread::getUiLabelPair (const QString &identifier) {
+	return getValue (identifier, RKStandardComponent::UiLabelPair);
+}
+
 bool QtScriptBackendThread::scriptError () {
 	RK_TRACE (PHP);
 
@@ -248,15 +257,15 @@ bool QtScriptBackendThread::includeFile (const QString &filename) {
 		_filename = script_path.toLocalFile ();
 	}
 
-        QFile file (_filename);
-        if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
+		QFile file (_filename);
+		if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
 		emit (error (i18n ("The file \"%1\" (needed by \"%2\") could not be found. Please check your installation.", _filename, _scriptfile)));
 		return false;
 	}
 
 	// evaluate in global context
 	engine.currentContext ()->setActivationObject (engine.globalObject ());
-	QScriptValue result = engine.evaluate (file.readAll(), _filename);
+	QScriptValue result = engine.evaluate (QString::fromUtf8 (file.readAll ()), _filename);
 
 	if (scriptError ()) return false;
 
@@ -268,8 +277,21 @@ void QtScriptBackendThread::run () {
 
 	QScriptValue backend_object = engine.newQObject (this);
 	engine.globalObject ().setProperty ("_RK_backend", backend_object);
+	RKMessageCatalogObject::addI18nToScriptEngine (&engine, catalog);
+	if (scriptError ()) return;
 
+#ifdef USE_Q_SCRIPT_PROGRAM
+	if (!RKPrecompiledQtScripts::loadCommonScript (&engine, _commonfile)) {
+		if (!engine.hasUncaughtException ()) {
+			emit error (i18n ("Could not open common script file \"%1\"", _commonfile));
+		} else {
+			scriptError ();
+		}
+		return;
+	}
+#else
 	if (!includeFile (_commonfile)) return;
+#endif
 	if (!includeFile (_scriptfile)) return;
 
 	emit (commandDone ("startup complete"));
@@ -303,4 +325,41 @@ void QtScriptBackendThread::run () {
 	}
 }
 
+#ifdef USE_Q_SCRIPT_PROGRAM
+namespace RKPrecompiledQtScripts {
+	QMap<QString, QScriptProgram> compiled_includes;
+	QMutex compiled_includes_mutex;
+
+	bool loadCommonScript (QScriptEngine* engine, QString scriptfile) {
+		RK_TRACE (PHP);
+
+		// NOTE: QScriptProgram cannot be evaluated concurrently in several threads (see https://bugreports.qt-project.org/browse/QTBUG-29246).
+		// Neither would our QMap caching logic work in concurrent threads. Thus the mutex. This clearly has the drawback that QScript evaluation threads
+		// may be waiting for each other during initialization. However, we assume that
+		// - Typically only few such threads are running
+		// - Responsiveness (i.e. UI startup speed), not throughput is the main goal, here.
+		// - The important script engines are those running in the UI thread (and thus necessarily sequentially). As long as these are initialized before
+		//   the other threads, they will clearly profit from pre-compiling
+		QMutexLocker ml (&compiled_includes_mutex);
+		if (!compiled_includes.contains (scriptfile)) {
+			RK_DEBUG (PHP, DL_DEBUG, "Compiling common script file %s", qPrintable (scriptfile));
+			QFile file (scriptfile);
+			if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
+				return false;
+			}
+			compiled_includes.insert (scriptfile, QScriptProgram (QString::fromUtf8 (file.readAll ()), scriptfile));
+			file.close ();
+		} else {
+			RK_DEBUG (PHP, DL_DEBUG, "Script file %s is already compiled", qPrintable (scriptfile));
+		}
+		engine->evaluate (compiled_includes[scriptfile]);
+		if (engine->hasUncaughtException ()) {
+			compiled_includes.remove (scriptfile);
+			return false;
+		}
+		return true;
+	}
+}
+#endif
+
 #include "qtscriptbackend.moc"
