@@ -2,8 +2,8 @@
                           simplebackend  -  description
                              -------------------
     begin                : Thu May 10 2007
-    copyright            : (C) 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2007, 2012 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -46,28 +46,28 @@ void SimpleBackend::destroy () {
 void SimpleBackend::preprocess (int flags) {
 	RK_TRACE (PHP);
 
-	callFunction (QString::null, flags, Preprocess);
+	callFunction (QString (), flags, Preprocess);
 }
 
 void SimpleBackend::calculate (int flags) {
 	RK_TRACE (PHP);
 
-	callFunction (QString::null, flags, Calculate);
+	callFunction (QString (), flags, Calculate);
 }
 
 void SimpleBackend::printout (int flags) {
 	RK_TRACE (PHP);
 
-	callFunction (QString::null, flags, Printout);
+	callFunction (QString (), flags, Printout);
 }
 
 void SimpleBackend::preview (int flags) {
 	RK_TRACE (PHP);
 
-	callFunction (QString::null, flags, Preview);
+	callFunction (QString (), flags, Preview);
 }
 
-void SimpleBackend::writeData (const QString &data) {
+void SimpleBackend::writeData (const QVariant &data) {
 	RK_TRACE (PHP);
 
 	current_values.append (data);
@@ -120,7 +120,7 @@ void SimpleBackend::processCall () {
 		RK_ASSERT (token_end >= 0);
 		QString token = current_template.mid (next_token + 3, token_end - (next_token + 3));
 		template_pos = token_end + 3;
-		emit (requestValue (token));
+		emit (requestValue (token, RKStandardComponent::StringValue));
 		return;
 	}
 
@@ -134,8 +134,8 @@ void SimpleBackend::finishCall (const QString &conditions) {
 	QString conds = conditions;
 	int repl = current_values.count();
 	for (int i = repl; i > 0; --i) {
-		QString placeholder = "%" + QString::number (i);
-		QString replacement = current_values[i-1];
+		QString placeholder = '%' + QString::number (i);
+		QString replacement = current_values[i-1].toString ();
 		conds.replace (placeholder, replacement);
 	}
 
