@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu May 10 2007
     copyright            : (C) 2007, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
