@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Oct 23 2007
     copyright            : (C) 2007, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -216,7 +216,7 @@ bool RKSettingsModuleCommandEditor::matchesScriptFileFilter (const QString &file
 	RK_TRACE (SETTINGS);
 
 	const QStringList exts = script_file_filter.split (' ');
-	foreach (const QString ext, exts) {
+	foreach (const QString& ext, exts) {
 		QRegExp reg (ext, Qt::CaseInsensitive, QRegExp::Wildcard);
 		if (reg.exactMatch (filename)) return true;
 	}
