@@ -2,8 +2,8 @@
                           rksettingsmodulegeneral  -  description
                              -------------------
     begin                : Fri Jul 30 2004
-    copyright            : (C) 2004-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004-2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -78,11 +78,17 @@ public:
 	static RKMDIFocusPolicy mdiFocusPolicy () { return mdi_focus_policy; }
 	static QString workspaceFilenameFilter () { return ("*.RData *.RDA"); };
 	static QString initialWorkingDirectory ();
+/** if the installation-path of KDE seems to have moved since the last startup, *and* the given path is relative to the
+ *  KDE data path, adjust the given path (probably loaded from config), accordingly. @See RKCommonFunctions::getRKWardDataDir()
+ *  TODO: similar, but not quite identical functionality in rkworkplace.cpp checkAdjustRestoredUrl(). Might be mergeable. */
+	static QString checkAdjustLoadedPath (const QString &localpath);
 
 	enum RKWardConfigVersion {
 		RKWardConfig_Pre0_5_7,
 		RKWardConfig_0_5_7,
 		RKWardConfig_0_6_1,
+		RKWardConfig_0_6_3,
+		RKWardConfig_0_6_4,
 		RKWardConfig_Next,		/**< add new configuration versions above / before this entry */
 		RKWardConfig_Latest = RKWardConfig_Next - 1
 	};
@@ -121,6 +127,8 @@ private:
 	static InitialDirectory initial_dir;
 	static QString initial_dir_specification;
 	static bool rkward_version_changed;
+	static QString previous_rkward_data_dir;
+	static bool installation_moved;
 };
 
 #endif
