@@ -2,8 +2,8 @@
                           rksettingsmodulegraphics  -  description
                              -------------------
     begin                : Mon Sep 13 2010
-    copyright            : (C) 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2010, 2013 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,10 +21,13 @@
 
 #include <QStringList>
 
+class QLineEdit;
 class QGroupBox;
 class RKSpinBox;
 class KIntSpinBox;
 class QCheckBox;
+class QButtonGroup;
+class QRadioButton;
 
 /**
 @author Thomas Friedrichsmeier
@@ -50,10 +53,27 @@ public:
 	QString caption ();
 	QString helpURL () { return ("rkward://page/rkward_plot_history#scd_settings"); };
 
+	enum DefaultDevice {
+		RKDevice,
+		PlatformDevice,
+		OtherDevice
+	};
+	enum StandardDevicesMode {
+		ReplaceDevice,
+		EmbedDevice,
+		LeaveDevice
+	};
+	
 	static bool plotHistoryEnabled () { return graphics_hist_enable; };
 public slots:
 	void boxChanged ();
 private:
+	void updateControls ();
+
+	QButtonGroup *default_device_group;
+	QLineEdit *default_device_other_edit;
+	QButtonGroup *replace_standard_devices_group;
+
 	QGroupBox *graphics_hist_box;
 	KIntSpinBox *graphics_hist_max_length_box;
 	KIntSpinBox *graphics_hist_max_plotsize_box;
@@ -63,6 +83,10 @@ private:
 
 	QCheckBox *kde_printing_box;
 
+	static DefaultDevice default_device;
+	static QString default_device_other;
+	static StandardDevicesMode replace_standard_devices;
+
 	static bool graphics_hist_enable;
 	static int graphics_hist_max_length;
 	static int graphics_hist_max_plotsize;
