@@ -2,8 +2,8 @@
                           rksettingsmodule  -  description
                              -------------------
     begin                : Fri Apr 22 2005
-    copyright            : (C) 2005 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -30,55 +30,27 @@
 #include "../rkglobals.h"
 #include "../misc/multistringselector.h"
 #include "rksettings.h"
+#include "rksettingsmodulegeneral.h"
 #include "../debug.h"
 
 // static
-bool RKSettingsModuleObjectBrowser::settings[RKObjectListViewSettings::SettingsCount];
+bool RKSettingsModuleObjectBrowser::workspace_settings[RKObjectListViewSettings::SettingsCount];
+bool RKSettingsModuleObjectBrowser::varselector_settings[RKObjectListViewSettings::SettingsCount];
 QStringList RKSettingsModuleObjectBrowser::getstructure_blacklist;
 
 RKSettingsModuleObjectBrowser::RKSettingsModuleObjectBrowser (RKSettings *gui, QWidget *parent) : RKSettingsModule (gui, parent) {
 	RK_TRACE (SETTINGS);
 
-	checkboxes = new QCheckBox*[RKObjectListViewSettings::SettingsCount];
-
 	QVBoxLayout *layout = new QVBoxLayout (this);
 
-	layout->addWidget (new QLabel (i18n ("Which objects should be shown by default?"), this));
-
-	checkboxes[RKObjectListViewSettings::ShowObjectsHidden] = new QCheckBox (i18n ("Show hidden objects"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowObjectsHidden]);
-	checkboxes[RKObjectListViewSettings::ShowObjectsAllEnvironments] = new QCheckBox (i18n ("Show all environments"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowObjectsAllEnvironments]);
-	layout->addSpacing (2*RKGlobals::spacingHint ());
-	checkboxes[RKObjectListViewSettings::ShowObjectsContainer] = new QCheckBox (i18n ("Show objects with children"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowObjectsContainer]);
-	checkboxes[RKObjectListViewSettings::ShowObjectsFunction] = new QCheckBox (i18n ("Show functions"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowObjectsFunction]);
-	checkboxes[RKObjectListViewSettings::ShowObjectsVariable] = new QCheckBox (i18n ("Show variables"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowObjectsVariable]);
-
-	layout->addSpacing (2*RKGlobals::spacingHint ());
-
-	layout->addWidget (new QLabel (i18n ("Which columns should be shown by default?"), this));
-
-	checkboxes[RKObjectListViewSettings::ShowFieldsLabel] = new QCheckBox (i18n ("Label field"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowFieldsLabel]);
-	checkboxes[RKObjectListViewSettings::ShowFieldsType] = new QCheckBox (i18n ("Type field"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowFieldsType]);
-	checkboxes[RKObjectListViewSettings::ShowFieldsClass] = new QCheckBox (i18n ("Class field"), this);
-	layout->addWidget (checkboxes[RKObjectListViewSettings::ShowFieldsClass]);
-
-	layout->addStretch ();
-
-	for (int i = 0; i < RKObjectListViewSettings::SettingsCount; ++i) {
-		checkboxes[i]->setChecked (settings[i]);
-		connect (checkboxes[i], SIGNAL (stateChanged (int)), this, SLOT (boxChanged (int)));
-	}
+	// Note: Up to RKWard 0.6.3, this settings module had a lot of additional checkboxes. Since 0.6.4, most settings are stored, implictily,
+	//       i.e. the Workspace Browser tool window "remembers" its latest settings (and so does the Varselector, separately). This modules
+	//       is still responsible to storing / loading settings.
 
 	blacklist_choser = new MultiStringSelector (i18n ("Never fetch the structure of these packages:"), this);
 	blacklist_choser->setValues (getstructure_blacklist);
-	connect (blacklist_choser, SIGNAL (listChanged ()), this, SLOT (listChanged ()));
-	connect (blacklist_choser, SIGNAL (getNewStrings (QStringList*)), this, SLOT (addBlackList (QStringList*)));
+	connect (blacklist_choser, SIGNAL (listChanged()), this, SLOT (listChanged()));
+	connect (blacklist_choser, SIGNAL (getNewStrings(QStringList*)), this, SLOT (addBlackList(QStringList*)));
 	layout->addWidget (blacklist_choser);
 }
 
@@ -87,9 +59,15 @@ RKSettingsModuleObjectBrowser::~RKSettingsModuleObjectBrowser () {
 }
 
 //static
-bool RKSettingsModuleObjectBrowser::isSettingActive (RKObjectListViewSettings::Settings setting) {
+void RKSettingsModuleObjectBrowser::setDefaultForWorkspace (RKObjectListViewSettings::PersistentSettings setting, bool state) {
 	RK_TRACE (SETTINGS);
-	return settings[setting];
+	workspace_settings[setting] = state;
+}
+
+//static
+void RKSettingsModuleObjectBrowser::setDefaultForVarselector (RKObjectListViewSettings::PersistentSettings setting, bool state) {
+	RK_TRACE (SETTINGS);
+	varselector_settings[setting] = state;
 }
 
 //static
@@ -100,21 +78,13 @@ bool RKSettingsModuleObjectBrowser::isPackageBlacklisted (const QString &package
 
 void RKSettingsModuleObjectBrowser::addBlackList (QStringList *string_list) {
 	RK_TRACE (SETTINGS);
-	QString new_string = KInputDialog::getText (i18n ("Add exclusion"), i18n ("Add the name of the package that no structure should be fetched for"), QString::null, 0, this);
+	QString new_string = KInputDialog::getText (i18n ("Add exclusion"), i18n ("Add the name of the package that no structure should be fetched for"), QString (), 0, this);
 	(*string_list).append (new_string);
 }
 
-bool RKSettingsModuleObjectBrowser::hasChanges () {
-	RK_TRACE (SETTINGS);
-	return changed;
-}
-
 void RKSettingsModuleObjectBrowser::applyChanges () {
 	RK_TRACE (SETTINGS);
 
-	for (int i = 0; i < RKObjectListViewSettings::SettingsCount; ++i) {
-		settings[i] = checkboxes[i]->isChecked ();
-	}
 	getstructure_blacklist = blacklist_choser->getValues();
 }
 
@@ -128,21 +98,31 @@ QString RKSettingsModuleObjectBrowser::caption () {
 	return (i18n ("Workspace"));
 }
 
+void writeSettings (KConfigGroup &cg, bool *settings) {
+	cg.writeEntry ("show hidden vars", settings[RKObjectListViewSettings::ShowObjectsHidden]);
+	cg.writeEntry ("show label field", settings[RKObjectListViewSettings::ShowFieldsLabel]);
+	cg.writeEntry ("show type field", settings[RKObjectListViewSettings::ShowFieldsType]);
+	cg.writeEntry ("show class field", settings[RKObjectListViewSettings::ShowFieldsClass]);
+}
+
 //static
 void RKSettingsModuleObjectBrowser::saveSettings (KConfig *config) {
 	RK_TRACE (SETTINGS);
 
 	KConfigGroup cg = config->group ("Object Browser");
-	cg.writeEntry ("show hidden vars", settings[RKObjectListViewSettings::ShowObjectsHidden]);
-	cg.writeEntry ("show all environments", settings[RKObjectListViewSettings::ShowObjectsAllEnvironments]);
-	cg.writeEntry ("show container objects", settings[RKObjectListViewSettings::ShowObjectsContainer]);
-	cg.writeEntry ("show function objects", settings[RKObjectListViewSettings::ShowObjectsFunction]);
-	cg.writeEntry ("show variable objects", settings[RKObjectListViewSettings::ShowObjectsVariable]);
-	cg.writeEntry ("show label field", settings[RKObjectListViewSettings::ShowFieldsLabel]);
-	cg.writeEntry ("show type field", settings[RKObjectListViewSettings::ShowFieldsType]);
-	cg.writeEntry ("show class field", settings[RKObjectListViewSettings::ShowFieldsClass]);
-
 	cg.writeEntry ("package blacklist", getstructure_blacklist);
+
+	KConfigGroup toolgroup = cg.group ("Tool window");
+	writeSettings (toolgroup, workspace_settings);
+	KConfigGroup varselgroup = cg.group ("Varselector");
+	writeSettings (varselgroup, varselector_settings);
+}
+
+void readSettings (const KConfigGroup &cg, bool *settings) {
+	settings[RKObjectListViewSettings::ShowObjectsHidden] = cg.readEntry ("show hidden vars", false);
+	settings[RKObjectListViewSettings::ShowFieldsLabel] = cg.readEntry ("show label field", true);
+	settings[RKObjectListViewSettings::ShowFieldsType] = cg.readEntry ("show type field", true);
+	settings[RKObjectListViewSettings::ShowFieldsClass] = cg.readEntry ("show class field", true);
 }
 
 //static
@@ -150,16 +130,10 @@ void RKSettingsModuleObjectBrowser::loadSettings (KConfig *config) {
 	RK_TRACE (SETTINGS);
 
 	KConfigGroup cg = config->group ("Object Browser");
-	settings[RKObjectListViewSettings::ShowObjectsHidden] = cg.readEntry ("show hidden vars", false);
-	settings[RKObjectListViewSettings::ShowObjectsAllEnvironments] = cg.readEntry ("show all environments", true);
-	settings[RKObjectListViewSettings::ShowObjectsContainer] = cg.readEntry ("show container objects", true);
-	settings[RKObjectListViewSettings::ShowObjectsFunction] = cg.readEntry ("show function objects", true);
-	settings[RKObjectListViewSettings::ShowObjectsVariable] = cg.readEntry ("show variable objects", true);
-	settings[RKObjectListViewSettings::ShowFieldsLabel] = cg.readEntry ("show label field", true);
-	settings[RKObjectListViewSettings::ShowFieldsType] = cg.readEntry ("show type field", true);
-	settings[RKObjectListViewSettings::ShowFieldsClass] = cg.readEntry ("show class field", true);
-
 	getstructure_blacklist = cg.readEntry ("package blacklist", QStringList ("GO"));
+
+	readSettings (cg.group ("Tool window"), workspace_settings);
+	readSettings (cg.group ("Varselector"), varselector_settings);
 }
 
 void RKSettingsModuleObjectBrowser::boxChanged (int) {
