@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Jul 28 2004
     copyright            : (C) 2004-2014 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -246,7 +246,7 @@ QString RKSettingsModulePlugins::findPluginMapById (const QString &id) {
 	}
 	// for "rkward::" namespace, try a little harded:
 	if (id.startsWith ("rkward::")) {
-		QFileInfo info (RKCommonFunctions::getRKWardDataDir () + "/" + id.mid (8));
+		QFileInfo info (RKCommonFunctions::getRKWardDataDir () + '/' + id.mid (8));
 		if (info.isReadable ()) return info.absoluteFilePath ();
 	}
 
@@ -385,12 +385,12 @@ QStringList RKSettingsModulePlugins::findPluginMapsRecursive (const QString &bas
 	foreach (const QString &map, maps) ret.append (dir.absoluteFilePath (map));
 
 	QStringList subdirs = dir.entryList (QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
-	foreach (const QString subdir, subdirs) {
+	foreach (const QString& subdir, subdirs) {
 #if QT_VERSION >= 0x040500
 		ret.append (findPluginMapsRecursive (dir.absoluteFilePath (subdir)));
 #else
 		QStringList subs = findPluginMapsRecursive (dir.absoluteFilePath (subdir));
-		foreach (const QString sub, subs) ret.append (sub);
+		foreach (const QString& sub, subs) ret.append (sub);
 #endif
 	}
 
