@@ -2,8 +2,8 @@
                           rksettingsmoduler  -  description
                              -------------------
     begin                : Wed Jul 28 2004
-    copyright            : (C) 2004-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004-2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,6 +31,9 @@
 #include <QGridLayout>
 #include <QPushButton>
 #include <QTextEdit>
+#ifdef Q_WS_WIN
+#	include <QFileDialog>
+#endif
 
 #include "rksettingsmodulegeneral.h"
 #include "../core/robject.h"
@@ -38,6 +41,7 @@
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rkcommonfunctions.h"
 #include "../rbackend/rinterface.h"
+#include "../rbackend/rksessionvars.h"
 #include "../rkglobals.h"
 #include "../debug.h"
 
@@ -85,32 +89,32 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 	warn_input->insertItem (2, i18n ("Print warnings immediately"));
 	warn_input->insertItem (3, i18n ("Convert warnings to errors"));
 	warn_input->setCurrentIndex (options_warn + 1);
-	connect (warn_input, SIGNAL (activated (int)), this, SLOT (settingChanged()));
+	connect (warn_input, SIGNAL (activated(int)), this, SLOT (settingChanged()));
 	grid->addWidget (warn_input, row, 1);
 
 	// options (OutDec)
 	grid->addWidget (new QLabel (i18n ("Decimal character (only for printing)"), this), ++row, 0);
 	outdec_input = new QLineEdit (options_outdec, this);
 	outdec_input->setMaxLength (1);
-	connect (outdec_input, SIGNAL (textChanged (const QString &)), this, SLOT (settingChanged()));
+	connect (outdec_input, SIGNAL (textChanged(QString)), this, SLOT (settingChanged()));
 	grid->addWidget (outdec_input, row, 1);
 
 	// options (width)
 	grid->addWidget (new QLabel (i18n ("Output width (characters)"), this), ++row, 0);
 	width_input = new KIntSpinBox (10, 10000, 1, options_width, this);
-	connect (width_input, SIGNAL (valueChanged (int)), this, SLOT (settingChanged()));
+	connect (width_input, SIGNAL (valueChanged(int)), this, SLOT (settingChanged()));
 	grid->addWidget (width_input, row, 1);
 
 	// options (max.print)
 	grid->addWidget (new QLabel (i18n ("Maximum number of elements shown in print"), this), ++row, 0);
 	maxprint_input = new KIntSpinBox (100, INT_MAX, 1, options_maxprint, this);
-	connect (maxprint_input, SIGNAL (valueChanged (int)), this, SLOT (settingChanged()));
+	connect (maxprint_input, SIGNAL (valueChanged(int)), this, SLOT (settingChanged()));
 	grid->addWidget (maxprint_input, row, 1);
 
 	// options (warnings.length)
 	grid->addWidget (new QLabel (i18n ("Maximum length of warnings/errors to print"), this), ++row, 0);
 	warningslength_input = new KIntSpinBox (100, 8192, 1, options_warningslength, this);
-	connect (warningslength_input, SIGNAL (valueChanged (int)), this, SLOT (settingChanged()));
+	connect (warningslength_input, SIGNAL (valueChanged(int)), this, SLOT (settingChanged()));
 	grid->addWidget (warningslength_input, row, 1);
 
 	// options (keep.source)
@@ -120,7 +124,7 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 	keepsource_input->addItem (i18n ("TRUE (default)"), true);
 	keepsource_input->addItem (i18n ("FALSE"), false);
 	keepsource_input->setCurrentIndex (options_keepsource ? 0 : 1);
-	connect (keepsource_input, SIGNAL (activated (int)), this, SLOT (settingChanged()));
+	connect (keepsource_input, SIGNAL (activated(int)), this, SLOT (settingChanged()));
 	grid->addWidget (keepsource_input, row, 1);
 
 	// options (keep.source.pkgs)
@@ -130,19 +134,19 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 	keepsourcepkgs_input->addItem (i18n ("TRUE"), true);
 	keepsourcepkgs_input->addItem (i18n ("FALSE (default)"), false);
 	keepsourcepkgs_input->setCurrentIndex (options_keepsourcepkgs ? 0 : 1);
-	connect (keepsourcepkgs_input, SIGNAL (activated (int)), this, SLOT (settingChanged()));
+	connect (keepsourcepkgs_input, SIGNAL (activated(int)), this, SLOT (settingChanged()));
 	grid->addWidget (keepsourcepkgs_input, row, 1);
 
 	// options (expressions)
 	grid->addWidget (new QLabel (i18n ("Maximum level of nested expressions"), this), ++row, 0);
 	expressions_input = new KIntSpinBox (25, 500000, 1, options_expressions, this);
-	connect (expressions_input, SIGNAL (valueChanged (int)), this, SLOT (settingChanged()));
+	connect (expressions_input, SIGNAL (valueChanged(int)), this, SLOT (settingChanged()));
 	grid->addWidget (expressions_input, row, 1);
 
 	// options (digits)
 	grid->addWidget (new QLabel (i18n ("Default decimal precision in print ()"), this), ++row, 0);
 	digits_input = new KIntSpinBox (1, 22, 1, options_digits, this);
-	connect (digits_input, SIGNAL (valueChanged (int)), this, SLOT (settingChanged()));
+	connect (digits_input, SIGNAL (valueChanged(int)), this, SLOT (settingChanged()));
 	grid->addWidget (digits_input, row, 1);
 
 	// options (check.bounds)
@@ -152,7 +156,7 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 	checkbounds_input->addItem (i18n ("TRUE"), true);
 	checkbounds_input->addItem (i18n ("FALSE (default)"), false);
 	checkbounds_input->setCurrentIndex (options_checkbounds ? 0 : 1);
-	connect (checkbounds_input, SIGNAL (activated (int)), this, SLOT (settingChanged()));
+	connect (checkbounds_input, SIGNAL (activated(int)), this, SLOT (settingChanged()));
 	grid->addWidget (checkbounds_input, row, 1);
 
 	grid->addWidget (new QLabel (i18n ("Editor command"), this), ++row, 0);
@@ -163,7 +167,7 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 		editor_input->addItem (options_editor);
 		editor_input->setCurrentIndex (1);
 	}
-	connect (editor_input, SIGNAL (editTextChanged (const QString &)), this, SLOT (settingChanged()));
+	connect (editor_input, SIGNAL (editTextChanged(QString)), this, SLOT (settingChanged()));
 	grid->addWidget (editor_input, row, 1);
 
 	grid->addWidget (new QLabel (i18n ("Pager command"), this), ++row, 0);
@@ -174,7 +178,7 @@ RKSettingsModuleR::RKSettingsModuleR (RKSettings *gui, QWidget *parent) : RKSett
 		pager_input->addItem (options_pager);
 		pager_input->setCurrentIndex (1);
 	}
-	connect (pager_input, SIGNAL (editTextChanged (const QString &)), this, SLOT (settingChanged()));
+	connect (pager_input, SIGNAL (editTextChanged(QString)), this, SLOT (settingChanged()));
 	grid->addWidget (pager_input, row, 1);
 
 #ifdef Q_WS_WIN
@@ -236,12 +240,13 @@ void RKSettingsModuleR::applyChanges () {
 // apply run time options in R
 	QStringList commands = makeRRunTimeOptionCommands ();
 	for (QStringList::const_iterator it = commands.begin (); it != commands.end (); ++it) {
-		RKGlobals::rInterface ()->issueCommand (*it, RCommand::App, QString::null, 0, 0, commandChain ());
+		RKGlobals::rInterface ()->issueCommand (*it, RCommand::App, QString (), 0, 0, commandChain ());
 	}
 }
 
 //static
 QStringList RKSettingsModuleR::makeRRunTimeOptionCommands () {
+	RK_TRACE (SETTINGS);
 	QStringList list;
 
 	QString tf;
@@ -262,15 +267,14 @@ QStringList RKSettingsModuleR::makeRRunTimeOptionCommands () {
 	else list.append ("options (editor=\"" + options_editor + "\")\n");
 	if (options_pager == builtin_editor) list.append ("options (pager=rk.show.files)\n");
 	else list.append ("options (pager=\"" + options_pager + "\")\n");
-	if (!options_further.isEmpty ()) list.append (options_further + "\n");
+	if (!options_further.isEmpty ()) list.append (options_further + '\n');
 #ifdef Q_WS_WIN
 	list.append (QString ("setInternet2 (") + (options_internet2 ? "TRUE)\n" : "FALSE)\n"));
 #endif
 
-#warning TODO make the following options configurable
-	list.append ("options (device=\"rk.screen.device\")\n");
-	// register as interactive
-	list.append ("try (deviceIsInteractive(name=\"rk.screen.device\"))\n");
+#ifdef __GNUC__
+#	warning TODO make the following options configurable
+#endif
 	list.append ("options (help_type=\"html\")\n");		// for R 2.10.0 and above
 	list.append ("try ({options (htmlhelp=TRUE); options (chmhelp=FALSE)})\n");	// COMPAT: for R 2.9.x and below
 	list.append ("options (browser=rk.show.html)\n");
@@ -353,7 +357,7 @@ RKSettingsModuleRPackages::RKSettingsModuleRPackages (RKSettings *gui, QWidget *
 	main_vbox->addLayout (hbox);
 	cran_mirror_input = new QLineEdit (cran_mirror_url, this);
 	if (cran_mirror_url == "@CRAN@") cran_mirror_input->clear ();
-	connect (cran_mirror_input, SIGNAL (textChanged(const QString&)), this, SLOT (settingChanged()));
+	connect (cran_mirror_input, SIGNAL (textChanged(QString)), this, SLOT (settingChanged()));
 	hbox->addWidget (cran_mirror_input);
 	QPushButton* cran_mirror_button = new QPushButton (i18n ("Select mirror"), this);
 	connect (cran_mirror_button, SIGNAL (clicked()), this, SLOT (selectCRANMirror()));
@@ -361,13 +365,13 @@ RKSettingsModuleRPackages::RKSettingsModuleRPackages (RKSettings *gui, QWidget *
 
 	repository_selector = new MultiStringSelector (i18n ("Additional package repositories (where libraries are downloaded from)"), this);
 	repository_selector->setValues (package_repositories);
-	connect (repository_selector, SIGNAL (listChanged ()), this, SLOT (settingChanged ()));
-	connect (repository_selector, SIGNAL (getNewStrings (QStringList*)), this, SLOT (addRepository (QStringList*)));
+	connect (repository_selector, SIGNAL (listChanged()), this, SLOT (settingChanged()));
+	connect (repository_selector, SIGNAL (getNewStrings(QStringList*)), this, SLOT (addRepository(QStringList*)));
 	main_vbox->addWidget (repository_selector);
 
 	archive_packages_box = new QCheckBox (i18n ("Archive downloaded packages"), this);
 	archive_packages_box->setChecked (archive_packages);
-	connect (archive_packages_box, SIGNAL (stateChanged (int)), this, SLOT (settingChanged()));
+	connect (archive_packages_box, SIGNAL (stateChanged(int)), this, SLOT (settingChanged()));
 	main_vbox->addWidget (archive_packages_box);
 
 #if defined Q_WS_WIN || defined Q_WS_MAC
@@ -379,15 +383,15 @@ RKSettingsModuleRPackages::RKSettingsModuleRPackages (RKSettings *gui, QWidget *
 	source_packages_box->setEnabled (false);
 #endif
 	RKCommonFunctions::setTips (QString ("<p>%1</p>").arg (i18n ("Installing packages from pre-compiled binaries (if available) is generally faster, and does not require an installation of development tools and libraries. On the other hand, building packages from source provides best compatibility. On Mac OS X and Linux, building packages from source is currently recommended.")), source_packages_box);
-	connect (source_packages_box, SIGNAL (stateChanged (int)), this, SLOT (settingChanged()));
+	connect (source_packages_box, SIGNAL (stateChanged(int)), this, SLOT (settingChanged()));
 	main_vbox->addWidget (source_packages_box);
 
 	main_vbox->addStretch ();
 
 	libloc_selector = new MultiStringSelector (i18n ("R Library locations (where libraries get installed to, locally)"), this);
 	libloc_selector->setValues (liblocs);
-	connect (libloc_selector, SIGNAL (listChanged ()), this, SLOT (settingChanged ()));
-	connect (libloc_selector, SIGNAL (getNewStrings (QStringList*)), this, SLOT (addLibLoc (QStringList*)));
+	connect (libloc_selector, SIGNAL (listChanged()), this, SLOT (settingChanged()));
+	connect (libloc_selector, SIGNAL (getNewStrings(QStringList*)), this, SLOT (addLibLoc(QStringList*)));
 	main_vbox->addWidget (libloc_selector);
 	QLabel *label = new QLabel (i18n ("Note: The startup defaults will always be used in addition to the locations you specify in this list"), this);
 	main_vbox->addWidget (label);
@@ -415,7 +419,18 @@ void RKSettingsModuleRPackages::settingChanged () {
 
 void RKSettingsModuleRPackages::addLibLoc (QStringList *string_list) {
 	RK_TRACE (SETTINGS);
+#ifdef Q_WS_WIN
+	// TODO: Hang on Windows when trying to select any dir using (K|Q)FileDialog::getExistingDirectory (). KDE 4.10
+	QFileDialog dummy (this, i18n ("Add R Library Directory"));
+	dummy.setFileMode (QFileDialog::Directory);
+	dummy.setOptions (QFileDialog::ShowDirsOnly);
+	QString new_string;
+	if (dummy.exec ()) {
+		new_string = dummy.selectedFiles ().value (0);
+	}
+#else
 	QString new_string = KFileDialog::getExistingDirectory (KUrl (), this, i18n ("Add R Library Directory"));
+#endif
 	if (!new_string.isEmpty ()) {
 		(*string_list).append (new_string);
 	}
@@ -423,7 +438,7 @@ void RKSettingsModuleRPackages::addLibLoc (QStringList *string_list) {
 
 void RKSettingsModuleRPackages::addRepository (QStringList *string_list) {
 	RK_TRACE (SETTINGS);
-	QString new_string = KInputDialog::getText (i18n ("Add repository"), i18n ("Add URL of new repository"), QString::null, 0, this);
+	QString new_string = KInputDialog::getText (i18n ("Add repository"), i18n ("Add URL of new repository"), QString (), 0, this);
 	(*string_list).append (new_string);
 }
 
@@ -441,7 +456,7 @@ void RKSettingsModuleRPackages::selectCRANMirror () {
 
 	RKProgressControl* control = new RKProgressControl (this, title, title, RKProgressControl::CancellableProgress);
 	control->addRCommand (command, true);
-	RKGlobals::rInterface ()->issueCommand (command);
+	RKGlobals::rInterface ()->issueCommand (command, commandChain ());
 	control->doModal (true);
 }
 
@@ -464,7 +479,7 @@ QString RKSettingsModuleRPackages::libLocsCommand () {
 	QString command = ".libPaths (unique (c (";
 	bool first = true;
 	QStringList ll = libraryLocations ();
-	foreach (const QString libloc, ll) {
+	foreach (const QString& libloc, ll) {
 		if (first) first = false;
 		else command.append (", ");
 		command.append (RObject::rQuote (libloc));
@@ -483,7 +498,12 @@ QString RKSettingsModuleRPackages::pkgTypeOption () {
 #	if defined Q_WS_WIN
 	else ret.append ("win.binary");
 #	else
-	else ret.append ("mac.binary.leopard");
+	else if (RKSessionVars::compareRVersion ("3.0.0") > 0) {
+		ret.append ("mac.binary.leopard");
+	} else {
+		// OS X binary packages have switched repo locations and package type in R >= 3.0.0
+		ret.append ("mac.binary");
+	}
 #	endif
 	ret.append ("\")\n");
 #endif
@@ -526,7 +546,7 @@ void RKSettingsModuleRPackages::applyChanges () {
 // apply options in R
 	QStringList commands = makeRRunTimeOptionCommands ();
 	for (QStringList::const_iterator it = commands.begin (); it != commands.end (); ++it) {
-		RKGlobals::rInterface ()->issueCommand (*it, RCommand::App, QString::null, 0, 0, commandChain ());
+		RKGlobals::rInterface ()->issueCommand (*it, RCommand::App, QString (), 0, 0, commandChain ());
 	}
 }
 
@@ -553,10 +573,13 @@ void RKSettingsModuleRPackages::loadSettings (KConfig *config) {
 	KConfigGroup cg = config->group ("R Settings");
 
 	cran_mirror_url = cg.readEntry ("CRAN mirror url", "@CRAN@");
-	const QString rkward_repo ("http://rkward.sf.net/R/");
+	const QString rkward_repo ("http://files.kde.org/rkward/R/");
 	package_repositories = cg.readEntry ("Repositories", QStringList (rkward_repo));
 	if (RKSettingsModuleGeneral::storedConfigVersion () <= RKSettingsModuleGeneral::RKWardConfig_Pre0_5_7) {
 		package_repositories.removeAll ("@CRAN@");	// COMPAT: Cran mirror was part of this list before 0.5.3
+		if (package_repositories.isEmpty ()) package_repositories.append (rkward_repo);
+	} else if (RKSettingsModuleGeneral::storedConfigVersion () < RKSettingsModuleGeneral::RKWardConfig_0_6_3) {
+		package_repositories.removeAll ("http://rkward.sf.net/R");
 		package_repositories.append (rkward_repo);
 	}
 
