@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Oct 21 2005
     copyright            : (C) 2005, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
