@@ -2,8 +2,8 @@
                           rkcommandeditorwindow  -  description
                              -------------------
     begin                : Mon Aug 30 2004
-    copyright            : (C) 2004, 2006, 2007, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004-2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -115,10 +115,10 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 	layout->setContentsMargins (0, 0, 0, 0);
 	layout->addWidget(m_view);
 
-	connect (m_doc, SIGNAL (documentUrlChanged (KTextEditor::Document*)), this, SLOT (updateCaption (KTextEditor::Document*)));
-	connect (m_doc, SIGNAL (modifiedChanged (KTextEditor::Document*)), this, SLOT (updateCaption(KTextEditor::Document*)));                // of course most of the time this causes a redundant call to updateCaption. Not if a modification is undone, however.
-	connect (m_doc, SIGNAL (modifiedChanged (KTextEditor::Document*)), this, SLOT (autoSaveHandlerModifiedChanged()));
-	connect (m_doc, SIGNAL (textChanged (KTextEditor::Document*)), this, SLOT (autoSaveHandlerTextChanged()));
+	connect (m_doc, SIGNAL (documentUrlChanged(KTextEditor::Document*)), this, SLOT (updateCaption(KTextEditor::Document*)));
+	connect (m_doc, SIGNAL (modifiedChanged(KTextEditor::Document*)), this, SLOT (updateCaption(KTextEditor::Document*)));                // of course most of the time this causes a redundant call to updateCaption. Not if a modification is undone, however.
+	connect (m_doc, SIGNAL (modifiedChanged(KTextEditor::Document*)), this, SLOT (autoSaveHandlerModifiedChanged()));
+	connect (m_doc, SIGNAL (textChanged(KTextEditor::Document*)), this, SLOT (autoSaveHandlerTextChanged()));
 	connect (m_view, SIGNAL (selectionChanged(KTextEditor::View*)), this, SLOT (selectionChanged(KTextEditor::View*)));
 	// somehow the katepart loses the context menu each time it loses focus
 	connect (m_view, SIGNAL (focusIn(KTextEditor::View*)), this, SLOT (focusIn(KTextEditor::View*)));
@@ -135,8 +135,8 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 				completion_model = new RKCodeCompletionModel (this);
 				completion_timer = new QTimer (this);
 				completion_timer->setSingleShot (true);
-				connect (completion_timer, SIGNAL (timeout ()), this, SLOT (tryCompletion()));
-				connect (m_doc, SIGNAL (textChanged (KTextEditor::Document*)), this, SLOT (tryCompletionProxy (KTextEditor::Document*)));
+				connect (completion_timer, SIGNAL (timeout()), this, SLOT (tryCompletion()));
+				connect (m_doc, SIGNAL (textChanged(KTextEditor::Document*)), this, SLOT (tryCompletionProxy(KTextEditor::Document*)));
 			} else {
 				RK_ASSERT (false);
 			}
@@ -156,7 +156,7 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 	connect (autosave_timer, SIGNAL (timeout()), this, SLOT (doAutoSave()));
 
 	updateCaption ();	// initialize
-	QTimer::singleShot (0, this, SLOT (setPopupMenu ()));
+	QTimer::singleShot (0, this, SLOT (setPopupMenu()));
 }
 
 RKCommandEditorWindow::~RKCommandEditorWindow () {
@@ -209,16 +209,14 @@ void RKCommandEditorWindow::initializeActions (KActionCollection* ac) {
 	RK_TRACE (COMMANDEDITOR);
 
 	RKStandardActions::copyLinesToOutput (this, this, SLOT (copyLinesToOutput()));
-	RKStandardActions::pasteSpecial (this, this, SLOT (paste(const QString&)));
+	RKStandardActions::pasteSpecial (this, this, SLOT (paste(QString)));
 
 	action_run_all = RKStandardActions::runAll (this, this, SLOT (runAll()));
-	action_run_selection = RKStandardActions::runSelection (this, this, SLOT (runSelection()));
-	action_run_selection->setEnabled (false);
-	action_run_line = RKStandardActions::runLine (this, this, SLOT (runLine()));
+	action_run_current = RKStandardActions::runCurrent (this, this, SLOT (runCurrent()), true);
 	// NOTE: enter_and_submit is not currently added to the menu
 	KAction *action = ac->addAction ("enter_and_submit", this, SLOT (enterAndSubmit()));
 	action->setText (i18n ("Insert line break and run"));
-	action->setShortcuts (KShortcut (Qt::ControlModifier + Qt::Key_Return, Qt::ControlModifier + Qt::Key_Enter));
+	action->setShortcuts (KShortcut (Qt::AltModifier + Qt::Key_Return, Qt::AltModifier + Qt::Key_Enter));
 
 	action_help_function = RKStandardActions::functionHelp (this, this, SLOT (showHelp()));
 
@@ -233,7 +231,7 @@ void RKCommandEditorWindow::initializeActions (KActionCollection* ac) {
 	ac->addAction ("unmark_block", actionmenu_unmark_block);
 	connect (actionmenu_unmark_block->menu(), SIGNAL (aboutToShow()), this, SLOT (clearUnusedBlocks()));
 
-	action_setwd_to_script = ac->addAction ("setwd_to_script", this, SLOT (setWDToScript ()));
+	action_setwd_to_script = ac->addAction ("setwd_to_script", this, SLOT (setWDToScript()));
 	action_setwd_to_script->setText (i18n ("CD to script directory"));
 #if KDE_IS_VERSION(4,3,0)
 	action_setwd_to_script->setHelpText (i18n ("Change the working directory to the directory of this script"));
@@ -333,7 +331,7 @@ QString RKCommandEditorWindow::fullCaption () {
 	if (m_doc->url ().isEmpty ()) {
 		return (shortCaption ());
 	} else {
-		QString cap = m_doc->url ().url ();
+		QString cap = m_doc->url ().pathOrUrl ();
 		if (isModified ()) cap.append (i18n (" [modified]"));
 		return (cap);
 	}
@@ -380,9 +378,9 @@ bool RKCommandEditorWindow::openURL (const KUrl url, const QString& encoding, bo
 				if (!encoding.isEmpty () && (conf.readEntry ("Encoding", encoding) != encoding)) conf.writeEntry ("Encoding", encoding);
 				if (conf.readEntry ("URL", url) != url) conf.writeEntry ("URL", url);
 				/* HACK: What the...?! Somehow, at least on longer R scripts, stored Mode="Normal" in combination with R Highlighting
-				 * causes code folding to fail (KDE 4.8.4, https://sourceforge.net/tracker/?func=detail&atid=459007&aid=3564769&group_id=50231).
+				 * causes code folding to fail (KDE 4.8.4, http://sourceforge.net/p/rkward/bugs/122/).
 				 * Forcing Mode == Highlighting appears to help. */
-				conf.writeEntry ("Mode", conf.readEntry ("Highlighting", "Normal"));
+				if (use_r_highlighting) conf.writeEntry ("Mode", conf.readEntry ("Highlighting", "Normal"));
 				iface->readSessionConfig (conf);
 			}
 			iface = qobject_cast<KTextEditor::SessionConfigInterface*> (m_view);
@@ -391,8 +389,9 @@ bool RKCommandEditorWindow::openURL (const KUrl url, const QString& encoding, bo
 				iface->readSessionConfig (conf);
 			}
 		}
-
 		if (use_r_highlighting) RKCommandHighlighter::setHighlighting (m_doc, RKCommandHighlighter::RScript);
+		else RKCommandHighlighter::setHighlighting (m_doc, RKCommandHighlighter::Automatic);
+
 		setReadOnly (read_only);
 
 		updateCaption ();
@@ -461,7 +460,7 @@ void RKCommandEditorWindow::doAutoSave () {
 	KUrl backup_autosave_url;
 	if (previous_autosave_url.isValid ()) {
 		backup_autosave_url = previous_autosave_url;
-		backup_autosave_url.setFileName (backup_autosave_url.fileName () + "~");
+		backup_autosave_url.setFileName (backup_autosave_url.fileName () + '~');
 		if (previous_autosave_url.isLocalFile ()) {
 			QFile::remove (backup_autosave_url.toLocalFile ());
 			QFile::copy (previous_autosave_url.toLocalFile (), backup_autosave_url.toLocalFile ());
@@ -640,6 +639,7 @@ void RKCommandEditorWindow::tryCompletion () {
 	int start;
 	int end;
 	RKCommonFunctions::getCurrentSymbolOffset (current_line, cursor_pos, false, &start, &end);
+	if (end > cursor_pos) return;   // Only hint when at the end of a word/symbol: https://mail.kde.org/pipermail/rkward-devel/2015-April/004122.html
 
 	KTextEditor::Range range = KTextEditor::Range (para, start, para, end);
 	QString word;
@@ -690,25 +690,20 @@ void RKCommandEditorWindow::setWDToScript () {
 	RKConsole::pipeUserCommand ("setwd (\"" + dir + "\")");
 }
 
-void RKCommandEditorWindow::runSelection() {
+void RKCommandEditorWindow::runCurrent () {
 	RK_TRACE (COMMANDEDITOR);
 
-	QString command = m_view->selectionText ();
-	if (command.isEmpty ()) return;
+	if (m_view->selection ()) {
+		RKConsole::pipeUserCommand (m_view->selectionText ());
+	} else {
+		KTextEditor::Cursor c = m_view->cursorPosition();
+		QString command = m_doc->line (c.line());
+		if (!command.isEmpty ()) RKConsole::pipeUserCommand (command + '\n');
 
-	RKConsole::pipeUserCommand (command);
-}
-
-void RKCommandEditorWindow::runLine() {
-	RK_TRACE (COMMANDEDITOR);
-
-	KTextEditor::Cursor c = m_view->cursorPosition();
-	QString command = m_doc->line (c.line());
-	if (!command.isEmpty ()) RKConsole::pipeUserCommand (command + '\n');
-
-	// advance to next line (NOTE: m_view->down () won't work on auto-wrapped lines)
-	c.setLine(c.line() + 1);
-	m_view->setCursorPosition (c);
+		// advance to next line (NOTE: m_view->down () won't work on auto-wrapped lines)
+		c.setLine(c.line() + 1);
+		m_view->setCursorPosition (c);
+	}
 }
 
 void RKCommandEditorWindow::enterAndSubmit () {
@@ -863,10 +858,8 @@ void RKCommandEditorWindow::selectionChanged (KTextEditor::View* view) {
 	RK_ASSERT (view == m_view);
 
 	if (view->selection ()) {
-		action_run_selection->setEnabled (true);
 		actionmenu_mark_block->setEnabled (true);
 	} else {
-		action_run_selection->setEnabled (false);
 		actionmenu_mark_block->setEnabled (false);
 	}
 }
@@ -930,7 +923,7 @@ void RKFunctionArgHinter::tryArgHint () {
 	if (!RKSettingsModuleCommandEditor::argHintingEnabled ()) return;
 
 	// do this in the next event cycle to make sure any inserted characters have truly been inserted
-	QTimer::singleShot (0, this, SLOT (tryArgHintNow ()));
+	QTimer::singleShot (0, this, SLOT (tryArgHintNow()));
 }
 
 void RKFunctionArgHinter::tryArgHintNow () {
@@ -1180,7 +1173,7 @@ QString RKCommandHighlighter::commandToHTML (const QString r_command, Highlighti
 	if (!iface) return (QString ("<pre>") + r_command + "</pre>");
 
 	doc->setText (r_command);
-	if (r_command.endsWith ("\n")) doc->removeLine (doc->lines () - 1);
+	if (r_command.endsWith ('\n')) doc->removeLine (doc->lines () - 1);
 	setHighlighting (doc, mode);
 	QString ret;
 
@@ -1224,7 +1217,7 @@ QString RKCommandHighlighter::commandToHTML (const QString r_command, Highlighti
 					ret.append (opening.arg ("output_normal"));
 					previous_chunk = Output;
 				}
-				ret.append (Qt::escape (line) + "\n");	// don't copy output "highlighting". It is set using CSS, instead
+				ret.append (Qt::escape (line) + '\n');	// don't copy output "highlighting". It is set using CSS, instead
 				continue;
 			}
 		}
@@ -1264,9 +1257,20 @@ QString RKCommandHighlighter::commandToHTML (const QString r_command, Highlighti
 void RKCommandHighlighter::setHighlighting (KTextEditor::Document *doc, HighlightingMode mode) {
 	RK_TRACE (COMMANDEDITOR);
 
-	QString mode_string = "R Script";
-	if (mode == RInteractiveSession) mode_string = "R interactive session";
-	if (!(doc->setHighlightingMode (mode_string) && doc->setMode (mode_string))) RK_DEBUG (COMMANDEDITOR, DL_ERROR, "R syntax highlighting defintion ('%s')not found!", qPrintable (mode_string));
+	QString mode_string;
+	if (mode == RScript) mode_string = "R Script";
+	else if (mode == RInteractiveSession) mode_string = "R interactive session";
+	else {
+		QString fn = doc->url ().fileName ().toLower ();
+		if (fn.endsWith (".pluginmap") || fn.endsWith (".rkh") || fn.endsWith (".xml") || fn.endsWith (".inc")) {
+			mode_string = "XML";
+		} else if (fn.endsWith (".js")) {
+			mode_string = "JavaScript";
+		} else {
+			return;
+		}
+	}
+	if (!(doc->setHighlightingMode (mode_string) && doc->setMode (mode_string))) RK_DEBUG (COMMANDEDITOR, DL_ERROR, "R syntax highlighting definition ('%s')not found!", qPrintable (mode_string));
 }
 
 void RKCommandHighlighter::copyLinesToOutput (KTextEditor::View *view, HighlightingMode mode) {
