@@ -2,8 +2,8 @@
                           rkcommandeditorwindow  -  description
                              -------------------
     begin                : Mon Aug 30 2004
-    copyright            : (C) 2004, 2006, 2007, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004-2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -102,7 +102,6 @@ private:
 };
 
 /** code completion model for RKCommandEditorWindow */
-#include <kdeversion.h>
 #if KDE_VERSION_MAJOR != 4
 #	error Adjust the versioning hack below!
 #endif
@@ -128,7 +127,7 @@ public:
 class RKCodeCompletionModel : public KTextEditor::CodeCompletionModel {
 #endif
 public:
-	RKCodeCompletionModel (RKCommandEditorWindow* parent);
+	explicit RKCodeCompletionModel (RKCommandEditorWindow* parent);
 	~RKCodeCompletionModel ();
 
 	void updateCompletionList (const QString& symbol);
@@ -160,7 +159,7 @@ class RKCommandEditorWindow : public RKMDIWindow, public RKScriptContextProvider
 public:
 /** constructor
 @param use_r_highlighting Initialize the view to use R syntax highlighting. Use, if you're going to edit an R syntax file */
-	RKCommandEditorWindow (QWidget *parent = 0, bool use_r_highlighting=true, bool use_codehinting=true);
+	explicit RKCommandEditorWindow (QWidget *parent = 0, bool use_r_highlighting=true, bool use_codehinting=true);
 /** destructor */
 	~RKCommandEditorWindow ();
 /** open given URL. 
@@ -205,10 +204,8 @@ public slots:
 	void focusIn (KTextEditor::View *);
 /** Show help about the current word. */
 	void showHelp ();
-/** run the currently selected command(s) */
-	void runSelection ();
-/** run the current line */
-	void runLine ();
+/** run the currently selected command(s) or line */
+	void runCurrent ();
 /** run the entire script */
 	void runAll ();
 /** insert line break and run the (previous) line */
@@ -287,8 +284,7 @@ private:
 	KActionMenu* actionmenu_run_block;
 
 	KAction* action_run_all;
-	KAction* action_run_selection;
-	KAction* action_run_line;
+	KAction* action_run_current;
 
 	KAction* action_setwd_to_script;
 
@@ -305,7 +301,8 @@ class RKCommandHighlighter {
 public:
 	enum HighlightingMode {
 		RInteractiveSession,
-		RScript
+		RScript,
+		Automatic
 	};
 	static void copyLinesToOutput (KTextEditor::View *view, HighlightingMode mode);
 	static void setHighlighting (KTextEditor::Document *doc, HighlightingMode mode);
