@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Nov 3 2002
     copyright            : (C) 2002, 2004, 2005 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -287,9 +287,9 @@ void RKCommandLogPart::initActions () {
 	QAction *configure = actionCollection ()->addAction ("log_configure", log, SLOT(configureLog()));
 	configure->setText (i18n ("Configure"));
 
-	run_selection = RKStandardActions::runSelection (log, log, SLOT(runSelection()));
+	run_selection = RKStandardActions::runCurrent (log, log, SLOT(runSelection()));
 
-	connect (log->getView (), SIGNAL (popupMenuRequest (const QPoint &)), this, SLOT (doPopupMenu (const QPoint &)));
+	connect (log->getView (), SIGNAL (popupMenuRequest(QPoint)), this, SLOT (doPopupMenu(QPoint)));
 }
 
 void RKCommandLogPart::doPopupMenu (const QPoint &pos) {
