@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Nov 3 2002
     copyright            : (C) 2002, 2004, 2005, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -26,7 +26,7 @@
 #include "../rbackend/rcommandreceiver.h"
 
 class RCommand;
-class ROutput;
+struct ROutput;
 class RKCommandLogView;
 class RKCommandLogPart;
 
@@ -78,7 +78,7 @@ friend class RKWardMainWindow;
 class RKCommandLogView : public QTextEdit {
 	Q_OBJECT
 public:
-	RKCommandLogView (RKCommandLog *parent);
+	explicit RKCommandLogView (RKCommandLog *parent);
 	~RKCommandLogView ();
 public slots:
 	void selectAll ();
