@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Dec 01 2012
     copyright            : (C) 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -76,7 +76,7 @@ void RKDebugMessageWindow::createWidget () {
 
 		if (first) {
 			KMessageBox::information (this, i18n ("<p>This window is used for displaying RKWard related debug messages. It is targetted primarily at (plugin) developers. It does <b>not</b> offer any features for debugging R code.</p>"
-				"<p>Note that the list of message is cleared everytime you close the window.</p><p>Type and severity level of messages can be controlled from Settings->Configure RKWard->Debug</p>"), i18n ("About this window"), "inforkdebugmessagewindow");
+				"<p>Note that the list of messages is cleared every time you close the window.</p><p>Type and severity level of messages can be controlled from Settings->Configure RKWard->Debug</p>"), i18n ("About this window"), "inforkdebugmessagewindow");
 			first = false;
 		}
 	}
@@ -137,6 +137,6 @@ void RKDebugMessageWindowWidget::newMessage (const int flags, const int level, c
 	}
 	message_viewer->setTextColor (Qt::black);
 
-	message_viewer->insertPlainText (message + "\n");
+	message_viewer->insertPlainText (message + '\n');
 }
 
