@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Apr 26 2007
     copyright            : (C) 2007, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -57,7 +57,7 @@ TODO: KDE4: check whether there is a ready widget for this. Much of the implemen
 class RKFileBrowserWidget : public KVBox {
 	Q_OBJECT
 public:
-	RKFileBrowserWidget (QWidget *widget);
+	explicit RKFileBrowserWidget (QWidget *widget);
 	~RKFileBrowserWidget ();
 
 	void setURL (const QString &url);
