@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Feb 25 2005
     copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -75,7 +75,7 @@ friend class RKWardMainWindow;
 @author Thomas Friedrichsmeier */
 class RKHelpSearchResultsModel : public QAbstractTableModel {
 public:
-	RKHelpSearchResultsModel (QObject *parent);
+	explicit RKHelpSearchResultsModel (QObject *parent);
 	~RKHelpSearchResultsModel ();
 
 /** Set the results. The model will assume ownership of the results */
