@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Oct 12 2005
     copyright            : (C) 2005, 2006, 2007, 2009, 2011, 2014, 2015 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,31 +19,53 @@
 #define RKHTMLWINDOW_H
 
 #include <kurl.h>
-#include <kparts/browserextension.h>
-#include <kxmlguiclient.h>
+#include <kparts/part.h>
 #include <kio/jobclasses.h>
+#include <kwebpage.h>
+
 
 #include "../windows/rkmdiwindow.h"
 
-class KHTMLPart;
-class KTemporaryFile;
 class KActionCollection;
 class KRecentFilesAction;
 class QAction;
 class QDomElement;
 class RKComponentHandle;
 class XMLHelper;
+class RKHTMLWindowPart;
+class KWebView;
+class KTemporaryFile;
+class RKHTMLWindow;
+class RKFindBar;
+
+class RKWebPage : public KWebPage {
+	Q_OBJECT
+public:
+	explicit RKWebPage (RKHTMLWindow* window);
+	void load (const QUrl& url);
+signals:
+	void pageInternalNavigation (const QUrl& url);
+protected:
+/** reimplemented to always emit linkClicked() for pages that need special handling (importantly, rkward://-urls). */
+	bool acceptNavigationRequest (QWebFrame* frame, const QNetworkRequest& request, NavigationType type);
+/** reimplemented to schedule new window creation for the next page to load */
+	QWebPage* createWindow (WebWindowType type);
+private:
+	RKHTMLWindow *window;
+	bool new_window;
+	bool direct_load;
+};
 
 /**
 	\brief Show html files.
 
-This class wraps a khtml part.
+Provide a window for viewing HTML pages.
 
-It is used as a base for several purposes: Display R-help (in HTML format), display generic HTML, display RKWard output. Do not use this class directly. Use the derived classes instead.
+It is used as a base for several purposes: Display R-help (in HTML format), display RKWard help pages, display generic HTML, display RKWard output.
 
 @author Pierre Ecochard
 */
-class RKHTMLWindow : public RKMDIWindow, public KXMLGUIClient {
+class RKHTMLWindow : public RKMDIWindow {
 	Q_OBJECT
 public:
 	enum WindowMode {
@@ -54,7 +76,7 @@ public:
 
 /** constructor. 
 @param parent parent QWidget, usually RKGlobals::rkApp () or similar */
-	RKHTMLWindow (QWidget *parent, WindowMode mode=HTMLHelpWindow);
+	explicit RKHTMLWindow (QWidget *parent, WindowMode mode=HTMLHelpWindow);
 /** destructor */
 	~RKHTMLWindow ();
 /** open given URL. Returns false, if the URL is not an existing local file. Loading a non-local URL may succeed, even if this returns false! */
@@ -65,21 +87,18 @@ public:
  */
 	static bool handleRKWardURL (const KUrl &url, RKHTMLWindow *window=0);
 	void openRKHPage (const KUrl &url);
-/** initialize all actions */
-	void initActions ();
 
 	bool isModified ();
 /** Return current url */
 	KUrl url ();
 /** Return current url in a restorable way, i.e. for help pages, abstract the session specific part of the path */
 	KUrl restorableUrl ();
-	void doGotoAnchor (const QString &anchor_name);
 
 	WindowMode mode () { return window_mode; };
 public slots:
-/** this is used for browsing only. Use openURL instead, when calling from outside. */
-	void slotOpenUrl (const KUrl & url, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &);
 	void slotPrint ();
+	void slotSave ();
+	void saveRequested (const QNetworkRequest& request);
 	void slotForward ();
 	void slotBack ();
 	void selectionChanged ();
@@ -88,35 +107,63 @@ public slots:
 	void flushOutput ();
 /** Reload current page.*/
 	void refresh ();
-/** apply our customizations to the khtmlpart GUI */
-	void fixupPartGUI ();
+	void zoomIn ();
+	void zoomOut ();
+	void setTextEncoding (QTextCodec* encoding);
 private slots:
-/** This slot is called when the new page has finished loading. Sets scroll position to scroll_position */
-	void loadDone ();
-	void doGotoAnchorNow ();
+	void scrollToBottom ();
 	void mimeTypeDetermined (KIO::Job*, const QString& type);
-	void internalNavigation ();
-protected:
-/** Here we store the state of the part before refresh. Used to scroll to the same position after a reload */
-	QByteArray saved_state;
-/** the part doing all the real work */
-	KParts::ReadOnlyPart * renderingpart;
+	void internalNavigation (const QUrl& new_url);
+	void makeContextMenu (const QPoint& pos);
+	void findRequest (const QString& text, bool backwards, const RKFindBar *findbar, bool* found);
+private:
+friend class RKHTMLWindowPart;
+	KWebView* view;
+	RKWebPage* page;
+	RKFindBar* findbar;
+	bool have_highlight;
 /** In case the part is a khtmlpart: A ready-cast pointer to that. 0 otherwise (if a webkit part is in use) */
-	KHTMLPart *khtmlpart;
+	RKHTMLWindowPart *part;
 /** update caption according to given URL */
 	virtual void updateCaption (const KUrl &url);
 /** called from openURL. Takes care of updating caption, and updating back/forward actions, if available */
 	void changeURL (const KUrl &url);
-private:
+
 	struct VisitedLocation {
 		KUrl url;
-		QByteArray state;
+		QPoint scroll_position;
 	};
 	QList<VisitedLocation> url_history;
 	void openLocationFromHistory (VisitedLocation &loc);
 	int current_history_position;
 	bool url_change_is_from_history;	// dirty!!!
 
+	KUrl current_url;
+	void startNewCacheFile ();
+	KTemporaryFile *current_cache_file;
+
+	WindowMode window_mode;
+	void useMode (WindowMode);
+
+	void fileDoesNotExistMessage ();
+
+	void saveBrowserState (VisitedLocation *state);
+	void restoreBrowserState (VisitedLocation *state);
+};
+
+class RKHTMLWindowPart : public KParts::Part {
+	Q_OBJECT
+public:
+	explicit RKHTMLWindowPart (RKHTMLWindow *window);
+	~RKHTMLWindowPart () {};
+
+	void setOutputWindowSkin ();
+	void setHelpWindowSkin ();
+	void initActions ();
+private:
+friend class RKHTMLWindow;
+	RKHTMLWindow *window;
+
 	// general actions
 	QAction *run_selection;
 	QAction* print;
@@ -126,37 +173,7 @@ private:
 	// actions in help window mode
 	QAction *back;
 	QAction *forward;
-
-	QString goto_anchor_name;
-	KUrl current_url;
-
-	WindowMode window_mode;
-	void useMode (WindowMode);
-
-	void fileDoesNotExistMessage ();
-
-	// for dealing with rkward://[page|component]-pages
-	bool renderRKHelp (const KUrl &url);
-	struct HTMLRendererState {
-		XMLHelper *help_xml;
-		XMLHelper *component_xml;
-		QDomElement help_doc_element;
-		QDomElement component_doc_element;
-	};
-	QString renderHelpFragment (QDomElement &fragment, const HTMLRendererState &state);
-	QString resolveLabel (const QString &id, const HTMLRendererState &state) const;
-	QString prepareHelpLink (const QString &href, const QString &text);
-	QString componentPathToId (QString path);
-	RKComponentHandle *componentPathToHandle (QString path);
-	QString startSection (const QString &name, const QString &title, const QString &shorttitle, QStringList *anchors, QStringList *anchor_names);
-
-	void beginWritingHTML (const KUrl &url);
-	void writeHTML (const QString &string);
-	KTemporaryFile* html_write_file;
-	void endWritingHTML ();
-
-	void saveBrowserState (QByteArray *state);
-	void restoreBrowserState (QByteArray *state);
+	QAction* save_page;
 };
 
 /**
@@ -167,9 +184,26 @@ private:
 class RKHelpRenderer {
 public:
 /** ctor */
-	RKHelpRenderer () {};
+	explicit RKHelpRenderer (QIODevice *_device) { device = _device; help_xml = 0; component_xml = 0; };
 /** destructor */
 	~RKHelpRenderer () {};
+
+	XMLHelper *help_xml;
+	XMLHelper *component_xml;
+	QDomElement help_doc_element;
+	QDomElement component_doc_element;
+
+	// for dealing with rkward://[page|component]-pages
+	bool renderRKHelp (const KUrl &url);
+	QString renderHelpFragment (QDomElement &fragment);
+	QString resolveLabel (const QString &id) const;
+	QString prepareHelpLink (const QString &href, const QString &text);
+	QString componentPathToId (QString path);
+	RKComponentHandle *componentPathToHandle (QString path);
+	QString startSection (const QString &name, const QString &title, const QString &shorttitle, QStringList *anchors, QStringList *anchor_names);
+
+	QIODevice *device;
+	void writeHTML (const QString &string);
 };
 
 #include <QMultiHash>
