@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Apr 24 2007
     copyright            : (C) 2007, 2009, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,6 +41,7 @@
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rkcommonfunctions.h"
 #include "../plugin/rkcomponentmap.h"
+#include "../dialogs/rkerrordialog.h"
 #include "../rbackend/rinterface.h"
 #include "../rkglobals.h"
 #include "../rkward.h"
@@ -82,7 +83,7 @@ RKTopLevelWindowGUI::RKTopLevelWindowGUI (KXmlGuiWindow *for_window) : QObject (
 	next_action->setShortcut (Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_Tab);
 
 	KAction *action;
-	foreach (RKToolWindowList::ToolWindowRepresentation rep, RKToolWindowList::registeredToolWindows ()) {
+	foreach (const RKToolWindowList::ToolWindowRepresentation& rep, RKToolWindowList::registeredToolWindows ()) {
 		action = actionCollection ()->addAction ("window_show_" + rep.id, this, SLOT (toggleToolView()));
 		action->setText (i18n ("Show/Hide %1", rep.window->shortCaption ()));
 		action->setIcon (rep.window->windowIcon ());
@@ -98,7 +99,7 @@ RKTopLevelWindowGUI::RKTopLevelWindowGUI (KXmlGuiWindow *for_window) : QObject (
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::WindowOutput));
 
 	// settings
-	KStandardAction::keyBindings (this, SLOT (configureShortcuts ()), actionCollection ());
+	KStandardAction::keyBindings (this, SLOT (configureShortcuts()), actionCollection ());
 	KStandardAction::configureToolbars (this, SLOT (configureToolbars()), actionCollection ());
 }
 
@@ -141,42 +142,7 @@ void RKTopLevelWindowGUI::startWhatsThis () {
 }
 
 void RKTopLevelWindowGUI::reportRKWardBug () {
-	RK_TRACE (APP);
-
-	QString report_template = i18n ("---Problem description---\n");
-	report_template.append (i18n ("Please give a brief summary on the problem:\n###Please fill in###\n\n"));
-	report_template.append (i18n ("What - in detail - did you do directly before you encountered this problem?\n###Please fill in###\n\n"));
-	report_template.append (i18n ("When you try to repeat the above, does the problem occur again (no, sometimes, always)?\n###Please fill in###\n\n"));
-	report_template.append (i18n ("If applicable: When doing the same thing in an R session outside of RKWard, do you see the same problem?\n###Please fill in###\n\n"));
-	report_template.append (i18n ("Do you have any further information that might help us to track this problem down? In particular, if applicable, can you provide sample data and sample R code to reproduce this problem?\n###Please fill in###\n\n"));
-
-	RCommand *command = new RCommand ("rk.sessionInfo()", RCommand::App);
-	RKProgressControl *control = new RKProgressControl (this, i18n ("Please stand by while gathering some information on your setup.\nIn case the backend has died or hung up, you may want to press 'Cancel' to skip this step."), i18n ("Gathering setup information"), RKProgressControl::CancellableNoProgress);
-	control->addRCommand (command, true);
-	RKGlobals::rInterface ()->issueCommand (command);
-	bool ok = control->doModal (false);
-
-	report_template.append ("---Session Info---\n");
-	report_template.append (control->fullCommandOutput ());
-	if (!ok) report_template.append ("- not available -");
-	delete control;
-
-	KDialog *dialog = new KDialog (for_window);
-	connect (dialog, SIGNAL (finished(int)), dialog, SLOT (deleteLater()));
-	dialog->setCaption (i18n ("Reporting bugs in RKWard"));
-	dialog->setButtons (KDialog::Ok);
-	KVBox *vbox = new KVBox (dialog);
-	dialog->setMainWidget (vbox);
-	QLabel *label = new QLabel (i18n ("<p><b>Where should I report bugs or wishes?</b></p><p>Please submit your bug reports or wishes at <a href=\"%1\">%1</a> or send email to <a href=\"mailto:%2\">%2</a>.</p>"
-							"<p><b>What information should I provide?</b></p><p>Please copy the information shown below, and fill in the details to the questions.</p>"
-							, QString ("http://sourceforge.net/tracker/?group_id=50231&atid=459007"), QString ("rkward-devel@lists.sourceforge.net")), vbox);
-	label->setWordWrap (true);
-	label->setOpenExternalLinks (true);
-	QTextEdit *details = new QTextEdit (vbox);
-	details->setReadOnly (true);
-	details->setText (report_template);
-
-	dialog->show ();
+	RKErrorDialog::reportBug (for_window);
 }
 
 void RKTopLevelWindowGUI::showAboutApplication () {
