@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed May 4 2005
     copyright            : (C) 2005 - 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -29,6 +29,7 @@
 
 #include "../rkwardapplication.h"
 #include "../settings/rksettingsmodulegraphics.h"
+#include "../dialogs/rkerrordialog.h"
 #include "rkworkplace.h"
 #include "../misc/rkstandardicons.h"
 #include "../debug.h"
@@ -67,9 +68,9 @@ void RKWindowCatcher::stop (int new_cur_device) {
 #endif
 		} else {
 #if defined Q_WS_MAC
-			KMessageBox::information (0, i18n ("You have created a new graphics device window in R. Usually, RKWard tries to detect such windows, to take control of them, and add a menu-bar to them. However, this is not currently supported in this build of RKWard on Mac OS X. See http://p.sf.net/rkward/mac for more information."), i18n ("Could not embed R X11 window"), "embed_x11_device_not_supported");
+			KMessageBox::information (0, i18n ("You have tried to embed a new R graphics device window in RKWard. However, this is not currently supported in this build of RKWard on Mac OS X. See http://rkward.kde.org/mac for more information."), i18n ("Could not embed R X11 window"), "embed_x11_device_not_supported");
 #else
-			KMessageBox::information (0, i18n ("You have created a new X11 device window in R. Usually, RKWard tries to detect such windows, to take control of them, and add a menu-bar to them. This time, however, RKWard failed to detect, which window was created, and so can not embed it.\nIf you created the window on a different screen or X11 display, that is to be expected. You might want to consider changing options(\"display\"), then.\nIf you can see the X11 window on the same screen as this message, then RKWard should do better. In this case, please contact us at rkward-devel@lists.sourceforge.net with details on your setup, so we can try to fix this in future versions of RKWard."), i18n ("Could not embed R X11 window"), "failure_to_detect_x11_device");
+			RKErrorDialog::reportableErrorMessage (0, i18n ("You have tried to embed a new R graphics device window in RKWard. However, either no window was created, or RKWard failed to detect the new window. If you think RKWard should have done better, consider reporting this as a bug. Alternatively, you may want to adjust Settings->Configure RKWard->Onscreen Graphics."), QString (), i18n ("Could not embed R X11 window"), "failure_to_detect_x11_device");
 #endif
 		}
 	}
@@ -131,6 +132,7 @@ void RKWindowCatcher::killDevice (int device_number) {
 
 #include "../rkglobals.h"
 #include "../rbackend/rinterface.h"
+#include "../rbackend/rkwarddevice/rkgraphicsdevice.h"
 #include "../core/robject.h"
 #include "../misc/rkprogresscontrol.h"
 #include "../misc/rksaveobjectchooser.h"
@@ -142,33 +144,8 @@ QHash<int, RKCaughtX11Window*> RKCaughtX11Window::device_windows;
 RKCaughtX11Window::RKCaughtX11Window (WId window_to_embed, int device_number) : RKMDIWindow (0, X11Window), RCommandReceiver () {
 	RK_TRACE (MISC);
 
-	capture = 0;
-	killed_in_r = close_attempted = false;
+	commonInit (device_number);
 	embedded = window_to_embed;
-	RKCaughtX11Window::device_number = device_number;
-	RK_ASSERT (!device_windows.contains (device_number));
-	device_windows.insert (device_number, this);
-
-	error_dialog = new RKProgressControl (0, i18n ("An error occurred"), i18n ("An error occurred"), RKProgressControl::DetailedError);
-	setPart (new RKCaughtX11WindowPart (this));
-	setMetaInfo (i18n ("Graphics Device Window"), "rkward://page/rkward_plot_history", RKSettings::PageX11);
-	initializeActivationSignals ();
-	setFocusPolicy (Qt::ClickFocus);
-	updateHistoryActions (0, 0, QStringList ());
-
-	status_popup = new KPassivePopup (this);
-	status_popup->setTimeout (0);
-	disconnect (status_popup, SIGNAL (clicked()), status_popup, SLOT (hide()));	// no auto-hiding, please
-
-	QVBoxLayout *layout = new QVBoxLayout (this);
-	layout->setContentsMargins (0, 0, 0, 0);
-	box_widget = new KVBox (this);
-	layout->addWidget (box_widget);
-	scroll_widget = new QScrollArea (this);
-	scroll_widget->hide ();
-	layout->addWidget (scroll_widget);
-
-	xembed_container = new KVBox (box_widget);	// QX11EmbedContainer can not be reparented (between the box_widget, and the scroll_widget) directly. Therefore we place it into a container, and reparent that instead
 
 #ifdef Q_WS_WIN
 	// unfortunately, trying to get KWindowInfo as below hangs on windows (KDElibs 4.2.3)
@@ -192,33 +169,87 @@ RKCaughtX11Window::RKCaughtX11Window (WId window_to_embed, int device_number) :
 	setGeometry (wininfo.geometry ());	// it's important to set a size, even while not visible. Else DetachedWindowContainer will assign a default size of 640*480, and then size upwards, if necessary.
 	setCaption (wininfo.name ());
 #endif
-	dynamic_size = false;
-	dynamic_size_action->setChecked (false);
 
 	// somehow in Qt 4.4.3, when the RKCaughtWindow is reparented the first time, the QX11EmbedContainer may kill its client. Hence we delay the actual embedding until after the window was shown.
 	// In some previous version of Qt, this was not an issue, but I did not track the versions.
 	QTimer::singleShot (0, this, SLOT (doEmbed()));
 }
 
+RKCaughtX11Window::RKCaughtX11Window (RKGraphicsDevice* rkward_device, int device_number) : RKMDIWindow (0, X11Window) {
+	RK_TRACE (MISC);
+
+	commonInit (device_number);
+	rk_native_device = rkward_device;
+	xembed_container->setFixedSize (rk_native_device->viewPort ()->size ());
+	resize (xembed_container->size ());
+	rk_native_device->viewPort ()->setParent (xembed_container);
+	connect (rkward_device, SIGNAL (captionChanged(QString)), this, SLOT (setCaption(QString)));
+	connect (rkward_device, SIGNAL (goingInteractive(bool,QString)), this, SLOT (deviceInteractive(bool,QString)));
+	stop_interaction->setVisible (true);
+	stop_interaction->setEnabled (false);
+	setCaption (rkward_device->viewPort ()->windowTitle ());
+
+	QTimer::singleShot (0, this, SLOT (doEmbed()));
+}
+
+void RKCaughtX11Window::commonInit (int device_number) {
+	RK_TRACE (MISC);
+
+	capture = 0;
+	rk_native_device = 0;
+	embedded = 0;
+	killed_in_r = close_attempted = false;
+	RKCaughtX11Window::device_number = device_number;
+	RK_ASSERT (!device_windows.contains (device_number));
+	device_windows.insert (device_number, this);
+
+	error_dialog = new RKProgressControl (0, i18n ("An error occurred"), i18n ("An error occurred"), RKProgressControl::DetailedError);
+	setPart (new RKCaughtX11WindowPart (this));
+	setMetaInfo (i18n ("Graphics Device Window"), "rkward://page/rkward_plot_history", RKSettings::PageX11);
+	initializeActivationSignals ();
+	setFocusPolicy (Qt::ClickFocus);
+	updateHistoryActions (0, 0, QStringList ());
+
+	status_popup = new KPassivePopup (this);
+	status_popup->setTimeout (0);
+	disconnect (status_popup, SIGNAL (clicked()), status_popup, SLOT (hide()));	// no auto-hiding, please
+
+	QVBoxLayout *layout = new QVBoxLayout (this);
+	layout->setContentsMargins (0, 0, 0, 0);
+	box_widget = new KVBox (this);
+	layout->addWidget (box_widget);
+	scroll_widget = new QScrollArea (this);
+	scroll_widget->hide ();
+	layout->addWidget (scroll_widget);
+
+	xembed_container = new KVBox (box_widget);	// QX11EmbedContainer can not be reparented (between the box_widget, and the scroll_widget) directly. Therefore we place it into a container, and reparent that instead.
+	// Also, this makes it easier to handle the various different devices
+
+	dynamic_size = false;
+	dynamic_size_action->setChecked (false);
+}
+
 void RKCaughtX11Window::doEmbed () {
 	RK_TRACE (MISC);
 
+	if (embedded) {
 #ifdef Q_WS_WIN
-	capture = new QWinHost (xembed_container);
-	capture->setWindow (embedded);
-	capture->setFocusPolicy (Qt::ClickFocus);
-	capture->setAutoDestruct (true);
-	connect (capture, SIGNAL (clientDestroyed()), this, SLOT (deleteLater()), Qt::QueuedConnection);
-	connect (capture, SIGNAL (clientTitleChanged(const QString&)), this, SLOT (setCaption(const QString&)), Qt::QueuedConnection);
+		capture = new QWinHost (xembed_container);
+		capture->setWindow (embedded);
+		capture->setFocusPolicy (Qt::ClickFocus);
+		capture->setAutoDestruct (true);
+		connect (capture, SIGNAL (clientDestroyed()), this, SLOT (deleteLater()), Qt::QueuedConnection);
+		connect (capture, SIGNAL (clientTitleChanged(QString)), this, SLOT (setCaption(QString)), Qt::QueuedConnection);
 
-	setCaption (capture->getClientTitle ());
+		setCaption (capture->getClientTitle ());
 #elif defined Q_WS_X11
-	capture = new QX11EmbedContainer (xembed_container);
-	capture->embedClient (embedded);
-	connect (capture, SIGNAL (clientClosed ()), this, SLOT (deleteLater ()));
+		capture = new QX11EmbedContainer (xembed_container);
+		capture->embedClient (embedded);
+		connect (capture, SIGNAL (clientClosed()), this, SLOT (deleteLater()));
 
-	RKWardApplication::getApp ()->registerNameWatcher (embedded, this);
+		RKWardApplication::getApp ()->registerNameWatcher (embedded, this);
 #endif
+	}
 	// make xembed_container resizable, again, now that it actually has a content
 	dynamic_size_action->setChecked (true);
 	fixedSizeToggled ();
@@ -238,7 +269,7 @@ RKCaughtX11Window::~RKCaughtX11Window () {
 
 	close (false);
 #ifdef Q_WS_X11
-	RKWardApplication::getApp ()->unregisterNameWatcher (embedded);
+	if (embedded) RKWardApplication::getApp ()->unregisterNameWatcher (embedded);
 #endif
 	error_dialog->autoDeleteWhenDone ();
 	delete status_popup;
@@ -264,6 +295,8 @@ bool RKCaughtX11Window::close (bool also_delete) {
 		return RKMDIWindow::close (also_delete);
 	}
 
+	if (rk_native_device) rk_native_device->stopInteraction ();
+
 	QString status = i18n ("Closing device (saving history)");
 	if (!close_attempted) {
 		RCommand* c = new RCommand ("dev.off (" + QString::number (device_number) + ')', RCommand::App, i18n ("Shutting down device number %1", device_number));
@@ -310,6 +343,28 @@ void RKCaughtX11Window::prepareToBeDetached () {
 	reEmbed ();
 }
 
+void RKCaughtX11Window::deviceInteractive (bool interactive, const QString& prompt) {
+	RK_TRACE (MISC);
+
+	stop_interaction->setToolTip (prompt);
+	stop_interaction->setEnabled (interactive);
+
+	if (interactive) {
+		activate (true);
+		// it is necessary to do this also in the wrapper widget. Otherwise, for some reason, the view cannot be expanded, but can be shrunk.
+		setSizePolicy (QSizePolicy::Fixed, QSizePolicy::Fixed);
+	} else {
+		setSizePolicy (QSizePolicy::Preferred, QSizePolicy::Preferred);
+	}
+}
+
+void RKCaughtX11Window::stopInteraction () {
+	RK_TRACE (MISC);
+
+	RK_ASSERT (rk_native_device);
+	rk_native_device->stopInteraction ();
+}
+
 void RKCaughtX11Window::fixedSizeToggled () {
 	RK_TRACE (MISC);
 
@@ -390,7 +445,7 @@ void RKCaughtX11Window::setFixedSizeManual () {
 void RKCaughtX11Window::activateDevice () {
 	RK_TRACE (MISC);
 
-	RKGlobals::rInterface ()->issueCommand ("dev.set (" + QString::number (device_number) + ")", RCommand::App, i18n ("Activate graphics device number %1", device_number), error_dialog);
+	RKGlobals::rInterface ()->issueCommand ("dev.set (" + QString::number (device_number) + ')', RCommand::App, i18n ("Activate graphics device number %1", device_number), error_dialog);
 }
 
 void RKCaughtX11Window::copyDeviceToOutput () {
@@ -404,7 +459,7 @@ void RKCaughtX11Window::printDevice () {
 
 	QString printer_device;
 	if (RKSettingsModuleGraphics::kdePrintingEnabled ()) printer_device = "rk.printer.device";
-	RKGlobals::rInterface ()->issueCommand ("dev.set (" + QString::number (device_number) + ")\ndev.print (" + printer_device + ")", RCommand::App, i18n ("Print contents of graphics device number %1", device_number), error_dialog);
+	RKGlobals::rInterface ()->issueCommand ("dev.set (" + QString::number (device_number) + ")\ndev.print (" + printer_device + ')', RCommand::App, i18n ("Print contents of graphics device number %1", device_number), error_dialog);
 }
 
 void RKCaughtX11Window::copyDeviceToRObject () {
@@ -420,7 +475,7 @@ void RKCaughtX11Window::copyDeviceToRObject () {
 
 	new QLabel (i18n ("Specify the R object name, you want to save the graph to"), page);
 	RKSaveObjectChooser *chooser = new RKSaveObjectChooser (page, "my.plot");
-	connect (chooser, SIGNAL (changed (bool)), dialog, SLOT (enableButtonOk (bool)));
+	connect (chooser, SIGNAL (changed(bool)), dialog, SLOT (enableButtonOk(bool)));
 	if (!chooser->isOk ()) dialog->enableButtonOk (false);
 
 	dialog->exec ();
@@ -439,7 +494,7 @@ void RKCaughtX11Window::copyDeviceToRObject () {
 void RKCaughtX11Window::duplicateDevice () {
 	RK_TRACE (MISC);
 
-	RKGlobals::rInterface ()->issueCommand ("rk.duplicate.device (" + QString::number (device_number) + ")", RCommand::App, i18n ("Duplicate graphics device number %1", device_number), error_dialog);
+	RKGlobals::rInterface ()->issueCommand ("rk.duplicate.device (" + QString::number (device_number) + ')', RCommand::App, i18n ("Duplicate graphics device number %1", device_number), error_dialog);
 }
 
 void RKCaughtX11Window::nextPlot () {
@@ -505,7 +560,7 @@ void RKCaughtX11Window::clearHistory () {
 void RKCaughtX11Window::showPlotInfo () {
 	RK_TRACE (MISC);
 
-	RKGlobals::rInterface ()->issueCommand ("rk.show.plot.info (" + QString::number (device_number) + ")", RCommand::App, i18n ("Plot properties (device number %1)", device_number), error_dialog);
+	RKGlobals::rInterface ()->issueCommand ("rk.show.plot.info (" + QString::number (device_number) + ')', RCommand::App, i18n ("Plot properties (device number %1)", device_number), error_dialog);
 }
 
 void RKCaughtX11Window::updateHistoryActions (int history_length, int position, const QStringList &labels) {
@@ -647,8 +702,13 @@ RKCaughtX11WindowPart::RKCaughtX11WindowPart (RKCaughtX11Window *window) : KPart
 	action->setText (i18n ("Duplicate"));
 	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionWindowDuplicate));
 
+	action = window->stop_interaction = actionCollection ()->addAction ("stop_interaction", window, SLOT (stopInteraction()));
+	action->setText (i18n ("Stop interaction"));
+	action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionInterrupt));
+	action->setVisible (false);
+
 	// initialize context for plugins
-	RKContextMap *context = RKComponentMap::getContext ("x11");
+	RKComponentGUIXML *context = RKComponentMap::getContext ("x11");
 	if (!context) return;
 	RKContextHandler *context_handler = context->makeContextHandler (this);
 	insertChildClient (context_handler);
