@@ -2,8 +2,8 @@
                           rwindowcatcher.h  -  description
                              -------------------
     begin                : Wed May 4 2005
-    copyright            : (C) 2005 - 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005-2013 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -95,8 +95,10 @@ class RKProgressControl;
 class QX11EmbedContainer;
 class QWinHost;
 class KPassivePopup;
+class RKGraphicsDevice;
 
-/** An R X11 device window managed by rkward. */
+/** An R onscreen graphics device window managed by rkward. Currently, this can be X11 devices (on X11), Windows devices (on Windows), and
+ RK devices (anywhere). */
 class RKCaughtX11Window : public RKMDIWindow, public RCommandReceiver {
 	Q_OBJECT
 public:
@@ -104,6 +106,7 @@ public:
 @param window_to_embed the Window id of the R X11 device window to embed
 @param device_number the device number corresponding to that window */
 	RKCaughtX11Window (WId window_to_embed, int device_number);
+	RKCaughtX11Window (RKGraphicsDevice *rkward_device, int device_number);
 /** dtor */
 	~RKCaughtX11Window ();
 /** TODO? */
@@ -124,6 +127,8 @@ is simply busy (e.g. when saving the current plot to history). */
  * NOTE: If no device exists (or isn't known to the system), this function does nothing */
 	static void setStatusMessage (int dev_num, const QString &message, RCommand *command=0);
 public slots:
+	void deviceInteractive (bool interactive, const QString &prompt);
+	
 /** Fixed size action was (potentially) toggled. Update to the new state */
 	void fixedSizeToggled ();
 /** Switch to fixed size mode, and set size1 (currently 500*500) */
@@ -140,6 +145,7 @@ public slots:
 	void printDevice ();
 	void copyDeviceToRObject ();
 	void duplicateDevice ();
+	void stopInteraction ();
 
 /** history navigation */
 	void firstPlot ();
@@ -159,6 +165,7 @@ private slots:
 	void doEmbed ();
 private:
 	void forceClose ();
+	void commonInit (int device_number);
 	void reEmbed ();
 	void rCommandDone (RCommand *command);
 	friend class RKCaughtX11WindowPart;	// needs access to the actions
@@ -180,6 +187,7 @@ private:
 	// a dummy to make things compile for now
 	QWidget *capture;
 #endif
+	RKGraphicsDevice *rk_native_device;
 
 	bool dynamic_size;
 	KToggleAction *dynamic_size_action;
@@ -192,6 +200,7 @@ private:
 	KAction *plot_clear_history_action;
 	KAction *plot_properties_action;
 	KSelectAction *plot_list_action;
+	KAction *stop_interaction;
 
 	KPassivePopup* status_popup;
 	RCommand* status_change_command;
