@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 21 2006
     copyright            : (C) 2006-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,6 +31,7 @@
 
 #include <QFileInfo>
 #include <QCryptographicHash>
+#include <QKeyEvent>
 
 #include "detachedwindowcontainer.h"
 #include "rkcommandeditorwindow.h"
@@ -211,7 +212,7 @@ void RKWorkplace::addWindow (RKMDIWindow *window, bool attached) {
 	RK_TRACE (APP);
 
 	windows.append (window);
-	connect (window, SIGNAL (destroyed (QObject *)), this, SLOT (removeWindow (QObject *)));
+	connect (window, SIGNAL (destroyed(QObject*)), this, SLOT (removeWindow(QObject*)));
 	connect (window, SIGNAL (windowActivated(RKMDIWindow*)), history, SLOT (windowActivated(RKMDIWindow*)));
 	if (window->isToolWindow () && !window->tool_window_bar) return;
 	if (attached) attachWindow (window);
@@ -221,7 +222,7 @@ void RKWorkplace::addWindow (RKMDIWindow *window, bool attached) {
 void RKWorkplace::placeToolWindows() {
 	RK_TRACE (APP);
 
-	foreach (const RKToolWindowList::ToolWindowRepresentation rep, RKToolWindowList::registeredToolWindows ()) {
+	foreach (const RKToolWindowList::ToolWindowRepresentation& rep, RKToolWindowList::registeredToolWindows ()) {
 		placeInToolWindowBar (rep.window, rep.default_placement);
 		getHistory ()->popLastWindow (rep.window);	// windows send a spurious activation signal triggered from KPartsManager::addPart(), so we pop them, again
 	}
@@ -249,7 +250,9 @@ void RKWorkplace::placeInToolWindowBar (RKMDIWindow *window, int position) {
 bool RKWorkplace::openAnyUrl (const KUrl &url, const QString &known_mimetype, bool force_external) {
 	RK_TRACE (APP);
 
-#warning TODO support rkward:\/\/-protocol, here, too
+	if (url.protocol () == "rkward") {
+		if (RKHTMLWindow::handleRKWardURL (url)) return true;
+	}
 	KMimeType::Ptr mimetype;
 	if (!known_mimetype.isEmpty ()) mimetype = KMimeType::mimeType (known_mimetype);
 	else mimetype = KMimeType::findByUrl (url);
@@ -261,13 +264,14 @@ bool RKWorkplace::openAnyUrl (const KUrl &url, const QString &known_mimetype, bo
 			openHelpWindow (url, true);
 			return true;	// TODO
 		}
-		if (url.fileName ().toLower ().endsWith (".rdata")) {
-			RKWardMainWindow::getMain ()->fileOpenAskSave (url);
+		if (url.fileName ().toLower ().endsWith (".rdata") || url.fileName ().toLower ().endsWith (".rda")) {
+			RKWardMainWindow::getMain ()->askOpenWorkspace (url);
 			return true;	// TODO
 		}
-		if (mimetype->name ().startsWith ("text")) {
+		if (mimetype->is ("text/plain")) {
 			return (openScriptEditor (url, QString (), RKSettingsModuleCommandEditor::matchesScriptFileFilter (url.fileName())));
 		}
+		RK_DEBUG (APP, DL_INFO, "Don't know how to handle mimetype %s.", qPrintable (mimetype->name ()));
 	}
 
 	if (KMessageBox::questionYesNo (this, i18n ("The url you are trying to open ('%1') is not a local file or the filetype is not supported by RKWard. Do you want to open the url in the default application?", url.prettyUrl ()), i18n ("Open in default application?")) != KMessageBox::Yes) {
@@ -352,6 +356,14 @@ void RKWorkplace::newX11Window (WId window_to_embed, int device_number) {
 	addWindow (window, false);
 }
 
+void RKWorkplace::newRKWardGraphisWindow (RKGraphicsDevice* dev, int device_number) {
+	RK_TRACE (APP);
+
+	RKCaughtX11Window *window = new RKCaughtX11Window (dev, device_number);
+	window->state = RKMDIWindow::Detached;
+	addWindow (window, false);
+}
+
 void RKWorkplace::newObjectViewer (RObject *object) {
 	RK_TRACE (APP);
 	RK_ASSERT (object);
@@ -607,14 +619,16 @@ void RKWorkplace::saveWorkplace (RCommandChain *chain) {
 // standard KConfig format.
 	if (RKSettingsModuleGeneral::workplaceSaveMode () != RKSettingsModuleGeneral::SaveWorkplaceWithWorkspace) return;
 
-	RKGlobals::rInterface ()->issueCommand ("rk.save.workplace(description=" + RObject::rQuote (makeWorkplaceDescription().join ("\n")) + ")", RCommand::App, i18n ("Save Workplace layout"), 0, 0, chain);
+	RKGlobals::rInterface ()->issueCommand ("rk.save.workplace(description=" + RObject::rQuote (makeWorkplaceDescription().join ("\n")) + ')', RCommand::App, i18n ("Save Workplace layout"), 0, 0, chain);
 }
 
-void RKWorkplace::restoreWorkplace (RCommandChain *chain) {
+void RKWorkplace::restoreWorkplace (RCommandChain *chain, bool merge) {
 	RK_TRACE (APP);
 	if (RKSettingsModuleGeneral::workplaceSaveMode () != RKSettingsModuleGeneral::SaveWorkplaceWithWorkspace) return;
 
-	RKGlobals::rInterface ()->issueCommand ("rk.restore.workplace()", RCommand::App, i18n ("Restore Workplace layout"), 0, 0, chain);
+	QString no_close_windows;
+	if (merge) no_close_windows = "close.windows = FALSE";
+	RKGlobals::rInterface ()->issueCommand ("rk.restore.workplace(" + no_close_windows + ')', RCommand::App, i18n ("Restore Workplace layout"), 0, 0, chain);
 }
 
 KUrl checkAdjustRestoredUrl (const QString &_url, const QString old_base) {
