@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Sep 26 2006
     copyright            : (C) 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -66,7 +66,7 @@ RKWorkplaceView::RKWorkplaceView (QWidget *parent) : KTabWidget (parent) {
 #endif
 
 	tabBar ()->setContextMenuPolicy (Qt::CustomContextMenu);
-	connect (tabBar (), SIGNAL (customContextMenuRequested(const QPoint&)), this, SLOT (showContextMenu(const QPoint&)));
+	connect (tabBar (), SIGNAL (customContextMenuRequested(QPoint)), this, SLOT (showContextMenu(QPoint)));
 
 	KAcceleratorManager::setNoAccel (tabBar ());	// TODO: This is a WORKAROUND for a bug in kdelibs where tabs named "a0.txt", "a1.txt", etc. will steal the Alt+0/1... shortcuts
 	setTabBarHidden (true);		// initially
@@ -126,7 +126,7 @@ void RKWorkplaceView::addWindow (RKMDIWindow *widget) {
 
 	id = addTab (widget, icon, widget->shortCaption ());
 
-	connect (widget, SIGNAL (captionChanged (RKMDIWindow *)), this, SLOT (childCaptionChanged (RKMDIWindow *)));
+	connect (widget, SIGNAL (captionChanged(RKMDIWindow*)), this, SLOT (childCaptionChanged(RKMDIWindow*)));
 	widget->show ();
 
 	if (count () > 1) setTabBarHidden (false);
@@ -143,7 +143,7 @@ void RKWorkplaceView::removeWindow (RKMDIWindow *widget, bool destroyed) {
 
 	int id = indexOf (widget);		// which page is it?
 	if (id == -1) RK_DEBUG (APP, DL_WARNING, "did not find page in RKWorkplaceView::removeWindow");
-	if (!destroyed) disconnect (widget, SIGNAL (captionChanged (RKMDIWindow *)), this, SLOT (childCaptionChanged (RKMDIWindow *)));
+	if (!destroyed) disconnect (widget, SIGNAL (captionChanged(RKMDIWindow*)), this, SLOT (childCaptionChanged(RKMDIWindow*)));
 
 	removeTab (id);
 	if (count () <= 1) setTabBarHidden (true);
