@@ -2,8 +2,8 @@
                           robjectbrowser  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007, 2008, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2004 - 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,13 +18,9 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qcheckbox.h>
-#include <qradiobutton.h>
-#include <QHBoxLayout>
 #include <QFocusEvent>
 #include <QVBoxLayout>
 #include <QMenu>
-#include <QButtonGroup>
 
 #include <klocale.h>
 #include <kinputdialog.h>
@@ -40,6 +36,7 @@
 #include "../rbackend/rinterface.h"
 #include "../misc/rkobjectlistview.h"
 #include "../misc/rkdummypart.h"
+#include "../misc/rkstandardicons.h"
 #include "rkworkplace.h"
 #include "../dataeditor/rkeditor.h"
 
@@ -110,8 +107,8 @@ RObjectBrowserInternal::RObjectBrowserInternal (QWidget *parent) : QWidget (pare
 	QVBoxLayout *vbox = new QVBoxLayout (this);
 	vbox->setContentsMargins (0, 0, 0, 0);
 
-	list_view = new RKObjectListView (this);
-	vbox->addWidget (new RKObjectListViewSettingsWidget (list_view->getSettings (), this));
+	list_view = new RKObjectListView (true, this);
+	vbox->addWidget (list_view->getSettings ()->filterWidget (this));
 	vbox->addWidget (list_view);
 
 	update_button = new QPushButton (i18n ("Update"), this);
@@ -156,7 +153,7 @@ RObjectBrowserInternal::~RObjectBrowserInternal () {
 void RObjectBrowserInternal::focusInEvent (QFocusEvent *e) {
 	RK_TRACE (APP);
 
-	list_view->setFocus ();
+	list_view->getSettings ()->filterWidget (this)->setFocus ();
 	if (e->reason () != Qt::MouseFocusReason) {
 		list_view->setObjectCurrent (RObjectList::getGlobalEnv (), true);
 	}
@@ -278,97 +275,4 @@ void RObjectBrowserInternal::doubleClicked (const QModelIndex& index) {
 	}
 }
 
-
-//////////////////// RKObjectListViewSettingsWidget //////////////////////////
-RKObjectListViewSettingsWidget::RKObjectListViewSettingsWidget (RKObjectListViewSettings *settings, QWidget *parent) : QWidget (parent) {
-	RK_TRACE (APP);
-
-	RKObjectListViewSettingsWidget::settings = settings;
-	connect (settings, SIGNAL (settingsChanged()), this, SLOT (settingsChanged()));
-
-	QVBoxLayout *layout = new QVBoxLayout (this);
-	layout->setContentsMargins (0, 0, 0, 0);
-
-	QButtonGroup *group = new QButtonGroup (this);
-	QHBoxLayout *hbox = new QHBoxLayout ();
-	hbox->setContentsMargins (0, 0, 0, 0);
-	group->addButton (all = new QRadioButton (i18n ("All"), this));
-	group->addButton (nonfunctions = new QRadioButton (i18n ("Non-Functions"), this));
-	group->addButton (functions = new QRadioButton (i18n ("Functions"), this));
-	hbox->addWidget (all);
-	hbox->addWidget (nonfunctions);
-	hbox->addWidget (functions);
-	connect (all, SIGNAL(clicked(bool)), this, SLOT(modeChanged(bool)));
-	connect (nonfunctions, SIGNAL(clicked(bool)), this, SLOT(modeChanged(bool)));
-	connect (functions, SIGNAL(clicked(bool)), this, SLOT(modeChanged(bool)));
-	layout->addLayout (hbox);
-
-	all_envirs = new QCheckBox (i18n ("Show All Environments"), this);
-	connect (all_envirs, SIGNAL (clicked(bool)), this, SLOT (boxChanged(bool)));
-	layout->addWidget (all_envirs);
-
-	hidden_objects = new QCheckBox (i18n ("Show Hidden Objects"), this);
-	connect (hidden_objects, SIGNAL (clicked(bool)), this, SLOT (boxChanged(bool)));
-	layout->addWidget (hidden_objects);
-
-	settingsChanged ();
-}
-
-RKObjectListViewSettingsWidget::~RKObjectListViewSettingsWidget () {
-	RK_TRACE (APP);
-}
-
-void RKObjectListViewSettingsWidget::settingsChanged () {
-	RK_TRACE (APP);
-
-	all_envirs->setChecked (settings->getSetting (RKObjectListViewSettings::ShowObjectsAllEnvironments));
-	hidden_objects->setChecked (settings->getSetting (RKObjectListViewSettings::ShowObjectsHidden));
-
-	bool functions_shown = settings->getSetting (RKObjectListViewSettings::ShowObjectsFunction);
-	bool vars_shown = settings->getSetting (RKObjectListViewSettings::ShowObjectsVariable);
-	bool containers_shown = settings->getSetting (RKObjectListViewSettings::ShowObjectsContainer);
-
-	if (functions_shown && vars_shown && containers_shown) {
-		all->setChecked (true);
-	} else if (vars_shown && containers_shown) {
-		nonfunctions->setChecked (true);
-	} else if (functions_shown && (!(vars_shown || containers_shown))) {
-		functions->setChecked (true);
-	} else {
-		all->setChecked (false);
-		nonfunctions->setChecked (false);
-		functions->setChecked (false);
-	}
-}
-
-void RKObjectListViewSettingsWidget::modeChanged (bool) {
-	RK_TRACE (APP);
-
-	if (all->isChecked ()) {
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsFunction, true);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsVariable, true);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsContainer, true);
-	} else if (functions->isChecked ()) {
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsFunction, true);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsVariable, false);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsContainer, false);
-	} else if (nonfunctions->isChecked ()) {
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsFunction, false);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsVariable, true);
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsContainer, true);
-	} else {
-		RK_ASSERT (false);
-	}
-}
-
-void RKObjectListViewSettingsWidget::boxChanged (bool) {
-	RK_TRACE (APP);
-
-	if (sender () == all_envirs) {
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsAllEnvironments, all_envirs->isChecked ());
-	} else {
-		settings->setSetting (RKObjectListViewSettings::ShowObjectsHidden, hidden_objects->isChecked ());
-	}
-}
-
 #include "robjectbrowser.moc"
