@@ -7,6 +7,7 @@ testsuites <- c (
 	"item_response_theory.R",
 	"analysis_plugins.R",
 	"distributions.R",
-	"plots.R")
+	"plots.R",
+	"data_plugin_tests.R")
 
 rktest.makeplugintests (testsuites=testsuites, outfile="make_plugintests.txt")
